--[[ Copyright (c) 2011, 2012 <Zbyněk "teh dude :D" Schwarz>, 2021 <Jan "jansakos" Sako>

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE. --]]

Font("unicode")
Language("Čeština", "Czech", "cs", "cze", "cz")
Inherit("English")
IsArabicNumerals(true)

high_score = {
  player = "HRÁČ",
  pos = "POZ",
  best_scores = "SÍŇ SLÁVY",
  killed = "Zabil",
  categories = {
    salary = "NEJVYŠŠÍ VÝPLATA",
    total_value = "CELKOVÁ HODNOTA",
    money = "NEJBOHATŠÍ",
    clean = "ČISTOTA",
    cures = "POČET VYLÉČENÍ",
    patient_happiness = "USPOKOJENÍ ZÁKAZNÍKŮ",
    deaths = "POČET ÚMRTÍ",
    cure_death_ratio = "POMĚR VYLÉČENÍ-ÚMRTÍ",
    staff_happiness = "SPOKOJENOST ZAMĚSTNANCŮ",
    visitors = "NEJVÍCE NÁVŠTĚVNÍKŮ",
    staff_number = "NEJVÍCE ZAMĚSTNANCŮ",
  },
  worst_scores = "SÍŇ HANBY",
  score = "SKÓRE",
}
menu_display = {
  shadows = "  STÍNY  ",
  mcga_lo_res = "  MCGA NÍZKÉ ROZ  ",
  high_res = "  VYSOKÉ ROZ  ",
}
hotkeys_file_err = {
  file_err_01 = "Nepovedlo se načíst soubor hotkeys.txt. Ověřte prosím, že CorsixTH má právo číst/psát soubory ",
  file_err_02 = ", nebo použijte v příkazovém řádku spouštěcí možnost --hotkeys-file=filename se jménem souboru. Popis chyby: ",
}
rooms_long = {
  dna_fixer = "Genex 2000", --[[Original translation of Theme Hospital named it the same way, both the room and the machine.--]]
  psychiatric = "Psychiatrie",
  corridors = "Chodby",
  gps_office = "Kancelář Praktického Lékaře",
  general = "Všeobecné",
  emergency = "Pohotovost",
  general_diag = "Vyšetřovna",
  hair_restoration = "Sázeč Vlasů",
  scanner = "Skener",
  research_room = "Výzkumná Laboratoř",
  cardiogram = "Kardiogram",
  toilets = "Toalety",
  decontamination = "Dekontaminace",
  staffroom = "Místnost pro Zaměstnance",
  ward = "Lůžkové Oddělení",
  jelly_vat = "Klinika slizu",
  x_ray = "Rentgen",
  inflation = "Hustírna",
  ultrascan = "Ultraskener",
  blood_machine = "Hemogram",
  tongue_clinic = "Oddělení Ochablého Jazyka",
  fracture_clinic = "Oddělení Zlomenin",
  training_room = "Učebna",
  electrolysis = "Oddělení Elektrolýzy",
  pharmacy = "Lékárna",
  operating_theatre = "Operační Sál",
}
menu_file_load = {
  [1] = "    HRA 1  ",
  [2] = "    HRA 2  ",
  [3] = "    HRA 3  ",
  [4] = "    HRA 4  ",
  [5] = "    HRA 5  ",
  [6] = "    HRA 6  ",
  [7] = "    HRA 7  ",
  [8] = "    HRA 8  ",
}
cheats_window = {
  warning = "Varování: Pokud budete podvádět, nedostanete na konci úrovně žádné bonusové body!",
  caption = "Cheaty",
  cheated = {
    no = "Cheaty použity: Ne",
    yes = "Cheaty použity: Ano",
  },
  close = "Zavřít",
  cheats = {
    lose_level = "Prohrát Úroveň",
    emergency = "Vytvořit Havárii",
    end_year = "Konec Roku",
    money = "Peníze",
    win_level = "Vyhrát Úroveň",
    earthquake = "Vytvořit Zemětřesení",
    all_research = "Všechen Výzkum",
    create_patient = "Vytvořit Pacienta",
    end_month = "Konec Měsíce",
    vip = "Vytvořit VIP",
    epidemic = "Vytvořit nakažlivého pacienta",
    toggle_infected = "Zapnout/Vypnout ikony nakažení",
    increase_prices = "Zvýšit ceny",
    decrease_prices = "Snížit ceny",
  },
}
menu_file_save = {
  [1] = "    HRA 1  ",
  [2] = "    HRA 2  ",
  [3] = "    HRA 3  ",
  [4] = "    HRA 4  ",
  [5] = "    HRA 5  ",
  [6] = "    HRA 6  ",
  [7] = "    HRA 7  ",
  [8] = "    HRA 8  ",
}
level_names = {
  [1] = "ToxiMěsto",
  [2] = "Ospalá Díra",
  [3] = "Velkočestr",
  [4] = "Mokrovousy nad Mořem",
  [5] = "Prosťáčkov",
  [6] = "Hnojnice",
  [7] = "Zelené Kaluže",
  [8] = "Lidový Čunín",
  [9] = "Východní Polipsy",
  [10] = "Vejcošunky",
  [11] = "Skřehotálkov",
  [12] = "Obezice",
  [13] = "Kámošlí",
  [14] = "Malé Ztlouknutí",
  [15] = "Zakopej Pohřbi",
}
custom_game_window = {
  free_build = "Volné stavění",
  caption = "Vlastní Hra",
  load_selected_level = "Spustit",
}
menu_debug_overlay = {
  positions = "    POZICE  ",
  parcel = "    PARCELA  ",
  byte_6 = "    BAJT 6  ",
  byte_floor = "    BAJT PODLAHY  ",
  none = "    ŽÁDNÝ  ",
  flags = "    PŘÍZNAKY  ",
  byte_0_1 = "    BAJT 0 a 1  ",
  byte_n_wall = "    BAJT S ZDI  ",
  byte_w_wall = "    BAJT Z ZDI  ",
  byte_5 = "    BAJT 5  ",
  byte_7 = "    BAJT 7  ",
  heat = "    TEPLOTA  ",
}
newspaper = {
  [1] = {
    [1] = "HOROR DR. ŠOKA",
    [2] = "DIVNÝ PRAKTICKÝ LÉKAŘ SI HRAJE NA BOHA",
    [3] = "ŠOK ŠPRÝMOŠTAINA",
    [4] = "CO BYLO NA LABORATORNÍM STOLE?",
    [5] = "RAZIE ZASTAVILA RISKANTNÍ VÝZKUM",
  },
  [2] = {
    [1] = "OPILÝ DO NĚMOTY",
    [2] = "OPILÝ CHIRURG",
    [3] = "HÝŘIVÝ KONZULTANT",
    [4] = "CHIRURGICKÁ ŠTAMPRLE",
    [5] = "CHIRURG NASÁVÁ",
    [6] = "CHIRURGICKÉ DUŠIČKY",
  },
  [3] = {
    [1] = "CHTIVÝ CHIRURG",
    [2] = "DOKTOR KALHOTYDOLŮ",
    [3] = "DOKTOR MÍŘÍ DOLŮ",
    [4] = "NEUKOJITELNÝ CHIRURG",
  },
  [4] = {
    [1] = "DOKTOR UPRAVUJE ČÍSLA",
    [2] = "ORGÁN-IZOVANÝ ZLOČIN",
    [3] = "OPERACE PŘEKLENUTÍ BANKY",
    [4] = "LÉKAŘ DRŽÍ FONDY",
  },
  [5] = {
    [1] = "ZDRAVOTNÍ VÝZKUMNÍK LOUPÍ HROBY",
    [2] = "DOKTOR VYPRAZDŇUJE HROBY",
    [3] = "PŘICHYCEN S MRTVOLOU",
    [4] = "DEN ZÚČTOVÁNÍ DR. SMRTKY",
    [5] = "SMRTELNÁ NEDBALOST",
    [6] = "DOKTOROVO NALEZIŠTĚ ODHALENO",
  },
  [6] = {
    [1] = "DOKTOROVA TAJNÁ DOHODA!",
    [2] = "NEPOZORNÝ MASTIČKÁŘ",
    [3] = "ZNIČUJÍCÍ VYŠETŘENÍ",
    [4] = "NEŠIKOVNÝ KONZULTANT",
  },
  [7] = {
    [1] = "DOKTOR NEMÁ CO DĚLAT",
    [2] = "CHIRURG 'OPERUJE' SÁM SEBE",
    [3] = "MASTURBACE NA HAJZLU",
    [4] = "DOKTORŮV SKANDÁL UCHOPEN",
    [5] = "MEDIK DĚLÁ BORDEL",
  },
}
months = {
  [1] = "Led",
  [2] = "Úno",
  [3] = "Bře",
  [4] = "Dub",
  [5] = "Kvě",
  [6] = "Čer",
  [7] = "Čvc",
  [8] = "Srp",
  [9] = "Zář",
  [10] = "Říj",
  [11] = "Lis",
  [12] = "Pro",
}
dynamic_info = {
  object = {
    strength = "Síla %d",
    queue_size = "Velikost Fronty %d",
    times_used = "Kolikrát Použito %d",
    queue_expected = "Očekávaná Fronta %d",
  },
  patient = {
    diagnosed = "Diagnóza: %s ",
    diagnosis_progress = "Průběh Vyšetření",
    guessed_diagnosis = "Odhadnutá diagnóza: %s ",
    actions = {
      no_diagnoses_available = "Nemáte pro mě žádné další diagnózy - Jdu domů",
      no_gp_available = "Čekám, až postavíte Kancelář Praktického Lékaře",
      cured = "Vyléčen!",
      waiting_for_treatment_rooms = "Čekám, až pro mě vybudujete místnost k léčení",
      fed_up = "Jsem naštvaný a odcházím",
      prices_too_high = "Vaše ceny jsou příliš vysoké - Jdu domů",
      on_my_way_to = "Na cestě do %s",
      sent_home = "Poslán domů",
      dying = "Umírá!",
      no_treatment_available = "Není pro mě diagnóza - Jdu domů",
      epidemic_contagious = "Jsem nakažlivý",
      waiting_for_diagnosis_rooms = "Čekám, až postavíte další diagnostická oddělení",
      queueing_for = "Ve frontě na %s",
      awaiting_decision = "Čekám na vaše rozhodnutí",
      sent_to_other_hospital = "Odkázán jinam",
      epidemic_sent_home = "Poslán domů Inspektorem",
      epidemic_vaccinated = "Již nejsem nakažlivý",
    },
    emergency = "Havárie: %s",
  },
  staff = {
    psychiatrist_abbrev = "Psych.",
    tiredness = "Únava",
    actions = {
      heading_for = "Mířím do %s",
      fired = "Propuštěn",
      wandering = "Jen se tak poflakuji",
      waiting_for_patient = "Čekám na pacienta",
      going_to_repair = "Jdu opravit %s",
      vaccine = "Očkuji pacienta",
    },
    ability = "Dovednost",
  },
  vip = "VIP Návštěvník",
  health_inspector = "Hygienický Inspektor",
}
calls_dispatcher = {
  summary = "%d volání; %d přiřazeno",
  watering = "Zalévám @ %d,%d",
  repair = "Opravit %s",
  staff = "%s - %s",
  close = "Zavřít",
}
town_map = {
  number = "Číslo Pozemku",
  area = "Oblast Pozemku",
  not_for_sale = "Nelze Vlastnit",
  owner = "Vlastník Pozemku",
  chat = "Chat Podrobností Města",
  for_sale = "Na prodej",
  price = "Cena Pozemku",
}
confirmation = {
  replace_machine = "Jste si jisti, že chcete nahradit %s za %d$?",
  music_warning = "Před zvolením hudby ve formátu mp3 se ujistěte, že máte dostupný soubor smpeg.dll, nebo podobné, pro váš operační systém, jinak ve hře nebudete mít žádnou hudbu. Chcete pokračovat?",
  abort_edit_room = "Právě stavíte nebo upravujete místnost. Pokud jsou všechny povinné objekty umístěny, bude dokončena, ale jinak bude smazána. Pokračovat?",
  quit = "Zvolili jste, že chcete Odejít. Opravdu chcete hru opustit?",
  needs_restart = "Změna tohoto nastavení vyžaduje restart CorsixTH. Jakýkoli neuložený postup bude ztracen. Jste si jisti, že to chcete udělat?",
  delete_room = "Opravdu chcete tuto místnost smazat?",
  sack_staff = "Jste si jisti, že chcete tohoto zaměstnance vykopnout?",
  restart_level = "Jste si jisti, že chcete úroveň restartovat?",
  overwrite_save = "Hra už byla do této pozice uložena. Jste si jisti, že ji chcete přepsat?",
  return_to_blueprint = "Jste si jisti, že se chcete vrátit do režimu Návrhu?",
  maximum_screen_size = "Velikost obrazovky, kterou jste zadali, je vyšší než 3000 x 2000. Na tato rozlišení lze přejít za předpokladu, že máte hardware schopný tuto hru udržet v hratelné rychlosti. Opravdu chcete pokračovat?",
  remove_destroyed_room = "Opravdu chcete odebrat místnost? Bude to stát $%d.",
  very_old_save = "Od doby, kdy jste začali s touto hrou, jsme již mnohokrát program aktualizovali. Chcete teď restartovat úroveň, pro jistotu, že vše správně funguje?//" ..
  "Vaše uložené rozehrané hry nebudou smazány, dokud je sami nepřepíšete novým uložením.",
}
adviser = {
  goals = {
    win = {
      reputation = "Zvyšte vaši reputaci na %d ke splnění kritéria pro výhru úrovně",
      money = "Potřebujete dalších %d ke splnění finančního kritéria v této úrovni.",
      cure = "Vylečte dalších %d pacientů a budete mít dostatek k výhře v této úrovni.",
      value = "Musíte zvýšit Vaši hodnotu nemocnice na %d",
    },
    lose = {
      kill = "Zabijte dalších %d pacientů a úroveň prohrajete!",
    },
  },
  competitors = {
    staff_poached = "Jeden z vašich zaměstnanců byl ukraden jinou nemocnicí.",
    land_purchased = "%s právě koupil pozemek.",
    hospital_opened = "%s otevřel v oblasti konkurenční nemocnici.",
  },
  information = {
    promotion_to_doctor = "Jeden z Vašich REZIDENTŮ se stal DOKTOREM.",
    pay_rise = "Jeden z Vašich zaměstnanců vyhrožuje výpovědí. Zvolte, jestli s jejich požadavky souhlasíte, nebo je vykopnete. Klikněte na ikonu vlevo, abyste viděli, který zaměstnanec hrozí výpovědí.",
    handyman_adjust = "Údržbáři můžou čistit účinněji tím, že jim zadáte priority.",
    emergency = "Je tu pohotovost! Pohyb! Pohyb! POHYB!",
    epidemic_health_inspector = "Zprávy o vaší epidemii se donesly na Ministerstvo Zdravotnictví. Připravte se na návštěvu Inspektora z Hygieny.",
    fax_received = "Ikona, která vyskočila vlevo dole na obrazovce, vás upozorňuje na důležitou informaci nebo rozhodnutí, které musíte udělat.",
    larger_rooms = "Větší místnosti dávají zaměstnancům pocit důležitosti a zlepšují jejich výkon.",
    first_cure = "Výborně! Právě jste vyléčili vašeho prvního pacienta.",
    promotion_to_specialist = "Jeden z Vašich Doktorů byl povýšen na %s.",
    initial_general_advice = {
      psychiatric_symbol = "Doktoři kvalifikování v psychiatrických záležitostech mají symbol: |",
      research_symbol = "Doktoři schopní výzkumu mají symbol: }",
      surgeon_symbol = "Doktoři, kteří mohou provádět operace, mají symbol: {",
      epidemic_spreading = "Ve vaší nemocnici je nákaza. Zkuste nakažené lidi vyléčit dřív než odejdou.",
      first_epidemic = "Ve vaší nemocnici je epidemie! Rozhodněte, zdali to chcete ututlat, nebo přiznáte barvu.",
      autopsy_available = "Auto-Pitevní stroj byl vynalezen. Tímto se můžete zbavit problémových a nevítaných pacientů a udělat na jejich zbytcích výzkum. Berte na vědomí, že použití tohoto přístroje je vysoce kontroverzní.",
      first_VIP = "Chystáte se pořádat vaši první návštěvu VIP. Snažte se zajistit, aby VIP neviděl nic nehygienického nebo nějaké nešťastné pacienty.",
      place_radiators = "Lidem ve vaší nemocnici je zima - můžete umístit více radiátorů tím, že je vyberete z menu Položek Chodby.",
      first_emergency = "Urgentní pacienti mají nad svými hlavami blikající modré světlo. Vylečte je předtím než zemřou nebo vyprší čas.",
      research_now_available = "Vybudovali jste vaši první Výzkumnou Laboratoř. Nyní můžete vstoupit do obrazovky Výzkumu.",
      taking_your_staff = "Někdo vám krade personál. Budete muset bojovat, aby tu zůstali.",
      first_patients_thirsty = "Lidé mají ve vaší nemocnici žízeň. Automat na nápoje by mohl pomoci.",
      machine_needs_repair = "Máte stroj, který potřebuje opravit. Nalezněte tento stroj - bude se z něho kouřit - a klikněte na něj. Pak klikněte na tlačítko údržbáře.",
      decrease_heating = "Lidé se ve vaší nemocnici roztékají! Třeba je na čase snížit teplotu vytápění v Obrazovce Města.",
      increase_heating = "Lidem visí u nosů rampouchy. Možná byste mohl zvýšit teplotu vytápění v Obrazovce Města.",
      rats_have_arrived = "Ve vaší nemocnici je více krys než pacientů. Zkuste pár krys myší zastřelit.",
    },
    place_windows = "Umístěním oken bude místnost jasnější a zlepší náladu vašich zaměstnanců.",
    patient_leaving_too_expensive = "Pacient odchází, aniž by zaplatil za %s. Je to pro něj příliš drahé.",
    vip_arrived = "Pozor! - %s právě přijel na obhlídku vaší nemocnice! Ujistěte se, že vše běží hladce, abyste ho potěšili.",
    epidemic = "Ve vaší nemocnici máte nakažlivou chorobu. Musíte s tím okamžitě něco dělat!",
    first_death = "Právě jste zabili svého prvního pacienta. Jaký je to pocit?",
    extra_items = "Dodatečné věci v místnostech vaše zaměstnance uklidňují a zlepšují jejich výkon.",
    promotion_to_consultant = "Jeden z Vašich DOKTORŮ se stal KONZULTANTEM.",
    patient_abducted = "Jednoho z vašich pacientů unášejí mimozemšťané.",
  },
  praise = {
    many_plants = "Jak milé. Máte spousty rostlin. Vaši pacienti to jistě ocení.",
    few_have_to_stand = "Jen málokdo musí ve vaší nemocnici stát. To pacienty potěší.",
    plenty_of_benches = "Je tu spousta míst k sezení. Gratuluji.",
    many_benches = "Pacienti teď mají dostatek míst k sezení. Bod pro vás.",
    plants_thriving = "Úžasné. Vaše rostliny přímo vzkvétají. Jen tak dál a možná za ně vyhrajete medaili.",
    plants_are_well = "Krása střídá nádheru. Umíte se postarat o vaše květiny.",
    patients_cured = "%d Pacientů vyléčeno.",
  },
  placement_info = {
    reception_can_place = "Tuto recepci můžete umístit zde.",
    window_can_place = "Toto okno můžete umístit zde. To by šlo.",
    door_can_place = "Pokud chcete, můžete tyto dveře umístit zde.",
    reception_cannot_place = "Zde nemůžete umístit tuto Recepci.",
    object_can_place = "Zde můžete umístit tento objekt.",
    room_cannot_place = "Zde nemůžete tuto místnost umístit.",
    room_cannot_place_2 = "Tato místnost sem dát nejde.",
    window_cannot_place = "Aha. Zde vlastně okno umístit nemůžete.",
    staff_cannot_place = "Zde nemůžete zaměstnance umístit. Je mi líto.",
    staff_can_place = "Zde můžete zaměstnance umístit. ",
    door_cannot_place = "Je mi líto, ale zde nemůžete umístit dveře.",
    object_cannot_place = "Hej, zde tento objekt umístit nemůžete.",
  },
  surgery_requirements = {
    need_surgeons_ward_op = "Musíte zaměstnat dva Chirurgy a postavit Lůžkové Oddělení a také Operační Sál k provedení Operace.",
    need_surgeon_ward = "Stále potřebujete zaměstnat dalšího Chirurga a postavit Lůžkové Oddělení, abyste mohli provádět Operace.",
  },
  build_advice = {
    placing_object_blocks_door = "Umístěním tohoto objektu zde by se lidé nedostali se k dveřím.",
    door_not_reachable = "Lidé by nebyli schopni se ke dveřím dostat. Co je v tom za problém, že.",
    blueprint_would_block = "Tento návrh by bránil ostatním místnostem. Zkuste změnit její velikost, nebo ji přesunout jinam!",
    blueprint_invalid = "To není platný návrh.",
  },
  multiplayer = {
    poaching = {
      not_interested = "Ha! Nemají zájem pro Vás pracovat - jsou spokojeni tam, kde jsou.",
      already_poached_by_someone = "To snad ne! Někdo se už snaží tuto osobu ukrást.",
      in_progress = "Dám vám vědět, zdali tato osoba bude chtít pro vás pracovat.",
    },
    everyone_failed = "Nikdo nedokázal splnit poslední úkol. Takže všichni hrají dál !",
    players_failed = "Následující hráč(i) nedokázal(i) splnit poslední úkol : ",
    objective_completed = "Naplnil jste cíl. Můžeme vám zatleskat!",
    objective_failed = "Nenaplnil jste cíl. Žádný potlesk.",
  },
  staff_place_advice = {
    only_doctors_in_room = "Pouze Doktoři mohou pracovat v %s.",
    only_nurses_in_room = "Pouze Sestry mohou pracovat v %s.",
    receptionists_only_at_desk = "Recepční mohou pracovat pouze na Recepci.",
    nurses_cannot_work_in_room = "Sestry nemohou pracovat v %s.",
    only_researchers = "Doktoři mohou ve Výzkumné Laboratoři zkoumat pouze pokud mají Výzkumnou odbornost.",
    only_surgeons = "Doktoři mohou na Operačním Sále operovat pouze pokud mají Chirurgickou odbornost.",
    only_psychiatrists = "Doktoři mohou na Psychiatrii pracovat pouze pokud mají Psychiatrickou odbornost.",
    doctors_cannot_work_in_room = "Doktoři nemohou pracovat v %s.",
  },
  tutorial = {
    start_tutorial = "Přečtěte si Úvod do Mise, pak klikněte levým tlačítkem myši ke spuštění výuky.",
    room_too_small_and_invalid = "Návrh je příliš malý a na neplatném místě. Tak jen do toho.",
    place_receptionist = "Přesuňte Recepční a umístěte ji kamkoliv. Za odměnu dojde ke svému stolu.",
    next_receptionist = "Toto je první Recepční v seznamu. Klikněte levým tlačítkem na blikající ikonku k zobrazení další dostupné.",
    build_reception = "Dobrý den. Nejdříve potřebuje Vaše nemocnice Recepci. Vyberte jednu z menu Položek Chodby.",
    accept_purchase = "Klikněte levým tlačítkem, abyste ji zakoupili.",
    window_in_invalid_position = "Toto okno je v neplatné pozici. Zkuste ho umístit někde jinde na zdi, pokud byste byli tak laskavi.",
    order_one_reception = "Klikněte jednou na blikající řádek levým tlačítkem myši k objednání jedné Recepce.",
    place_door = "Pohybujte myší okolo zdí návrhu, abyste umístili dveře tam, kam je chcete.",
    object_in_invalid_position = "Tato položka je v neplatné pozici. Prosím, buď ji umístěte někam jinam, nebo ji otočte tak, aby se vešla.",
    click_and_drag_to_build = "Pro vybudování kanceláře Praktického Lékaře si nejdříve musíte promyslet, jak bude velká. Klikněte a držte levé tlačítko, při držení Vaší místnosti, pro změnu velikosti.",
    doctor_in_invalid_position = "Hej! Zde Doktora dát nemůžete.",
    build_gps_office = "Abyste mohli začít vyšetřovat nemoci pacientů, musíte postavit kancelář praktického lékaře.",
    prev_receptionist = "Klikněte levým tlačítkem na blikající ikonu k zobrazení předchozí dostupné Recepční.",
    door_in_invalid_position = "Ah! Snažili jste se umístit dveře do neplatné polohy. Zkuste někde jinde na zdech návrhu.",
    room_big_enough = "Návrh je nyní dostatečně velký. Když uvolníte tlačítko myši, tak bude umístěna. Stále ji můžete přemisťovat, nebo měnit její velikost.",
    select_receptionists = "Klikněte levým tlačítkem na blikající ikonu, pro zobrazení, které Recepční jsou nyní k dispozici pro práci. To číslo na ikoně označuje, z kolika si musíte vybrat.",
    hire_doctor = "Potřebujete Doktora, který bude vyšetřovat a léčit nemocné lidi.",
    place_doctor = "Umístěte Doktora kdekoliv v nemocnici. Jakmile v kanceláři bude někdo k vyšetření, tak tam vyrazí.",
    choose_doctor = "Dobře se podívejte na dovednosti každého Doktora, než si jednoho zvolíte.",
    click_gps_office = "Klikněte levým tlačítkem na řádek pro vybrání kanceláře praktického lékaře.",
    choose_receptionist = "Rozhodněte, která Recepční má dobré dovednosti a spravedlivou mzdu, a pak klikněte levým tlačítkem na blikající ikonu, abyste ji zaměstnali.",
    hire_receptionist = "Budete také potřebovat Recepční, aby pacienty správně nasměrovala.",
    reception_invalid_position = "Recepce je zašedivělá protože je v neplatné pozici. Zkuste ji posunout nebo otočit.",
    rotate_and_place_reception = "Klikněte pravým tlačítkem myši k otočení Recepce a umístěte ji ve vaší nemocnici levým tlačítkem myši.",
    place_windows = "Okna umístěte stejným způsobem jako dveře. Okna sice nepotřebujete, ale vaši zaměstnanci jsou šťastnější, když se mají z čeho koukat ven. (Někteří ocení i když se na ně bude koukat někdo cizí.)",
    room_too_small = "Tento návrh místnosti je červený, protože je moc malý. Roztáhněte ho více, aby byl větší.",
    build_pharmacy = "Blahopřeji! Nyní vybudujte Lékárnu a zaměstnejte Sestru, abyste dostali fungující nemocnici.",
    room_in_invalid_position = "Jejda! Tento návrh je neplatný - červené oblasti označují, kde se překrývá s jinou místností nebo zdmi nemocnice.",
    select_doctors = "Klikněte levým tlačítkem na blikající ikonu, abyste se podívali na Doktory dostupné k zaměstnání.",
    place_objects = "Pravým tlačítkem otáčíte položky místnosti a levým tlačítkem je umisťujete.",
    receptionist_invalid_position = "Zde nemůžete Recepční umístit.",
    select_diagnosis_rooms = "Klikněte levým tlačítkem na blikající ikonu pro zobrazení seznamu dostupných diagnostických místností.",
    information_window = "Rámeček Nápovědy vám říká vše o té hezké kanceláři, kterou jste právě vybudovali.",
    confirm_room = "Klikněte levým tlačítkem na blikající ikonu k otevření vaší místnosti pro činnost, nebo klikněte na ikonku X, abyste šli o krok zpět.",
  },
  room_requirements = {
    op_need_two_surgeons = "Zaměstnejte dva Chirurgy k provádění operací na Operačním Sále.",
    op_need_ward = "Musíte vybudovat Lůžkové Oddělení k Předoperačnímu Vyšetření pacientů, než budou moci jít na zákrok.",
    research_room_need_researcher = "K použití Výzkumné Laboratoře musíte zaměstnat Doktora s Výzkumnou odborností.",
    training_room_need_consultant = "Musíte zaměstnat Konzultanta, který bude v Učebně učit.",
    pharmacy_need_nurse = "Pro tuto Lékárnu musíte zaměstnat Sestru.",
    reception_need_receptionist = "Musíte zaměstnat Recepční, jinak vám pacienti navždy zabloudí.",
    op_need_another_surgeon = "Stále musíte ještě zaměstnat jednoho Chirurga, aby Operační Sál mohl být použitelný.",
    psychiatry_need_psychiatrist = "Když jste nyní postavili Psychiatrii, musíte také zaměstnat Psychiatra.",
    ward_need_nurse = "Pro toto Lůžkové Oddělení musíte zaměstnat Sestru.",
    gps_office_need_doctor = "Potřebujete zaměstnat Doktora, aby v této kanceláři pracoval.",
  },
  research = {
    new_available = "Nový %s je dostupný.",
    drug_fully_researched = "%s jste vyzkoumali na 100%.",
    new_drug_researched = "Nový lék pro léčbu %s byl vynalezen.",
    drug_improved = "Lék na %s byl vylepšen vaší Výzkumnou Laboratoří.",
    autopsy_discovered_rep_loss = "Váš stroj Auto-Pitvy byl odhalen. Za to vás veřejnost odsoudí!",
    new_machine_researched = "Nový %s byl právě úspěšně vynalezen.",
    machine_improved = "%s byl vylepšen vaší Výzkumnou Laboratoří.",
    drug_improved_1 = "Lék %s byl vylepšen vaší Výzkumnou Laboratoří."
  },
  cheats = {
    th_cheat = "Blahopřejeme, právě jste odemkli cheaty!",
    roujin_off_cheat = "Roujinova výzva deaktivována.",
    roujin_on_cheat = "Roujinova výzva aktivována! Hodně štěstí…",
  },
  room_forbidden_non_reachable_parts = "Umístěním místnosti zde by zapříčinilo, že části nemocnice by byly nedostupné.",
  level_progress = {
    improve_reputation = "Potřebujete svoji reputaci zlepšit o %d, abyste vůbec měli šanci tuto úroveň vyhrát.",
    three_quarters_lost = "Jste na tři čtvrtě cesty k prohře v této úrovni.",
    another_patient_cured = "Výborně – další pacient vyléčen. To je teď %d.",
    three_quarters_won = "Jste na tři čtvrtě cesty k výhře této úrovně.",
    nearly_lost = "Dostáváte se velmi blízko k prohře této úrovně.",
    halfway_won = "Jste tak na půli cesty k výhře v této úrovni.",
    another_patient_killed = "Ale ne! Zabili jste dalšího pacienta. To teď dělá %d úmrtí.",
    dont_kill_more_patients = "Jste nemocnice, ne pohřebiště! Pokuste se nikoho už nezabít.",
    reputation_good_enough = "Krásně, vaše reputace je dost vysoká na výhru této úrovně. Udržujte ji nad %d a vyřešte jiné problémy, abyste mohli postoupit.",
    nearly_won = "Výhra této úrovně je vám na dosah.",
    hospital_value_enough = "Udržte hodnotu své nemocnice nad %d a věnujte se vašim ostatním problémům, abyste úroveň vyhráli.",
    close_to_win_increase_value = "Dostáváte se velmi blízko k výhře. Zvyšte hodnotu Vaší nemocnice o %d.",
    cured_enough_patients = "Sice jste vyléčili dostatek pacientů, ale budete muset udělat ve vaší nemocnici lepší pořádek, abyste úroveň vyhráli.",
    financial_criteria_met = "Splnili jste finanční kritéria pro tuto úroveň. Nyní udržujte vaši bilanci nad %d a zároveň se ujistěte, že vaše nemocnice dobře běží.",
    halfway_lost = "Jste na půl cesty k prohře v této úrovni.",
  },
  warnings = {
    litter_catastrophy = "Situace s odpadky je bezútěšná. Ať na tom hned začne pracovat tým Údržbářů!",
    financial_trouble = "Jste ve vážných finančních potížích. Hned si zorganizujte své finance! Pokud ztratíte dalších %d, tak zahodíte celou tuto úroveň!",
    need_toilets = "Pacienti potřebují toalety. Vybudujte je na snadno přístupném místě.",
    many_epidemics = "Vypadá to, že u vás propukla více než jedna epidemie najednou. To by mohla být obrovská katastrofa, takže s tím rychle něco dělejte.",
    need_staffroom = "Postavte Místnost pro Zaměstnance, aby si vaši zaměstnanci mohli kde odpočinout.",
    nobody_cured_last_month = "Minulý měsíc nebyl vůbec nikdo vyléčen. Opravdu jsme v léčebně?",
    charges_too_high = "Vaše poplatky jsou vysoké. Sice budete mít krátkodobě vysoké příjmy, ale později se lidé raději zvednou a odejdou k levnější konkurenci.",
    patient_stuck = "Někdo zabloudil, ani recepce mu nepomohla. Zkuste nestavět labirinty.",
    build_staffroom = "Okamžitě postavte Místnost pro Zaměstnance. Vaši zaměstnanci pracují příliš tvrdě a jsou na pokraji zhroucení. No tak - mějte rozum!",
    doctor_crazy_overwork = "Ale ne! Jeden z vašich Doktorů se kvůli přepracování zbláznil. Okamžitě mu dopřejte odpočinek, než bude pozdě!",
    machinery_very_damaged = "Naléhavé! Řekněte vašemu Údržbáři, aby okamžitě opravil vaše přístroje! Chystají se vybouchnout!",
    nurses_tired2 = "Vaše Sestry jsou velmi unavené. Dopřejte jim odpočinku.",
    patients_very_thirsty = "Pacienti trpí žízní. Pokud brzy neumístíte automaty na nápoje, budete čelit velkému odlivu pacientů do hospody vedle.",
    machinery_deteriorating = "Vaše přístroje začaly chátrat kvůli nadměrnému užívání. Hlídejte je, jinak je budete sbírat po kouskách.",
    machine_severely_damaged = "%s je velmi blízko k nenapravitelné škodě.",
    people_have_to_stand = "Trpící lid musí stát. Popřemýšlejte nad magickým lékem na stání.",
    machinery_damaged2 = "Musíte brzy zaměstnat Údržbáře, aby opravil vaše přístroje.",
    no_desk_3 = "Užíváte si klidu? Skoro rok a vy nemáte pracující recepci! Jak si myslíte, že vám sem budou chodit pacienti? Hned to vyřešte a přestaňte se flákat!",
    deal_with_epidemic_now = "Pokud se s touto epidemií brzo něco neprovede, budete až po čelo v průšvihu. Tak pohyb!",
    too_many_plants = "Máte příliš mnoho květin. Jsme v nemocnici, ne v džungli.",
    cannot_afford = "Vaším účtem tuto osobu opravdu k práci u vás nepřesvědčíte!",
    cannot_afford_2 = "To není drahé, jen vy nejste dost bohatí!",
    patients_thirsty = "Lidé začínají vysychat jako rozinky. Možná byste je mohl zavlažit automaty na nápoje.",
    machinery_slightly_damaged = "Vaše přístroje v nemocnici jsou lehce poškozené. Udržujte je v kondici, jinak jim něco rupne.",
    change_priorities_to_plants = "Musíte změnit priority vašich Údržbářů, jinak máte ze zeleně sušeň.",
    queue_too_long_send_doctor = "Vaše fronty %s jsou delší než na banány. Ujistěte se, že v místnosti je doktor.",
    too_much_litter = "Máte problém s odpadky. Údržbáři je třeba zvládnou uklidit.",
    place_plants_to_keep_people = "Lidé odchází. Umístěním kytiček je můžete přesvědčit, aby zůstali.",
    research_screen_open_1 = "Předtím, než můžete vstoupit na obrazovku výzkumu, musíte postavit Výzkumnou Laboratoř.",
    researcher_needs_desk_1 = "Výzkumník potřebuje pro práci svůj stůl.",
    researcher_needs_desk_2 = "Váš Výzkumník je potěšen vaší velkorysostí mu poskytnout přestávku při práci. Pokud jste zamýšleli, aby současně pracovalo více výzkumníků, musíte každému pořídit vlastní stůl pro práci.",
    researcher_needs_desk_3 = "Každý Výzkumník musí mít svůj vlastní pracovní stůl.",
    nurse_needs_desk_1 = "Každá Sestra potřebuje pro svoji práci vlastní stůl.",
    nurse_needs_desk_2 = "Vaše Sestra je přímo nadšená množstvím volna, které ji poskytujete. Pokud jste měli v úmyslu její začlenění do pracovního procesu, možná by se hodilo dát každé stůl z kterého mohou pracovat.",
    research_screen_open_2 = "Výzkum je v současné úrovni zakázán.",
    no_desk_1 = "Pokud chcete, aby lidé do vaší nemocnice chodili, budete muset najmout recepční a postavit ji recepci, kde může pracovat!",
    queue_too_long_at_reception = "Máte příliš mnoho pacientů čekajících na přidělení místnosti v recepci. Umístěte další Recepci a zaměstnejte další Recepční.",
    machines_falling_apart = "Vaše přístroje se začínají rozpadat. Okamžitě k nim pošlete Údržbáře s izolepou!",
    patients_too_hot = "Pacientům začíná být velké horko. Buď nějaké radiátory odstraňte, snižte teplotu nebo umístěte více automatů na nápoje.",
    staff_tired = "Vaši zaměstnanci začínají být pěkně unavení. Pokud je nenecháte trochu si odpočinout v Místnosti pro Zaměstnance, někteří by mohli pod tlakem zešílet.",
    cash_low_consider_loan = "Váš účet se blíží absolutní nule. Přemýšleli jste o půjčce?",
    patient_leaving = "Pacient odchází. Důvod? Vaše mizerně spravovaná a špatně zaměstnaná i vybavená nemocnice.",
    build_toilet_now = "Hned vybudujte toaletu, jinak to lidé nevydrží. Nesmějte se - jinak vás ten smích rychle přejde.",
    epidemic_getting_serious = "Ta Nakažlivá Choroba se stává vážnou. Musíte brzo něco udělat!",
    money_very_low_take_loan = "Výše vašeho účtu za chvilku překoná Mariánský příkop. Mohli byste si vzít půjčku, víte.",
    more_benches = "Promyslete si umístění více laviček. Nemocní lidé nenávidí, když musejí stát.",
    some_litter = "Více údržbářů by se mohlo zbavit odpadků dříve, než se tady z toho stane skládka.",
    patients_very_cold = "Pacienti se mění v kostky ledu. Zkuste zvýšit teplotu vytápění nebo umístěte více radiátorů ve vaší nemocnici.",
    receptionists_tired2 = "Vaše Recepční jsou velmi vyčerpané. Hned je nechte odpočinout.",
    patients_getting_hot = "Pacienti se začínají vypařovat. Zkuste snížit vytápění nebo odstraňte některé radiátory.",
    people_did_it_on_the_floor = "Někteří pacienti to už nezvládli. Čištění bude pro někoho velká práce.",
    patients_really_thirsty = "Vaše nemocnice připomíná Saharu. Umístěte více automatů na nápoje nebo přemístěte existující blízko k největším frontám.",
    doctors_tired = "Vaši Doktoři téměř usínají při práci. Hned je nechte odpočinout.",
    financial_trouble3 = "Vaše bankovní bilance vypadá lehce znepokojivě. Přemýšlejte, kde se dá něco přivydělat. Ke katastrofě vám zbývá jen %d.",
    handymen_tired2 = "Vaši Údržbáři jsou naprosto zničení. Dopřejte jim odpočinek, nebo se rozsypou… a vaše přístroje s nimi.",
    no_desk_2 = "Výborně, to musí být světový rekord: skoro rok a žádní pacienti! Pokud chcete pokračovat jako správce této nemocnice, budete muset najmout recepční a postavit recepci odkud může pracovat!",
    patients_thirsty2 = "V nemocnici jsou lidé, ne kaktusy. Měli byste umístit další automaty na nápoje nebo existující přesunout blíže k lidem.",
    people_freezing = "Neuvěřitelné, i přes objev ohně a plynu někteří vaši pacienti mrznou zimou. Postavte radiátory, aby jim bylo tepleji, a zvyšte vytápění.",
    staff_too_hot = "Vaši zaměstnanci se přehřívají. Snižte teplotu nebo odstraňte radiátory z jejich místností.",
    staff_unhappy2 = "Vaši zaměstnanci jsou celkově nešťastní. To vás přijde na odměnách draho.",
    charges_too_low = "Účtujete si příliš málo. Sice to přinese více lidí do nemocnice, ale z každého nebudete mít moc velký výdělek.",
    staff_very_cold = "Zaměstnanci si stěžují na zimu. Zvyšte teplotu vytápění nebo umístěte více radiátorů.",
    place_plants4 = "Utěšte pacienty pomocí více zeleně v prostředí.",
    nurses_tired = "Vaše sestry jsou unavené. Dopřejte jim klidu.",
    bankruptcy_imminent = "Hej! Ještě chvilka a bankrotujete! Nechcete něco změnit?",
    handymen_tired = "Vaši Údržbáři jsou unavení. Pusťte je chvilku na gauč.",
    finanical_trouble2 = "Zařiďte, aby vám přicházely peníze, jinak budete švorc. Úroveň prohrajete, jestli přijdete o dalších %d.",
    desperate_need_for_watering = "Zoufale potřebujete zaměstnat Údržbáře, aby se staral o vaše rostliny.",
    machinery_damaged = "Hned opravte vaše přístroje. inak zanedlouho nebudete mít co spravovat.",
    many_killed = "Nyní jste zabili %d lidí. Víte, že jste nemocnice, ne jatka.",
    litter_everywhere = "Všude jsou odpadky. Pošlete na tento problém hejno Údržbářů.",
    falling_3 = "Au, to muselo bolet, zavolejte někdo doktora!",
    no_patients_last_month = "Minulý měsíc nepřišli do vaší nemocnice žádní noví pacienti. Já jen, že bez nich nemocnice ztrácí význam.",
    receptionists_tired = "Vaše Recepční jsou vážně unavené. Nechte je také někdy vyklouznout zpoza recepcí.",
    falling_5 = "Toto není místo pro srážení lidí, přece víte, že jsou nemocní!",
    falling_2 = "Přestaňte si zahrávat, jak by se to líbilo vám?",
    falling_1 = "Hej! Tohle není sranda, dívejte se, kam s tou myší klikáte; mohli byste někoho zranit!",
    falling_6 = "Toto není kuželník, s nemocnými lidmi by se takto nemělo zacházet!",
    more_toilets = "Potřebujete více toalet. Jinak zanedlouho budete muset objednávat plenky.",
    falling_4 = "Tohle je nemocnice, ne Theme Park!",
    plants_thirsty = "Starejte se i o vaše rostliny. Nejsou umělé, potřebují nějakou vodu.",
    doctors_tired2 = "Vaši Doktoři jsou neuvěřitelně unavení. Potřebují okamžitý odpočinek, jinak je ani polibek neprobudí.",
    staff_overworked = "Vaši zaměstnanci jsou strašně přepracovaní. Stávají se neschopnými a začnou dělat katastrofické chyby.",
    patients_annoyed = "Lidé jsou strašně naštvaní na způsob, jak vedete nemocnici. A já se jim nemůžu divit. Vzpamatujte se, nebo čelte následkům!",
    hospital_is_rubbish = "Lidé otevřeně říkají, že vaše nemocnice je příšerná. Než se nadáte, vezmou si svoje nemoci jinam.",
    pay_back_loan = "Máte peněz jako šlupek. Co takhle pomyslet na splacení půjčky?",
    plants_dying = "Vaše rostliny umírají. Voda je pro ně snad cizí slovo. Ať na tom pracuje více Údržbářů, pacienti nemají rádi suché listí.",
    patients_unhappy = "Pacienti nemají rádi vaši nemocnici. Měli byste něco udělat pro zlepšení jejich prostředí.",
    queues_too_long = "Během čekání ve frontě lze zkouknout celou Ulici. Co třeba postavit více místností?",
    place_plants2 = "Lidé prchají. Trochu více rostlin by je mohlo třeba déle udržet.",
    patients_leaving = "Pacienti odcházejí. Zlepšete nemocnici pro vaše návštěvníky umístěním rostlin, laviček, automatů na nápoje a tak dále.",
    money_low = "Peněžní odpočet tiká na druhou stranu, než by měl!",
    reception_bottleneck = "Na Recepci je zácpa. Zaměstnejte další Recepční.",
    no_desk = "V určité fázi byste měli vybudovat recepci a najmout recepční!",
    staff_unhappy = "Vaši zaměstnanci jsou nešťastní. Zkuste jim dát prémie, nebo ještě lépe, postavte jim Místnost pro Zaměstnance. Také byste mohli změnit zásady odpočinku vašich zaměstnanců na obrazovce Zásady.",
    reduce_staff_rest_threshold = "Zkuste snížit práh Odpočinku Zaměstnanců ve vaší obrazovce Zásad tak, aby vaši zaměstnanci častěji odpočívali. Jen takový nápad.",
    place_plants3 = "Pacienti začínají být nešťastní. Umístěte více rostlin, abyste je utěšili.",
    build_toilets = "Hned teď vybudujte Toaletu nebo uvidíte něco velmi nepěkného. A představte si, jak vaše nemocnice bude smrdět.",
    no_desk_4 = "Recepční potřebuje svoji vlastní pracovní stanici, kde bude vítat pacienty při jejich příchodu.",
    no_desk_5 = "No už bylo načase, za chvíli by vám měli začít přicházet pacienti!",
    no_desk_6 = "Recepční máte, tak co kdybyste jí postavili recepci, kde by mohla začít pracovat?",
    no_desk_7 = "Recepci jste postavili, a teď jenom najmout recepční. Bez ní se ve vaší nemocnici nevyznáte ani vy!",
    another_desk = "Musíte postavit Recepci pro svou Recepční.",
    low_prices = "Účtujete si málo za %s. Tím sice do nemocnice nalákáte hodně pacientů, ale moc z nich nevyděláte.",
    high_prices = "Za %s si účtujete moc vysokou částku. Sice tím vyděláte z pacientů více, ale oni raději přejdou ke konkurenci.",
    patient_not_paying = "Pacient odešel bez zaplacení %s, protože je to moc drahé!",
    fair_prices = "Vaše částka za %s vypadá přijatelně a vyváženě.",
  },
  earthquake = {
    ended = "Uf. Myslel jsem si, že tento byl Velký Třesk - Byl %d stupně na Richterově škále.",
    damage = "Toto zemětřesení poškodilo %d přístrojů a %d lidí v nemocnici.",
    alert = "Varování o zemětřesení. Během zemětřesení budou vaše přístroje poškozeny. A pokud se o ně nestaráte, máte oslavu i s ohňostrojem.",
  },
  staff_advice = {
    need_handyman_plants = "Budete muset zaměstnat Údržbáře, aby zaléval květiny.",
    need_doctors = "Potřebujete více Doktorů. Zkuste vaše nejlepší Doktory umístit do místností s dlouhými frontami.",
    need_handyman_litter = "Lidé začali dělat ve vaší nemocnici nepořádek. Zaměstnejte Údržbáře, aby po nich uklízel.",
    too_many_doctors = "Máte příliš mnoho Doktorů. Někteří v současnosti nemají nic na práci.",
    need_handyman_machines = "Pokud budete chtít udržovat přístroje ve vaší nemocnici, musíte zaměstnat Údržbáře.",
    need_nurses = "Musíte zaměstnat více Sester. Lůžková Oddělení a Lékárny potřebují Sestru.",
    too_many_nurses = "Myslím, že v současnosti zaměstnáváte příliš mnoho Sester.",
  },
  vomit_wave = {
    started = "Rozmohl se nám tady takový nešvar… Epidemie zvracení. Možná by pomohlo, kdybyste najal více Údržbářů, nemocnice poté nebude zatouchat.",
    ended = "Uf! Vypadá to, že jste tu pouklízeli. Lidem již není ze smrádku nevolno. Do budoucna udržujte vaši nemocnici čistou.",
  },
  epidemic = {
    multiple_epidemies = "Vypadá to, že u vás propukla více než jedna epidemie najednou. To by mohla být obrovská katastrofa, takže s tím rychle něco dělejte.",
    serious_warning = "Ta Nakažlivá Choroba se stává vážnou. Musíte brzo něco udělat!",
    hurry_up = "Pokud se s touto epidemií brzo něco neprovede, budete až po oči v průšvihu. Tak pohyb!",
  },
  boiler_issue = {
    resolved = "Dobré zprávy. Bojler a radiátory nyní už zase správně fungují. Během chvilky budou lidé v nemocnici zase ve správném skupenství.",
    maximum_heat = "Bojler ve sklepě se zbláznil. Teplo radiátorů se zaseklo na maximu. Lidi začnou tát! Umístění více automatů na nápoje by pomohlo.",
    minimum_heat = "Ah, tady jste. Bojler ve sklepě je rozbitý. Vypadá to, že lidem ve vaší nemocnici budou za chvilku drkotat zuby.",
  },
}
staff_descriptions = {
  good = {
    [1] = "Velmi rychlý a pilný pracovník. ",
    [2] = "Velmi svědomitý. Velký detailista. ",
    [3] = "Má široký rozsah dovedností. ",
    [4] = "Velmi přátelský a rád se směje. ",
    [5] = "Úžasná výdrž. Prostě pořád jede. ",
    [6] = "Pozoruhodně slušný, chová se vlídně. ",
    [7] = "Neuvěřitelně talentovaný a schopný. ",
    [8] = "Hodně mu záleží na práci, kterou dělá. ",
    [9] = "Je puntičkář, který se prostě nevzdává. ",
    [10] = "Nadšeně pomáhá lidem s úsměvem. ",
    [11] = "Půvabný, slušný a nápomocný. ",
    [12] = "Obecně dobře motivovaný a oddaný. ",
    [13] = "Dobrosrdečný a velmi těžce pracující. ",
    [14] = "Oddaný a přátelský. ",
    [15] = "Pečlivý a spolehlivý v nouzových situacích. ",
  },
  bad = {
    [1] = "Pomalý a malicherný. ",
    [2] = "Lenoch a špatně motivovaný. ",
    [3] = "Špatně vyučen a neschopný. ",
    [4] = "Drzý a neomalený. Leze lidem na nervy. ",
    [5] = "Hrozná výdrž - má špatný přístup. ",
    [6] = "Hluchý jako poleno. Je slabě cítit zelím. ",
    [7] = "Při práci je k ničemu. Možná přítěž. ",
    [8] = "Zbrklý a snadno rozptýlitelný. ",
    [9] = "Stresovaný a náchylný k chybám. ",
    [10] = "Zvrácený a zlý - spalován nenávistí. ",
    [11] = "Neopatrný a náchylný k nehodám. ",
    [12] = "Práce ho nezajímá. Líná veš. ",
    [13] = "Pošetile riskuje, je mu to úplně jedno. ",
    [14] = "Lstivý, prohnaný a podvratný. ",
    [15] = "Arogantní a nafoukaný. ",
  },
  misc = {
    [1] = "Sbírá figurky slonů. ",
    [2] = "Chodí se potápět. ",
    [3] = "Dělá sochy z ledu. ",
    [4] = "Objevil se v jednom dílu Neváhej a toč! ",
    [5] = "Jezdí v závodních autech. ",
    [6] = "Skáče bungee-jumping. ",
    [7] = "Sbírá pivní tácky. ",
    [8] = "Má rád skákání z pódia. ",
    [9] = "Rád surfuje pomocí prdění. ",
    [10] = "Užívá si rozšiřování řek. ",
    [11] = "Destiluje whisky. ",
    [12] = "Zkušený kutil. ",
    [13] = "Má rád Francouzské nezávislé filmy. ",
    [14] = "Hodně hraje Theme Park. ",
    [15] = "Má řidičák pro náklaďáky. ",
    [16] = "Chodí závodit na motorkách. ",
    [17] = "Hraje na klasické housle a violoncello. ",
    [18] = "Zanícený lupič vraků vlaků. ",
    [19] = "Milovník psů. ",
    [20] = "Zpívá si ve sprše. ",
    [21] = "Často se koupe v kašně. ",
    [22] = "Instruktor pro ruční práce s rafií. ",
    [23] = "Vydlabává zeleninu a používá ji jako držáky na mýdlo. ",
    [24] = "Zvláštní policejní komisař na částečný úvazek. ",
    [25] = "Bývalý moderátor kvizového pořadu. ",
    [26] = "Sbírá šrapnely z 2. světové války. ",
    [27] = "Přemisťuje nábytek. ",
    [28] = "Poslouchá rave a trip-hop. ",
    [29] = "Rozčiluje hmyz deodorantem ve spreji. ",
    [30] = "Pokřikuje na špatné komiky. ",
    [31] = "Špehuje pro obecní úřad. ",
    [32] = "Nenápadný zahradník. ",
    [33] = "Pašuje falešné hodinky. ",
    [34] = "Zpívá v rock&rollové skupině. ",
    [35] = "Uctívá denní televizní vysílání. ",
    [36] = "Lechtá pstruhy. ",
    [37] = "Láká turisty v muzeu. ",
  },
}
load_game_window = {
  caption = "Načíst Hru (%1%)",
}
menu_options_game_speed = {
  slowest = "    (%1%) NEJPOMALEJŠÍ  ",
  slower = "    (%1%) POMALEJŠÍ  ",
  pause = "    (%1%) POZASTAVENO  ",
  normal = "    (%1%) NORMÁLNÍ  ",
  max_speed = "    (%1%) MAX RYCHLOST  ",
  and_then_some_more = "    (%1%) A JEŠTĚ TROCHU NAVÍC ",
}
humanoid_name_starts = {
  [1] = "ZLATO",
  [2] = "VYSO",
  [3] = "ŽŮŽ",
  [4] = "JOS",
  [5] = "BOŘ",
  [6] = "JAKUB",
  [7] = "RA",
  [8] = "PAV",
  [9] = "POD",
  [10] = "KRÁL",
  [11] = "BAR",
  [12] = "ZVÍ",
  [13] = "ČLO",
  [14] = "KLUK",
  [15] = "VAL",
  [16] = "MAR",
  [17] = "KRAB",
  [18] = "RYBA",
  [19] = "VODA",
  [20] = "MIL",
  [21] = "MI",
  [22] = "FER",
  [23] = "BOHAT",
  [24] = "SKOT",
  [25] = "BUŘ",
  [26] = "HROT",
  [27] = "CUK",
  [28] = "BÍL",
  [29] = "KAR",
  [30] = "BŘE",
  [31] = "POD",
  [32] = "SPRÁVN",
  [33] = "KEŘ",
}
trophy_room = {
  rats_accuracy = {
    trophies = {
      [1] = "Je Vám udělen Pohár Syndicate Wars Přesnosti ve Střílení za to, že jste měli %d%% přesnost při střílení krys.",
      [2] = "Tento pohár připomíná Vaši neuvěřitelnou přesnost při zabití %d%% krys, na které jste ve Vaší nemocnici mířili v posledním roce.",
      [3] = "Na oslavu události Vašeho zabití %d%% všech krys ve Vaší nemocnici, je Vám udělen Pohár Dungeon Keeper Havěti Zbavený. Blahokrysujeme!",
    },
  },
  happy_staff = {
   regional_bad = {
      [1] = "Všichni Vaši zaměstnanci byli minulý rok velmi nešťastní. Měli jste si toho všimnout. Tak jak je to teď mají všechny ostatní nemocnice zaměstnance šťastnější než Vy.",
    },
    awards = {
      [1] = "Vaši zaměstnanci Vám udělují tuto cenu. Říkají, že i když je co zlepšovat, zacházeli jste s nimi vcelku dobře.",
      [2] = "Vaši zaměstnanci pro Vás tak rádi pracují, že se nemůžou přestat smát. Jste výborný správce.",
    },
    regional_good = {
      [1] = "Vaši zaměstnanci jsou šťastnější než ti v ostatních nemocnicích. Šťastní zaměstnanci přinášejí více výdělku a méně úmrtí. Ministerstvo je potěšeno.",
    },
    penalty = {
      [1] = "Vaši zaměstnanci chtějí, aby se vědělo, že jsou velmi nešťastní. Spokojení zaměstnanci jsou přínosem. Udělejte je šťastnějšími nebo je jednoho dne ztratit.",
    },
    trophies = {
      [1] = "Je Vám udělen Pohár Chechtáka za udržení radosti Vašich pracovitých zaměstnanců tak, jak to jen jde.",
      [2] = "Adami Institut Radosti Vás oceňuje za to, že jste Ve vaší nemocnici neměli minulý rok žádné nešťastné zaměstnance, tím že Vám uděluje tento pohár.",
      [3] = "Toto ocenění, Pohár Více Úsměvů je Vám slavnostně udělen za to, že jste Vaše zaměstnance udrželi šťastné nad rámec Vašich povinností během minulého roku. Úsměvy všude kolem!",
    },
  },
  happy_patients = {
    penalty = {
      [1] = "Lidé přicházející do nemocnice mají otřesné zážitky. Pokud si chcete vysloužit respekt ministerstva, budete se muset mnohem více snažit.",
      [2] = "Lidé, dostávající ve Vaši nemocnici léčbu, jsou velmi nespokojeni se stavem tohoto místa. Blaho pacientů byste měli důkladněji zvážit.",
    },
    awards = {
      [1] = "Můžete se dmout pýchou nad tím, že lidé v předchozím roce byly ve Vaší nemocnici velmi šťastní.",
      [2] = "Lidé navštěvující Vaši nemocnici byly během jejich léčby v průměru šťastnější než v kterékoliv jiné nemocnici ve hře.",
    },
  },
  happy_vips = {
    trophies = {
      [1] = "Vyhráli jste Nobelovu cenu za zapůsobení na VIP. Každý, kdo v minulém navštívil Vaší nemocnici, o ní pěl jen samou chválu.",
      [2] = "Agentura Slavných Lidí by Vám chtěla darovat Pohár Celebrity za potěšení těch, kteří navštívili Vaše zařízení. Považujte se za mírně slavného a skoro jednoho z nás.",
      [3] = "Blahopřejeme Vám k získání ocenění VÝLET VIP za ulehčení života těžce pracujících osobností v oku veřejnosti uspokojením těch, co Vaši nemocnici navštívili. To je výtečné.",
    },
  },
    pop_percentage = {
    penalty = {
      [1] = "Poznamenejte si, že jste v předchozím roce získali vysoký podíl obyvatel ve Vaší nemocnici města. Výborně.",
      [2] = "Blahopřejeme. Vaší nemocnici navštěvuje vyšší podíl místních obyvatel města než kterékoli jiné zařízení.",
    },
    awards = {
      [1] = "Poznamenejte si, že jste získali vysoký podíl obyvatel města ve Vaší nemocnici v minulém roce. Výborně.",
      [2] = "Blahopřejeme. Vaši nemocnici navštěvuje vyšší podíl místní populace, než jakoukoli jinou instituci.",
      [3] = "Úžasné. Do Vaší nemocnice jste nalákali více obyvatel, než navštívilo všechny nemocnice dohromady.",
    },
  },
  rats_killed = {
    awards = {
    },
    trophies = {
      [1] = "Byl Vám udělen Pohár Proti Havěti za zastřelení %d krys ve Vaší nemocnici během minulého roku.",
      [2] = "Díky Vaším výjimečným schopnostem střílení krys jste se kvalifikovali na získání tohoto poháru od Federace Proti Krysám a Myším, při zabití %d potvor.",
      [3] = "Kvalifikovali jste se na Pohár Odstřelení Krys za výjimečné dovednosti při zbavení %d krys ve Vaší nemocnici v minulém roce.",
    },
  },
  no_deaths = {
    awards = {
      [1] = "Obdrželi jste Ocenění Nikdo-Nechcíp za udržení 100 procent živých pacientů v posledním roce.",
      [2] = "Toto ocenění jste obdrželi, aby Vám připomnělo nízký počet úmrtí ve Vaší nemocnici tento rok. To je skvělé.",
    },
    trophies = {
      [1] = "Společnost Život Jde Dál Vám uděluje tento pohár za zabránění jakéhokoli úmrtí v posledním roce.",
      [2] = "Byl Vám udělen Pohár Zůstávám Naživu, že jste zvládli se vyhnout všech možných úmrtí v posledním roce ve Vaši nemocnici. Skvělé.",
      [3] = "Byla Vám udělena trofej Zůstávám Naživu za to, že jste dokázali v tomto roce zabránit jakémukoliv úmrtí ve Vaši skvělé nemocnici. Výborně.",
    },
        penalty = {
      [1] = "Počet smrtí Ve Vaší nemocnici byl v minulém roce na přijatelné výši. Věnujte větší pozornost Vaší práci. V budoucnu zajistěte, ať více lidí přežije.",
      [2] = "Vaše nemocnice je rizikem pro zdraví pacientů. Očekává se, že hodně lidí vyléčíte a ne, že je zahubíte.",
    },
    regional = {
      [1] = "Počet smrtí ve Vaší nemocnici byl minulý rok nižší než v ostatních nemocnicích. Přijměte prosím tuto cenu.",
    },
  },
  healthy_plants = {
    awards = {
      [1] = "Blahopřejeme k získání ocenění Hnojiva Rosť Více za udržení neobyčejného zdraví Vašich rostlin během minulého roku.",
    },
    trophies = {
      [1] = "Přátelé Pokojových Rostlin si přejí Vám udělit Zelený Pohár Zdraví za udržení všech Vašich kytek v dobrém stavu během posledních dvanácti měsíců.",
      [2] = "Senza Trifidi by Vám chtěli udělit Pohár Zelenéhoprstu za udržení Vašich rostlin v nemocnici v tom nejlepším možném stavu během posledního roku.",
    },
  },
  many_cured = {
    awards = {
      [1] = "Gratulujeme za vyléčení mnoha pacientů v minulém roce. Díky Vaší práci se mnoho lidí cítí dobře.",
      [2] = "Přijměte prosím toto ocenění za vyléčené více pacientů než kterákoli jiná nemocnice. Ryzí výkon.",
    },
    penalty = {
      [1] = "Vaše nemocnice selhává v poskytnutí účinné léčby pacientům, kteří ji potřebují. Soustřeďte se na Vaše léčby, abyste zvýšili jejich účinnost.",
      [2] = "Vaše nemocnice je méně účinná při ošetřovaní pacientů, než kterákoliv jiná. Zklamali jste ministerstvo a zklamali jste sebe. To je vše, co jsme chtěli říct.",
    },
    regional ={
      [1] = "Slavnostně Vám udělujeme cenu Všemocného léku za vyléčení více lidí, než všechny ostatní nemocnice dohromady.",
    },
    trophies = {
      [1] = "Gratulujeme k výhře Ocenění Marie Curie za úspěšné vyléčení skoro všech pacientů ve Vaší nemocnici v minulém roce.",
      [2] = "Mezinárodní Nadace Léčení si přeje ocenit skutečnost, že jste vyléčili ohromný počet lidí ve Vaší nemocnici minulý rok tím, že Vám udělí pohár Hodně-Léčíš-Někde.",
      [3] = "Byl Vám darován pohár Žádný Nemocný Řiťolezec za úspěšnou léčbu vysokého procenta pacientů ve Vaši nemocnici v minulém roce.",
    },
  },
  sold_drinks = {
    trophies = {
      [1] = "Světová Asociace Zubařů je hrdá, že Vás může ocenit touto cenou a plaketou za prodej spousty konzervovaných nápojů ve Vaší nemocnici.",
      [2] = "Vaše nemocnice byla oceněna Pohárem Šumivý Byznys za Prodej Nealkoholických Nápojů při uznání počtu nápojů prodaných ve Vaší nemocnici za poslední rok.",
      [3] = "Jménem DK Plomby a.s., je Vám udělena tato čokoládou pokrytý Pohár na oslavu neobyčejného počtu prodaných nealkoholických nápojů ve Vaší nemocnici tento rok.",
    },
  },
  gen_repairs = {
     penalty = {
      [1] = "Vaši údržbáři moc dobře Vaše stroje neudržovali. Měli byste na ně dohlédnout pečlivěji, nebo jich najmout více, aby byli schopni množství práce pojmout.",
      [2] = "Z údržby máte nepořádek. Vaši zaměstnanci by se o stroje měli starat jako o svoje vlastní.",
     },
     awards = {
      [1] = "Obdrželi jste zvláštní ocenění za pohotovost Vašich údržbářů, kteří udržují stroje Vaší nemocnice v dobrém stavu. Skvělé. Můžete si vzít dovolenou.",
      [2] = "Vaši údržbáři si vedli lépe než ti v ostatních nemocnicích. Toto je obrovský úspěch, za který je Vám poblahopřáno.",
      [3] = "Vaše stroje jsou skvěle udržované. Oddanost Vašich údržbářů je výjimečná. Vy všichni si toto prestižní ocenění zasloužíte. Výtečná práce.",
     },
  },
  research = {
     regional_good = {
      [1] = "Výzkum Vaší nemocnice udržel krok s nejnovějšími poznatky. Vaši výzkumní zaměstnanci si tuto cenu zaslouží. Skvělé.",
     },
     regional_bad = {
      [1] = "Všechny nemocnice v okolí mají lepší výzkum než Vy. Ministerstvo je rozčílené, protože výzkum by ve Vaší nemocnici měl být velmi důležitý.",
     },
     penalty = {
      [1] = "Ve výzkumu nové léčby, vybavení a léků jste zaostali. To je velmi špatné, protože technologický pokrok je nezbytný.",
     },
     awards = {
      [1] = "Výzkum Vaší nemocnice udržel krok s nejnovějšími poznatky. Vaši výzkumní zaměstnanci si tuto cenu zaslouží. Skvělé.",
      [2] = "Během posledního roku jste prozkoumali více léků a zařízení, než kdokoliv mohl doufat. Prosím přijměte toto ocenění od nás všech na ministerstvu.",
     },
  },
    curesvdeaths = {
    penalty = {
      [1] = "Váš poměr vyléčení k úmrtím je opravdu špatný. Měli byste zajistit, že vyléčíte mnohem více lidí, než necháte zemřít. Nebuďte naší ostudou.",
    },
    awards = {
      [1] = "Vydatné gratulace za dosažení úchvatného poměru vyléčení k úmrtím ve Vaší nemocnici minulý rok.",
    },
  },
  emergencies = {
    regional_good = {
      [1] = "Ministerstvo uznává, že Vaše nemocnice zvládla předešlý rok mimořádné události lépe než kterákoliv jiná nemocnice a uděluje Vám toto ocenění.",
    },
    award = {
      [1] = "Blahopřejeme: Vaše efektivní a účinné zvládnutí mimořádných událostí Vám získaly toto zvláštní ocenění. Dobrá práce.",
      [2] = "Vaše zacházení s mimořádnými událostmi je výjimečné. Toto ocenění je za to, že jste nejlepší ve zvládání velkých návalů nemocných a trpících.",
    },
    penalty = {
      [1] = "Mimořádné situace moc nezvládáte. Přicházející pacienti pohotovosti vyžadují rychlou a správnou pozornost, kterou jste nedokázali poskytnout.",
    },
    regional_bad = {
      [1] = "Vaše nemocnice je ve zvládání mimořádných událostí ta nejhorší v oblasti. Je Vaší chybou, že se potácíte na konci místní ligy ošetření v mimořádných situacích.",
    },
  },
  all_cured = {
    awards = {
      [1] = "Blahopřejeme k vítězství Ocenění Marie Curie za úspěšnou léčbu všech pacientů ve Vaší nemocnici za poslední rok.",
    },
    trophies = {
      [1] = "Mezinárodní Nadace Léčení si přeje ocenit skutečnost, že jste vyléčili všechny ve Vaší minulý rok tím, že Vám udělí pohár Hodně-Léčíš-Někde.",
      [2] = "Byl Vám darován pohár Žádný Nemocný Řiťolezec za úspěšnou léčbu všech pacientů ve Vaší nemocnici v minulém roce.",
    },
  },
    best_value_hosp = {
    regional = {
      [1] = "Blahopřejeme Vám za nejcennější nemocnici ve hře. Dobrá práce. Snažte se prosím takto pokračovat.",
    },
    penalty = {
      [1] = "Každá nemocnice v oblasti má větší hodnotu než ta Vaše. Udělejte něco s touto ostudnou situací. Dejte sem nějaké drahé věci!",
    },
    trophies = {
      [1] = "Blahopřejeme k získání ocenění Zlaté Truhlice za nemocnici s nejvyšší hodnotou během minulého roku. Ovšemže je plně zasloužená.",
    },
  },
  high_rep = {
    penalty = {
      [1] = "Za velmi špatnou reputaci za poslední rok vás trest nemine. Ujistěte se, že se to do budoucna zlepší.",
      [2] = "Reputace Vaší nemocnice je nejhorší v oblasti. Jaká ostuda! Zlepšete ji, nebo si hledejte jinou práci.",
    },
    regional = {
      [1] = "Přijměte prosím Cenu Bullfrog za nejvyšší reputaci v tomto roce ze všech nemocnic. Užijte si to - zasloužili jste si ji.",
      [2] = "Tento rok reputace Vaší nemocnice překonala všechny ostatní v oblasti dohromady. To je významný úspěch.",
    },
    awards = {
      [1] = "Výborně. Vyhráváte maličké ocenění za dosažení velmi úctyhodné reputace v posledním roce.",
      [2] = "Úžasné! Vaše nemocnice vyhrává cenu za vybudování nejlepší reputace za poslední rok.",
    },
    },
  cash = "PENÍZE",
  reputation = "REPUTACE",
    consistant_rep = {
    trophies = {
      [1] = "Tímto se Vám slavnostně uděluje ocenění Kabinetu Ministra za dokonalé standardy a nejvyšší možnou reputaci tento rok. Úžasné.",
      [2] = "Blahopřejeme k získání ocenění Křišťálová Lilie za nemocnici s nejlepší reputací během minulého roku. Potřeba dodat, že si jej zasloužíte.",
  },
  },
  wait_times = {
    penalty = {
      [1] = "Lidé ve Vaší nemocnici musí dlouho čekat. Fronty jsou zde delší než na podpultové zboží. Kdybyste se více snažili, mohli by se vaši pacienti léčit účinněji.",
    },
    award = {
      [1] = "Gratulujeme. Ve vaší nemocnici se nestojí žádné dlouhé fronty. Toto je důležité ocenění.",
    },
  },
  cleanliness = {
    regional_good = {
      [1] = "Vaše nemocnice byla vyhodnocena jako jedna z nejčistších široko daleko. Vaši údržbáři si zaslouží prémie. A vy za jejich výcvik také.",
    },
    award = {
      [1] = "Kontroloři si poznamenali, že Vaše nemocnice je velmi čistá. Čisté nemocnice jsou bezpečné nemocnice. Jen tak dál.",
    },
    regional_bad = {
      [1] = "Vaše nemocnice je nejšpinavější v oblasti. Ostatní správci zvládli udržet svoje chodby čistší. Jste hanbou zdravotnické profese.",
    },
  },
  hosp_value = {
    penalty = {
      [1] = "Vaší nemocnici se nepodařilo dosáhnout slušné hodnoty. Provedli jste špatná rozhodnutí s penězi. Nezapomeňte, že dobrá nemocnice je také drahá nemocnice.",
    },
    regional = {
      [1] = "Jste zázračné dítě přes finance. Vaše nemocnice má větší hodnotu než všechny ostatní nemocnice v oblasti dohromady.",
    },
    awards = {
      [1] = "Ministerstvo zdravotnictví by chtělo využít této příležitosti a poblahopřát Vám k působivé celkové hodnotě Vaší nemocnice.",
    },
  },
}
build_room_window = {
  pick_room_type = "Vyberte typ místnosti",
  pick_department = "Vyberte oddělení",
  cost = "Náklady: ",
}
object = {
  dna_fixer = "Genex 2000",
  op_sink1 = "Umyvadlo",
  litter_bomb = "Odpadková Bomba",
  auto_autopsy = "Auto-Pitvač",
  door = "Dveře",
  projector = "Projektor",
  radiation_shield = "Radiační Štít",
  entrance_left = "Vchodové Levé Dveře",
  operating_table = "Operační Stůl",
  bed2 = "Postel",
  cabinet = "Kartotéka",
  console = "Konzole",
  bed = "Postel",
  couch = "Sedačka",
  drinks_machine = "Automat na Nápoje",
  shower = "Sprcha",
  electrolyser = "Elektrolyzér",
  table2 = "Stůl",
  radiator = "Radiátor",
  chair = "Sedačka",
  jelly_moulder = "Forma na Sliz",
  computer = "Počítač",
  ultrascanner = "Ultraskener",
  bin = "Koš",
  surgeon_screen = "Zástěna Chirurga",
  slicer = "Kráječ",
  bed3 = "Postel",
  x_ray = "Rentgen",
  video_game = "Video Hra",
  atom_analyser = "Analyzátor Atomů",
  inflator = "Nafukovač",
  toilet = "Toaleta",
  x_ray_viewer = "Prohlížeč Rentgenových Snímků",
  cast_remover = "Odstraňovač Sádry",
  entrance_right = "Vchodové Pravé Dveře",
  litter = "Odpadek",
  cardio = "Kardiogram",
  plant = "Rostlina",
  pool_table = "Kulečníkový Stůl",
  tv = "Televize",
  sofa = "Pohovka",
  lamp = "Lampa",
  fire_extinguisher = "Hasicí Přístroj",
  bench = "Sedačka",
  scanner = "Skener",
  op_sink2 = "Umyvadlo",
  toilet_sink = "Umyvadlo",
  hair_restorer = "Sázeč Vlasů",
  desk = "Stůl",
  swing_door2 = "Křídlové Dveře",
  lecture_chair = "Učební Lavice",
  pharmacy_cabinet = "Skříň s Léky",
  screen = "Zástěna",
  table1 = "Stůl",
  gates_of_hell = "Brány Pekla",
  blood_machine = "Hemogram",
  comfortable_chair = "Pohodlné Křeslo",
  bookcase = "Knihovna",
  reception_desk = "Recepce",
  crash_trolley = "Manipulační vozík",
  swing_door1 = "Křídlové Dveře",
  skeleton = "Kostlivec",
  rathole = "Krysí Díra",
}
handyman_window = {
    all_parcels = "Všude",
    parcel = "Parcela",
    }
policy = {
  staff_leave_rooms = "zam. opouští svou místnost",
  diag_procedure = "proces vyšetření",
  header = "ZÁSADY NEMOCNICE",
  sliders = {
    send_home = "POSLAT DOMŮ",
    guess = "HÁDAT LÉČBU",
    stop = "ZASTAVIT PROCES",
    staff_room = "JÍT SI ODPOČINOUT",
  },
  diag_termination = "ukončení diagnózy",
  staff_rest = "poslat zaměstnance odpočinout",
}
room_classes = {
  treatment = "Léčba",
  diagnosis = "Diagnóza",
  facilities = "Oddělení",
  clinics = "Kliniky",
}
tooltip = {
  folders_window = {
    data_location = "Adresář instalace původní hry Theme Hospital, jenž je vyžadován pro spuštění CorsixTH",
    no_font_specified = "Umístění písma zatím nezadáno!",
    browse_data = "Procházet pro jiné umístění instalace Theme Hospital. (současné umístění: %1%)",
    browse_font = "Procházet pro výběr jiného souboru s písmem (současné umístění: %1%)",
    font_location = "Umístění souboru s písmem, které je schopno zobrazit znaky Unicode vyžadované vaším jazykem. Pokud toto není zadáno, nebudete moci zvolit jazyky, které potřebují více znaků, než původní hra obsahuje. Příklad: ruština a čínština",
    screenshots_location = "Standardně je složka se snímky obrazovky ve stejném umístění jako soubor s nastavením. Pokud toto není žádané, pak si můžete zvolit vlastní. Stačí zvolit adresář, který chete použít.",
    reset_to_default = "Resetovat adresář na jeho výchozí umístění",
    back = "Zavřít tuto nabídku a vrátit se zpět do nabídky Nastavení",
    music_location = "Vyberte umístění vašich mp3 souborů s hudbou. Adresář musí být vytvořen předem a pak ho můžete zde zvolit.",
    savegames_location = "Standardně je adresář uložených her na stejném místě jako soubor s nastavením. Pokud toto nechcete, můžete si zvolit svůj vlastní. Stačí zvolit adresář, který chcete používat.",
    browse = "Procházet pro zvolení adresáře",
    browse_screenshots = "Procházet pro zvolení jiného umístění vašeho adresáře snímků obrazovky  ( Současné umístění: %1% ) ",
    browse_music = "Procházet pro zvolení jiného umístění vašeho adresáře s hudbou  ( Současné umístění: %1% ) ",
    not_specified = "Žádné umístění adresáře zatím nezadáno!",
    browse_saves = "Procházet pro zvolení jiného umístění vašeho adresáře uložených her  ( Současné umístění: %1% ) ",
    default = "Výchozí umístění",
  },
  customise_window = {
    aliens = "Kvůli chybějícím správným animacím standardně pacienti s Mimozemskou DNA přicházejí pouze při pohotovosti. Abyste je povolili i jako normální pacienty, stačí toto vypnout.",
    average_contents = "Pokud chcete, aby si hra pamatovala vámi přidané dodatečné objekty při stavbě místností, pak toto zapněte.",
    back = "Zavřít tuto nabídku a přejít zpět do Nastavení",
    movies = "Globální kontrola videí, toto umožňuje zákaz všech videí",
    fractured_bones = "Kvůli špatné animaci jsou standardně zakázány pacientky se Zlomenými Kostmi. Pro povolení pacientek s touto diagnózou ve vaší nemocnici musíte toto vypnout.",
    volume = "Pokud tlačítko pro snížení hlasitosti zároveň také otevírá Knihu léčby pacientů, můžete toto zapnout pro změnu klávesové zkratky knihy na Shift + C",
    intro = "Zapne nebo vypne úvodní video. Pokud chcete, aby video bylo přehráváno při každém spuštění CorsixTH, je třeba zapnout globální kontrolu videí.",
    paused = "V Theme Hospital může hráč použít horní nabídku pouze při pozastavení hry. To samé platí v CorsixTH, ale pomocí této volby můžete při pozastavení povolit vše.",
    remove_destroyed_rooms = "Pokud chcete povolit možnost odstranit zničené místnosti (za poplatek), zapněte tuto možnost.",
  },
  options_window = {
    language = "Vybrat %s jako jazyk",
    language_dropdown_item = "Zvolit %s jako jazyk",
    width = "Zadejte požadovanou šířku obrazovky",
    select_language = "Vybrat jazyk hry",
    select_resolution = "Vybrat nové rozlišení",
    back = "Zavřít okno možností",
    resolution = "Rozlišení v kterém by hra měla být spuštěna",
    fullscreen = "Zdali má být hra spuštěna v režimu v okně nebo celé obrazovky",
    fullscreen_button = "Klikněte pro přepnutí režimu celé obrazovky",
    change_resolution = "Změnit rozlišení okna na rozměry zadané vlevo",
    apply = "Použít zadané rozlišení",
    cancel = "Vrátit se zpět bez změny rozlišení",
    height = "Zadejte požadovanou výšku obrazovky",
    audio_button = "Zapnout nebo vypnout všechny zvuky ve hře",
    audio_toggle = "Zapnout/vypnout",
    folder_button = "Možnosti složky",
    customise_button = "Další nastavení, pomocí kterých si můžete svoji hru přizpůsobit",
    hotkey = "Změnit klávesové zkratky.",
    apply_shift_scrollspeed = "Použít nastavenou rychlost rolování s shiftem.",
    apply_scrollspeed = "Použít nastavenou rychlost rolování.",
    cancel_shift_scrollspeed = "Neměnit rychlost rolování s shiftem.",
    apply_zoomspeed = "Použít nastavenou rychlost přibližování.",
    scrollspeed = "Nastavte rychlost rolování v rozmezí 1 (nejpomalejší) až 10 (nejrychlejší). Výchozí hodnota je 2.",
    capture_mouse = "Kliknutím přepnete zachytávání kurzoru v okně hry.",
    cancel_scrollspeed = "Neměnit rychlost rolování.",
    shift_scrollspeed = "Nastavte rychlost rolování s shiftem v rozmezí 1 (nejpomalejší) až 10 (nejrychlejší). Výchozí hodnota je 4.",
    zoom_speed = "Nastavte rychlost přibližování v rozmezí 10 (nejpomalejší) až 1000 (nejrychlejší). Výchozí hodnota je 80.",
    cancel_zoomspeed = "Neměnit rychlost přibližování.",
    check_for_updates = "Nastavuje, zda má hra při spuštění kontrolovat aktualizace.",
    },
  update_window = {
    download = "Přejít na stránku stahování pro získání nejnovější verze CorsixTH",
    ignore = "Zatím si této aktualizace nevšímat. Při příštím spuštění CorsixTH budete znovu informováni.",
    },
  information = {
    close = "Zavřít informační dialogové okno",
  },
  menu_list_window = {
    save_date = "Klikněte zde pro seřazení seznamu podle posledního data změny",
    name = "Klikněte zde pro seřazení seznamu podle názvu",
    back = "Zavřít toto okno",
  },
  cheats_window = {
    close = "Zavřít dialogové okno cheatů",
    cheats = {
      lose_level = "Prohrát současnou úroveň.",
      emergency = "Vytvořit havárii.",
      end_year = "Přeskočit na konec roku.",
      earthquake = "Vytvořit zemětřesení.",
      money = "Přidat 10.000$ na bankovní účet.",
      win_level = "Vyhrát současnou úroveň.",
      vip = "Vytvořit VIP.",
      all_research = "Dokončit veškerý výzkum.",
      create_patient = "Vytvořit Pacienta na kraji mapy.",
      end_month = "Přeskočit na konec měsíce.",
      epidemic = "Vytvořit nakažlivého pacienta, který může způsobit epidemii",
      toggle_infected = "Zobrazit/Skrýt ikony nakažení pro aktivní, zjištěné epidemie",
      increase_prices = "Zvýšit všechny ceny o 50% (max. 200%)",
      decrease_prices = "Snížit všechny ceny o 50% (min. 50%)",
    },
  },
  buy_objects_window = {
    price = "Cena položky",
    cancel = "Zrušit",
    confirm = "Koupit položku/y",
    total_value = "Celková hodnota objednaných položek",
    decrease = "Koupit o jednu položku méně",
    increase = "Koupit o jednu položku více",
  },
  custom_game_window = {
    free_build = "Toto políčko zaškrtněte, pokud chcete hrát bez peněz a podmínek pro vítězství a prohru",
    load_selected_level = "Načíst a hrát zvolenou úroveň",
    choose_game = "Klikněte na úroveň pro zobrazení informací o ní.",
  },
  new_game_window = {
    easy = "Pokud jste začátečníci v simulačních hrách, tak toto je volba pro Vás",
    cancel = "Ah, já vlastně nechtěl začít novou hru!",
    difficulty = "Vyberte úroveň obtížnosti s kterou chcete hru hrát",
    tutorial = "Pokud chcete se začátkem jednou pomoci, stiskněte toto tlačítko.",
    hard = "Pokud tento druh hry znáte a chcete výzvu, tak si vyberte tuto volbu",
    medium = "Toto je střední cesta, když nevíte, co si vybrat",
    player_name = "Zadejte jméno, kterým chcete být ve hře oslovováni.",
    start = "Zahájit hru se zvolenými možnostmi",
  },
  machine_window = {
    close = "Zavřít",
    replace = "Vyměnit stroj",
    status = "Stav stroje",
    repair = "Zavolat Údržbáře, aby stroj opravil",
    name = "Název",
    times_used = "Počet použití stroje",
  },
  calls_dispatcher = {
    close = "Zavřít dialogové okno rozvrhovače volání",
    task = "Seznam úkolů - klikněte na úkol pro otevření okna přiděleného zaměstnance a přejděte na místo úkolu",
    assigned = "Tento rámeček je označen, když je někomu přidělen úkol.",
  },
  staff_window = {
    happiness = "Spokojenost",
    salary = "Měsíční plat",
    doctor_seniority = "Hodnost - Rezident, Doktor nebo Konzultant",
    skills = "Zvláštní dovednosti",
    tiredness = "Únava",
    name = "Jméno zaměstnance",
    psychiatrist = "Psychiatr",
    close = "Zavřít",
    face = "Fotografie - klikněte pro otevření obrazovky správy",
    pick_up = "Přemístit",
    center_view = "Levým kliknutím se přiblížíte na zaměstnance, pravým kliknutím mezi nimi přepínáte",
    researcher = "Výzkumník",
    sack = "Vykopnout",
    surgeon = "Chirurg",
    ability = "Úroveň schopnosti",
  },
  town_map = {
    people = "Přepnout lidi",
    fire_extinguishers = "Přepnout požární hydranty",
    plants = "Přepnout rostliny",
    heat_inc = "Zvýšit teplotu",
    balance = "Bilance",
    heat_level = "Úroveň tepla",
    objects = "Přepnout objekty",
    radiators = "Přepnout radiátory",
    heat_dec = "Snížit teplotu",
    close = "Odejít ze zobrazení města",
    heating_bill = "Účet za topení",
  },
  casebook = {
    cure_type = {
      surgery = "Tato nemoc vyžaduje operaci",
      drug_percentage = "Tato léčba používá lék - Váš je účinný na %d%%",
      drug = "Tato léčba používá lék",
      machine = "Tato léčba vyžaduje přístroj",
      unknown = "Stále nevíte, jak léčit tuto nemoc",
      psychiatrist = "Tuto léčbu provádí psychiatr",
    },
    cured = "Počet vyléčení",
    reputation = "Lék/Reputace Vyšetření",
    down = "Posunout dolů",
    research = "Klikněte zde k použití rozpočtu Výzkumu Specializací pro tuto léčbu",
    sent_home = "Počet odmítnutých pacientů",
    close = "Zavřít Knihu léčby pacientů",
    up = "Posunout nahoru",
    deaths = "Počet úmrtí",
    earned_money = "Dosud vyděláno",
    increase = "Zvýšit množství",
    decrease = "Snížit množství",
    cure_requirement = {
      hire_surgeons = "K provádění operací potřebujete zaměstnat dva chirurgy",
      not_possible = "Tuto léčbu ještě nezvládáte",
      hire_staff_old = "Ke zvládnutí této léčby potřebujete zaměstnat %s",
      hire_staff = "Ke zvládnutí této léčby potřebujete přijmout zaměstnance",
      hire_surgeon = "K provedení operace potřebujete zaměstnat druhého chirurga",
      build_room = "Ke zvládnutí této léčby potřebujete vybudovat místnost",
      build_ward = "Ke zvládnutí této léčby potřebujete vybudovat Lůžkové Oddělení",
      ward_hire_nurse = "Ke zvládnutí této léčby potřebujete Sestru v Lůžkovém Oddělení",
      possible = "Tuto léčbu můžete zvládnout",
      research_machine = "Pro tuto léčbu potřebujete vynalézt nějaké nástroje",
    },
    treatment_charge = "Poplatek",
  },
  hire_staff_window = {
    qualifications = "Další kvalifikace Doktora",
    salary = "Plat",
    receptionists = "Zobrazit Recepční k dispozici pro najmutí",
    prev_person = "Zobrazit předchozí osobu",
    psychiatrist = "Psychiatr",
    nurses = "Zobrazit Sestry k dispozici pro najmutí",
    doctors = "Zobrazit Doktory k dispozici pro najmutí",
    doctor_seniority = "Zkušenost Doktora (Rezident, Doktor, Konzultant)",
    cancel = "Zrušit",
    staff_ability = "Schopnost zaměstnance",
    next_person = "Zobrazit další osobu",
    researcher = "Výzkumník",
    handymen = "Zobrazit Údržbáře k dispozici pro najmutí",
    surgeon = "Chirurg",
    hire = "Najmout osobu",
  },
  toolbar = {
    charts = "Grafy",
    policy = "Zásady",
    objects = "Vybavení chodby",
    status = "Stav",
    reputation = "Vaše reputace",
    research = "Výzkum",
    bank_button = "Levé kliknutí pro Správce Banky, pravé kliknutí pro Bankovní Výpis",
    rooms = "Postavit místnosti",
    town_map = "Mapa města",
    casebook = "Kniha léčby pacientů",
    edit = "Upravit místnosti/položky",
    date = "Datum",
    staff_list = "Správa zaměstnanců",
    balance = "Vaše bilance",
    hire = "Najmout zaměstnance",
  },
  main_menu = {
    load_game = "Načíst uloženou hru",
    options = "Upravit různá nastavení",
    load_menu = {
      load_slot = "NAČÍST HRU",
      empty_slot = "PRÁZDNÉ",
    },
    new_game = "Začít novou hru úplně od začátku",
    continue = "Pokračovat v předchozí hře",
    custom_level = "Postavit vaši nemocnici ve vlastní úrovni",
    network = "Spustit hru po síti",
    exit = "Ne, ne, prosím neodcházejte!",
    quit = "Odejít",
    custom_campaign = "Hrát komunitou vytvořenou kampaň",
    map_edit = "Vytvořit vlastní mapu",
  },
  queue_window = {
    num_expected = "Počet pacientů, u kterých Recepční očekává, že se brzy připojí do fronty",
    dec_queue_size = "Zmenšení maximální velikosti fronty",
    num_entered = "Počet pacientů, kteří byli doposud v této místnosti léčeni",
    num_in_queue = "Počet pacientů ve frontě",
    close = "Zavřít",
    patient = "Táhněte pacientem pro jeho přesun pozicemi ve frontě. Pravým kliknutím na pacienta ho pošlete domů nebo odkážete do konkurenční nemocnice",
    max_queue_size = "Maximální velikost fronty, kterou by Recepční měla dovolit",
    inc_queue_size = "Zvětšení maximální velikosti fronty",
    front_of_queue = "Přetáhněte pacienta na tuto ikonu pro přesun na začátek fronty",
    end_of_queue = "Přetáhněte pacienta na tuto ikonu pro přesun na konec fronty",
    patient_dropdown = {
      send_home = "Propustit pacienta z nemocnice",
      hospital_3 = "Odkázat pacienta do jiné nemocnice",
      reception = "Poslat pacienta k Recepční",
      hospital_2 = "Odkázat pacienta do jiné nemocnice",
      hospital_1 = "Odkázat pacienta do jiné nemocnice",
    },
  },
  load_game_window = {
    load_game_number = "Načíst hru %d",
    load_game = "Načíst hru %s",
    load_autosave = "Načíst automaticky uloženou hru",
  },
  statement = {
    close = "Zavřít obrazovku Výpisu",
  },
  graphs = {
    scale = "Měřítko grafu",
    reputation = "Přepnout Hodnotu Nemocnice",
    cures = "Přepnout vyléčení",
    close = "Zavřít Obrazovku Grafů",
    wages = "Přepnout výplaty",
    deaths = "Přepnout úmrtí",
    balance = "Přepnout bilanci",
    money_in = "Přepnout příjmy",
    money_out = "Přepnout výdaje",
    visitors = "Přepnout návštěvníky",
  },
  totd_window = {
    previous = "Zobrazit předchozí radu",
    next = "Zobrazit další radu",
  },
  fax = {
    close = "Zavřít toto okno bez vymazání zprávy",
  },
  save_game_window = {
    save_game = "Přepsat uloženou hru %s",
    new_save_game = "Zadejte jméno pro novou uloženou hru",
  },
  hotkey_window = {
    button_recallPosKeys = "Otevřít nabídku nastavení kláv. zkratek pozice kamery",
    button_defaults = "Resetovat všechny klávesové zkratky na původní.",
    button_back_02 = "Vrátit se k nastavení hlavních klávesových zkratek. Všechny změny zde provedené lze v hlavní nabídce uložit.",
    button_accept = "Potvrdit a uložit nastavení klávesových zkratek.",
    button_cancel = "Vrátit se do nastavení bez ukládání změn.",
    caption_panels = "Otevřít nabídku s klávesami panelu",
    button_gameSpeedKeys = "Otevřít nabídku s klávesami nastavení rychlosti hry",
  },
  pay_rise_window = {
    accept = "Splnit platový požadavek",
    decline = "Neplatit - místo toho je vykopnout",
  },
  jukebox = {
    close = "Zavřít jukebox",
    fast_forward = "Rychle dopředu",
    rewind = "Přetočit",
    current_title = "Jukebox",
    play = "Přehrát",
    stop = "Zastavit",
    loop = "Přehrávat ve smyčce",
  },
  handyman_window = {
    happiness = "Spokojenost",
    salary = "Měsíční plat",
    prio_machines = "Zvýšit Údržbářovu prioritu opravy přístrojů",
    tiredness = "Únava",
    sack = "Vykopnout",
    close = "Zavřít",
    name = "Jméno zaměstnance",
    pick_up = "Přemístit",
    prio_litter = "Zvýšit Údržbářovu prioritu zametání odpadků",
    center_view = "Přiblížit na Údržbáře",
    prio_plants = "Zvýšit Údržbářovu prioritu zalévání rostlin",
    face = "Fotografie - klikněte pro otevření obrazovky správy",
    ability = "Schopnost",
    parcel_select = "Parcela, kde údržbář přijímá úkoly. Klikněte pro změnu nastavení"
  },
  watch = {
    hospital_opening = "Čas pro stavbu: toto je zbývající čas do otevření vaší nemocnice veřejnosti. Kliknutím na zelené tlačítko ji otevřete okamžitě.",
    epidemic = "Epidemie: čas zbývající pro ututlání epidemie. Když tento čas vyprší NEBO nakažený pacient odejde z vaší nemocnice, navštíví vás Hygienický Inspektor. Tlačítko vypíná a zapíná režim očkování. Klikněte na pacienta, aby ho Sestra očkovala.",
    emergency = "Pohotovost: zbývající čas do vyléčení všech pacientů pohotovosti.",
  },
  policy = {
    close = "Zavřít obrazovku zásad",
    staff_leave = "Klikněte zde, aby zaměstnanci, kteří nemají nic na práci, pomohli kolegům, kteří to potřebují",
    staff_stay = "Klikněte zde, aby určití zaměstnanci zůstali tam, kde je umístíte",
    staff_rest = "Jak moc musí být zaměstnanci unavení, než si můžou odpočinout",
    diag_termination = "Vyšetření pacienta bude pokračovat, dokud si nebudou Doktoři tak jistí, jako je procento ZASTAVENÍ PROCEDURY, nebo dokud nebudou vyzkoušeny všechny diagnostické přístroje",
    diag_procedure = "Pokud je procento Doktorovy diagnózy nižší, než procento POSLAT DOMŮ, pacient bude poslán domů. Pokud je diagnóza jistější než procento HÁDAT LÉČBU, pacient bude poslán na příslušnou léčbu",
  },
  research_policy = {
    research_progress = "Vývoj směrem k dalšímu objevu v této kategorii: %1%/%2%",
    no_research = "V této kategorii nyní žádný výzkum neprobíhá",
  },
  status = {
    happiness = "Celková radost lidí ve vaší nemocnici",
    thirst = "Celková úroveň žízně lidí ve vaší nemocnici",
    reputation = "Vaše Reputace musí být alespoň %d. Nyní je %d",
    population = "Potřebujete, aby %d%% celkové populace chodilo do vaší nemocnice",
    population_chart = "Graf zobrazující jakou část místní populace každá nemocnice přitahuje",
    num_cured = "Cílem je vyléčit %d lidí. Dosud jste vyléčili %d",
    close = "Zavřít obrazovku Přehledu",
    balance = "Vaše bankovní bilance musí být alespoň %d. Nyní je %d",
    win_progress_other = "Zobrazit postup směrem ke kritériu výhry pro %s",
    value = "Vaše nemocnice musí mít cenu %d$. V současnosti má cenu %d$",
    win_progress_own = "Zobrazit postup směrem ke kritériu výhry pro vaši vlastní nemocnici",
    warmth = "Celková úroveň tepla lidí ve vaší nemocnici",
    percentage_killed = "Vaším úkolem je zabít méně než %d%% vašich návštěvníků. Dosud jste zabili %d%% z nich",
    percentage_cured = "Potřebujete vyléčit %d%% návštěvníků vaší nemocnice. Nyní jste vyléčili %d%%",
  },
  patient_window = {
    happiness = "Spokojenost",
    thirst = "Žízeň",
    queue = "Zobrazit frontu místnosti, kde pacient čeká",
    abort_diagnosis = "Poslat osobu na léčbu hned místo čekání na dokončení vyšetření",
    close = "Zavřít",
    casebook = "Zobrazit podrobnosti o nemoci této osoby",
    warmth = "Úroveň tepla této osoby",
    graph = "Klikněte pro přepínání mezi grafem zdraví osoby a jejich historií vyšetření",
    send_home = "Propustit pacienta z nemocnice",
    center_view = "Přiblížit hru na osobu",
  },
  message = {
    button_dismiss = "Levým kliknutím si zprávu přečtete, pravým kliknutím jí hodíte pod stůl",
    button = "Levým kliknutím zprávu otevřete",
  },
  build_room_window = {
    room_classes = {
      treatment = "Vybrat místnosti Léčby",
      clinic = "Vybrat místnosti Klinických Oddělení",
      facilities = "Vybrat místnosti Dalších Zařízení",
      diagnosis = "Vybrat místnosti pro Diagnózu",
    },
    close = "Zavřít",
    cost = "Cena vámi zvolené místnosti",
  },
  rooms = {
    dna_fixer = "Doktor používá Genex 2000 pro léčbu pacientů s Mimozemskou DNA",
    gps_office = "Pacienti obdrží jejich úvodní konzultaci a výsledky v Kanceláři Praktického Lékaře",
    toilets = "Postavte Toalety, abyste zabránili Pacientům dělat ve vaší nemocnici bordel!",
    general_diag = "Doktor používá Vyšetřovnu pro základní vyšetření pacientů. Levné a často velmi účinné",
    hair_restoration = "Doktor používá Místnost Sázeče Vlasů pro léčbu Plešatosti",
    scanner = "Doktor používá Skener k vyšetření Pacientů",
    research_room = "Doktoři s Výzkumnými dovednostmi můžou objevit nové léky a přístroje ve Výzkumné Laboratoři",
    cardiogram = "Doktor používá Místnost s Kardiem k vyšetření Pacientů",
    ward = "Lůžkové Oddělení je užitečné jak pro vyšetření, tak i pro léčbu. Pacienti jsou posláni pro pozorování a také pro zotavení z operace na Lůžkové Oddělení se Sestrou",
    psychiatry = "Psychiatrie léčí šílené pacienty a pomáhá v diagnóze ostatních pacientů, ale vyžaduje Doktora s Psychiatrickou dovedností",
    staffroom = "Doktoři a Sestry si v místnosti pro zaměstnance odpočinou a nebudou tak unaveni",
    electrolysis = "Doktor používá místnost Elektrolýzy k léčbě Vlasitidy",
    jelly_vat = "Doktor používá Kliniku Slizu k léčbě Slizitidy",
    x_ray = "Doktor používá Rentgen k vyšetření Pacientů",
    inflation = "Doktor používá Hustírnu k léčbě Pacientů s Nafouknutými Hlavami",
    ultrascan = "Doktor používá Ultrasken k vyšetření Pacientů",
    blood_machine = "Doktor používá Hemogram k vyšetření Pacientů",
    tongue_clinic = "Doktor používá ORL k léčbě Ochablého Jazyka",
    fracture_clinic = "Sestra používá Oddělení Zlomenin pro spravení Zlomených Kostí",
    training_room = "Učebna s Konzultantem může být použita k výuce jiných Doktorů",
    decontamination = "Doktor používá Dekontaminační Sprchu k léčbě Ozáření",
    pharmacy = "Sestra v Lékárně rozděluje léky k léčbě pacientů",
    operating_theatre = "Operační Sál potřebuje dva Doktory s chirurgickými dovednostmi",
  },
  bank_manager = {
    interest_payment = "Měsíční splátka úroků",
    borrow_5000 = "Půjčit si 5000$ od banky",
    current_loan = "Současné nevyřízené půjčky",
    repay_5000 = "Splatit 5000$ bance",
    hospital_value = "Současná hodnota vaší nemocnice",
    show_graph = "Zobrazit graf očekáváných plateb od %s",
    insurance_owed = "Množství peněz, které vám dluží %s",
    graph = "Graf očekávaných plateb od %s",
    inflation_rate = "Roční míra inflace",
    graph_return = "Vrátit se k předchozímu zobrazení",
    interest_rate = "Roční úroková míra",
    close = "Zavřít obrazovku Správce Banky",
    balance = "Vaše bankovní bilance",
  },
  window_general = {
    cancel = "Zrušit",
    confirm = "Potvrdit",
  },
  research = {
    cure_dec = "Snížit procento Léčby",
    drugs_inc = "Zvýšit procento výzkumu Léků",
    diagnosis_dec = "Snížit procento Výzkumu",
    improvements_inc = "Zvýšit procento Vylepšení",
    drugs_dec = "Snížit procento Léků",
    diagnosis_inc = "Zvýšit procento výzkumu Vybavení",
    close = "Zavřít obrazovku Výzkumu",
    specialisation_inc = "Zvýšit procento Mimořádného Výzkumu",
    improvements_dec = "Snížit procento Vylepšení",
    cure_inc = "Zvýšit procento Výzkumu",
    specialisation_dec = "Snížit procento Mimořádného Výzkumu",
    allocated_amount = "Množství přiděleného rozpočtu",
  },
  lua_console = {
    close = "Zavřít konzoli",
    textbox = "Zde zejte kód Lua pro spuštění",
    execute_code = "Spustit kód, který jste zadali",
  },
  place_objects_window = {
    pick_up = "Přemístit objekt",
    cancel = "Zrušit",
    buy_sell = "Koupit/prodat objekty",
    confirm = "Potvrdit",
  },
  staff_list = {
    happiness = "Zobrazuje, jak moc jsou zaměstnanci spokojení",
    researcher_train = "Na %d%% vyškolen pro to, aby se stal Výzkumníkem",
    ability_2 = "Úroveň schopnosti zaměstnance",
    surgeon_train = "Na %d%% vyškolen pro to, aby se stal Chirurgem",
    tiredness = "Zobrazuje, jak moc jsou zaměstnanci unavení",
    psychiatrist = "Kvalifikovaný Psychiatr",
    sack = "Vykopnout tuto osobu",
    next_person = "Zobrazit další stránku",
    researcher = "Kvalifikovaný Výzkumník",
    handymen = "Zobrazit seznam Údržbářů zaměstnaných v této nemocnici",
    surgeon = "Kvalifikovaný Chirurg",
    ability = "Zobrazí úroveň schopnosti těchto zaměstnanců",
    salary = "Současný plat této osoby",
    skills = "Zvláštní dovednosti",
    happiness_2 = "Spokojenost Zaměstnance",
    prev_person = "Zobrazit předchozí stránku",
    tiredness_2 = "Únava Zaměstnance",
    nurses = "Zobrazit seznam Sester zaměstnaných v této nemocnici",
    doctors = "Zobrazit seznam Doktorů zaměstnaných v této nemocnici",
    close = "Odejít a navrátit se do hry",
    bonus = "Zaplatit této osobě 10% bonus",
    pay_rise = "Zvýšit plat této osoby o 10%",
    doctor_seniority = "Služební věk doktora",
    detail = "Důraz na Detail",
    view_staff = "Zobrazit osobu při práci",
    psychiatrist_train = "Na %d%% vyškolen pro to, aby se stal Psychiatrem",
    receptionists = "Zobrazit seznam Recepčních zaměstnaných v této nemocnici",
  },
  objects = {
    dna_fixer = "23 OB_DNA_FIXER",
    op_sink1 = "33 OB_OP_SINK_1",
    litter_bomb = "Odpadková bomba: poškozuje nemocnice konkurenta",
    auto_autopsy = "Auto-Pitvač: velmi pomáhá při výzkumu",
    door = "Dveře: lidé tyto hodně zavírají a otevírají.",
    projector = "37 OB_PROJECTOR",
    radiation_shield = "28 OB_RAD_SHIELD",
    entrance_left = "58 OB_ENT_LDOOR",
    operating_table = "30 OB_OP_TABLE",
    bed2 = "nepoužito",
    cabinet = "Kartotéka: obsahuje složky pacientů, poznámky a dokumenty výzkumu.",
    console = "15 OB_SCANNER_CONSOLE",
    bed = "Postel: hodně nemocní lidé na těchto leží.",
    couch = "18 OB_COUCH",
    drinks_machine = "Automat na Nápoje: zabraňuje žízni pacientů a poskytuje výdělek.",
    shower = "54 OB_DECON_SHOWER",
    electrolyser = "46 OB_ELECTRO",
    table2 = "12 OB_BTABLE",
    radiator = "Radiátor: zabraňuje, aby ve vaší nemocnici byla zima.",
    chair = "Židle: pacienti na tomto sedí a povídají o svých nemocech.",
    jelly_moulder = "47 OB_JELLY_VAT",
    computer = "Počítač: klíčová součást výzkumu",
    ultrascanner = "22 OB_ULTRASCAN",
    bin = "Koš: pacienty sem dávají své odpadky.",
    surgeon_screen = "35 OB_SURGEON_SCREEN",
    slicer = "26 OB_SLICER",
    bed3 = "nepoužito",
    x_ray = "27 OB_XRAY",
    video_game = "Video hra: Nechte vaše zaměstnance odpočinout u Petrisu.",
    atom_analyser = "Chemický mixér: umístěn ve výzkumné laboratoři, tento stroj zrychlí celý výzkumný proces.",
    inflator = "Nafukovač: léčí lidi s Nafouknutou Hlavou.",
    toilet = "Záchod: pacienti, eh, toto používají.",
    x_ray_viewer = "29 OB_XRAY_VIEWER",
    cast_remover = "24 OB_CAST_REMOVE",
    entrance_right = "59 OB_ENT_RDOOR",
    litter = "Odpadek: Ponechán na zemi pacientem, protože nenalezl koš, do kterého by ho mohl hodit.",
    cardio = "13 OB_CARDIO",
    plant = "Rostlina: udržuje pacienty spokojené a čistí vzduch.",
    pool_table = "Kulečníkový stůl: zaměstnanci si mohou hrát na to, že umí hrát kulečník.",
    tv = "TV: zajistěte, aby zaměstnanci nezmeškali jejich oblíbené telenovely.",
    sofa = "Pohovka: Zaměstnanci odpočívající v Místnosti pro Zaměstnance budou tiše sedět na pohovce, ledaže by existoval lepší způsob, jak si odpočinout.",
    lamp = "Lampa: září z ní světlo a tím umožňuje zaměstnanci vidět.",
    fire_extinguisher = "Hasicí přístroj: zmenšuje nebezpečí od selhávajících přístrojů.",
    bench = "Sedačka: poskytuje sezení pro jednoho pacienta, dělá čekání pohodlnější.",
    scanner = "14 OB_SCANNER",
    op_sink2 = "34 OB_OP_SINK_2",
    toilet_sink = "Umyvadlo: Vaši pacienti více uvědomělí v hygieně si můžou v tomto umýt své zašpiněné ruce. Pokud není dostatek umyvadel, pacienti budou nespokojení.",
    hair_restorer = "25 OB_HAIR_RESTORER",
    desk = "Stůl: důležitý pro Doktora, aby si na něj mohl dát PC.",
    swing_door2 = "53 OB_DOUBLE_DOOR2",
    lecture_chair = "Přednášková židle: Vaši školící se Doktoři zde sedí a píšou si poznámky, nudí se a jen tak si čmárají. Čím více židlí umístíte, tím větší může vaše třída být.",
    pharmacy_cabinet = "Lékárna: kde jsou léky uchovávány",
    screen = "16 OB_SCREEN",
    table1 = "Stůl (ODSTRANĚNO): obsahuje kolekci časopisů, aby udržovaly čekající pacienty spokojené.",
    gates_of_hell = "48 OB_HELL",
    blood_machine = "42 OB_BLOOD_MC",
    comfortable_chair = "61 OB_COMFY_CHAIR",
    bookcase = "Knihovna: skládka nikdy neotevřených knih, díky kterým Doktoři vypadají chytřeji.",
    reception_desk = "Recepce: vyžaduje Recepční, která posílá pacienty k Doktorům.",
    crash_trolley = "20 OB_CRASH",
    swing_door1 = "52 OB_DOUBLE_DOOR1",
    skeleton = "Kostlivec: používán ke cvičebním účelům a na Halloween.",
    rathole = "Byteček krysí rodinky, které se zalíbila vaše špinavoučká nemocnice.",
  },
  custom_campaign_window = {
    choose_campaign = "Zvolte kampaň pro zobrazení informací o ní.",
    start_selected_campaign = "Načte první úroveň kampaně",
  },
  save_map_window = {
    map = "Přepsat mapu %s",
    new_map = "Zadejte název uložené hry s mapou",
  },
}
humanoid_name_ends = {
  [1] = "KOVÁŘ",
  [2] = "KNOT",
  [3] = "ÚTES",
  [4] = "FIN",
  [5] = "SNOB",
  [6] = "KOPEJ",
  [7] = "TUNA",
  [8] = "SYN",
  [9] = "LADA",
  [10] = "PLOD",
  [11] = "STROM",
  [12] = "LOK",
  [13] = "ŠUNKA",
  [14] = "PRÁH",
  [15] = "VÝHR",
  [16] = "PECH",
  [17] = "ŠVÉD",
  [18] = "KUNA",
  [19] = "POND",
  [20] = "MUŽ",
  [21] = "MĚLTO",
  [22] = "OPIE",
  [23] = "VÍCE",
  [24] = "BAŽINA",
  [25] = "NECH",
  [26] = "ČIN",
}
place_objects_window = {
  drag_blueprint = "Táhněte návrh, dokud nebude spokojeni s jeho velikostí",
  place_objects = "Umístěte objekty a přesunujte je, dokud nebudete spokojení, pak potvrďte",
  place_objects_in_corridor = "Umístěte objekty na chodbě",
  place_door = "Umístěte dveře",
  pick_up_object = "Klikněte na objekt pro zvednutí, nebo vyberte jinou možnost z nabídky",
  confirm_or_buy_objects = "Můžete stavbu místnost potvrdit, nebo koupit či přesunout nějaké objekty",
  place_windows = "Umístěte okna, pokud chcete, pak klikněte na potvrdit",
}
transactions = {
  cure = "Léčba",
  eoy_bonus_penalty = "Bonus/Penalizace na Konci Roku",
  wages = "Platy",
  machine_replacement = "Cena Náhradního Přístroje",
  cheat = "Peníze Pomocí Cheatu",
  bank_loan = "Půjčka Banky",
  build_room = "Stavba Místnosti",
  research = "Náklady Výzkumu",
  general_bonus = "Platba Obecného Bonusu",
  heating = "Náklady za Vytápění",
  buy_object = "Koupě Objektu",
  cure_colon = "Léčba:",
  emergency_bonus = "Platba Bonusu z Havárie",
  epidemy_coverup_fine = "Pokuta za Ututlání Epidemie",
  research_bonus = "Bonus Výzkumu",
  buy_land = "Koupě Pozemku",
  final_treat_colon = "Konečná Léčba:",
  drug_cost = "Cena Léku",
  personal_bonus = "Vyplacení Osobního Bonusu",
  severance = "Odškodné",
  jukebox = "Příjem: Jukebox",
  drinks = "Příjem: Automaty na Nápoje",
  vaccination = "Očkování",
  insurance_colon = "Pojištění:",
  epidemy_fine = "Pokuta za Epidemii",
  deposit = "Záloha za Léčbu",
  compensation = "Odškodné Vlády",
  loan_interest = "Úrok z Půjčky",
  sell_object = "Prodej Objektu",
  vip_award = "Peněžní Odměna od VIP",
  treat_colon = "Léčba:",
  loan_repayment = "Splacení Půjčky",
  eoy_trophy_bonus = "Bonus z Ocenění na Konci Roku",
  advance_colon = "Pokrok:",
  hire_staff = "Najmutí Zaměstnanců",
  overdraft = "Úrok z Přečerpání",
  remove_room = "Odklizení Rozbité Místnosti"
}
diseases = {
  jellyitis = {
    cure = "Léčba - Pacient je na chvíli ponořen do Formy na Sliz ve speciální místnosti.",
    cause = "Příčina - Dieta využívající k hubnutí želatinu.",
    name = "Slizitida",
    symptoms = "Příznaky - Nadměrný třes, časté padání a podivná konzistence.",
  },
  hairyitis = {
    cure = "Léčba - Elektrolytický přístroj odstraní vlasy a uzavře póry.",
    cause = "Příčina - Dlouhodobé vystavení úplňku.",
    name = "Vlasitida",
    symptoms = "Příznaky - Pacient má výrazně vyvinutý čich.",
  },
  golf_stones = {
    cure = "Léčba - Kameny musí být odstraněny pomocí operace vyžadující dva Chirurgy.",
    cause = "Příčina - Vystavení pacienta jedovatému plynu uvnitř golfových míčků.",
    name = "Golfové Kameny",
    symptoms = "Symptomy - Delirium a zvýšený stud.",
  },
  discrete_itching = {
    cure = "Léčba - Pacient vypije lékárnický lepkavý sirup k zabránění svědění kůže.",
    cause = "Příčina - Malý hmyz s ostrými zoubky.",
    name = "Extrémní Svědění",
    symptoms = "Příznaky - Škrábání pacienta.",
  },
  serious_radiation = {
    cure = "Léčba - Pacient musí být umístěn do Dekontaminační Sprchy a řádně vykartáčován.",
    cause = "Příčina - Záměna izotopů plutonia za žvýkačku.",
    name = "Vážné Ozáření",
    symptoms = "Příznaky - Pacienti s touto nemocí se cítí velmi, velmi mizerně.",
  },
  broken_wind = {
    cure = "Léčba - Pacientovi je podán lék s vůní fialek.",
    cause = "Příčina - Cvičení na hrazdě po dojezení hrachové kaše.",
    name = "Plynatost",
    symptoms = "Příznaky - Kolíčky na nosech osob stojících za pacientem.",
  },
  ruptured_nodules = {
    cure = "Léčba - Dva kvalifikovaní Chirurgové musí uzliny odstranit použitím pevných rukou.",
    cause = "Příčina - Bungee jumping za studeného počasí.",
    name = "Roztržené Uzliny",
    symptoms = "Příznaky - Neschopnost si pohodlně sednout.",
  },
  invisibility = {
    cure = "Léčba - Barevná tekutina vypitá v Lékárně brzy pacienta obnoví do plné pozorovatelnosti.",
    cause = "Příčina - Kousnutí radioaktivním (a neviditelným) mravencem.",
    name = "Neviditelnost",
    symptoms = "Příznaky - Pacienti nijak netrpí. Ba naopak, někteří zneužívají této nemoci k uskutečnění kanadských žertíků na své známé.",
  },
  infectious_laughter = {
    cure = "Léčba - Kvalifikovaný Psychiatr musí pacientovi připomenout závažnost jeho nemoci.",
    cause = "Příčina - Časté sledování klasických komedií.",
    name = "Nakažlivý Smích",
    symptoms = "Příznaky - Bezmocné potlačování smíchu a opakování známých vtipů.",
  },
  diag_blood_machine = {
    name = "Vyše Hemogram",
  },
  general_practice = {
    name = "Vyše Prakt. Lékař",
  },
  fractured_bones = {
    cure = "Léčba - Pacient je mumifikován v sádře. Následně je třeba přebytečnou sádru odřezat.",
    cause = "Příčina - Pád z výšky ega na výšku IQ pacienta.",
    name = "Zlomené Kosti",
    symptoms = "Příznaky - Hlasité křupnutí a neschopnost použít zasažené končetiny.",
  },
  corrugated_ankles = {
    cure = "Léčba - Křeč způsobená lehce jedovatou směsí bylin navrátí kotníky do původní podoby.",
    cause = "Příčina - Léta strávená za volantem bez přestávky.",
    name = "Ohnuté Kotníky",
    symptoms = "Příznaky - Pacientovi nepadnou jeho oblíbené boty.",
  },
  diag_psych = {
    name = "Vyše Psychiatr",
  },
  sweaty_palms = {
    cure = "Léčba - Psychiatr musí pacientovi tuto chorobu doslova vymluvit.",
    cause = "Příčina - Strach z pracovních pohovorů.",
    name = "Zpocené Dlaně",
    symptoms = "Příznaky - Potřást si rukou s pacientem je jako potřást si s čerstvě nacucanou houbou.",
  },
  diag_x_ray = {
    name = "Vyše Rentgen",
  },
  diag_ward = {
    name = "Vyše Lůžkové Oddělení",
  },
  slack_tongue = {
    cure = "Léčba - Jazyk je umístěn do Sekáčku a je rychle, účinně a bezbolestně odstraněn.",
    cause = "Příčina - Věčné diskutování o televizních seriálech.",
    name = "Ochablý Jazyk",
    symptoms = "Příznaky - Jazyk se natáhne do pětinásobku své původní délky.",
  },
  sleeping_illness = {
    cure = "Léčba - Vypití velmi silné kávy.",
    cause = "Příčina - Hyperaktivní spánková žláza v patře úst.",
    name = "Spavá Nemoc",
    symptoms = "Příznaky - Nepřekonatelná touha se všude vyspat.",
  },
  uncommon_cold = {
    cure = "Léčba - Štamprle tajného extraktu ze švestek.",
    cause = "Příčina - Kašlající prcek od souseda.",
    name = "Neobyčejné Nachlazení",
    symptoms = "Příznaky - Kýchání, bílý jazyk a velký červený nos.",
  },
  transparency = {
    cure = "Léčba - Drahý lék vyrobený z obarvené vody tuto nemoc vyléčí.",
    cause = "Příčina - Lízání jogurtu z víčka.",
    name = "Průhlednost",
    symptoms = "Příznaky - Tělo pacienta funguje jako tlusté sklo.",
  },
  diag_cardiogram = {
    name = "Vyše Kardiogram",
  },
  diag_general_diag = {
    name = "Vyše Obecné",
  },
  spare_ribs = {
    cure = "Léčba - Žebra musí být vyňata dvěma Chirurgy a dána pacientovi v igelitovém sáčku.",
    cause = "Příčina - Hltání pilulek bez zapíjení.",
    name = "Přebytečná Žebra",
    symptoms = "Příznaky - Pacient si připadá, jako by byl vyztužen..",
  },
  the_squits = {
    cure = "Léčba - Lepkavá směs vláknitých lékárenských chemikálií uklidní neklidný zažívací trakt.",
    cause = "Příčina - Jezení pizzy nalezené za sporákem.",
    name = "Hnačka",
    symptoms = "Příznaky - Ehm… Tohle jistě znáte.",
  },
  broken_heart = {
    cure = "Léčba - Dva Chirurgové otevřou hrudník a, zadržujíce dech, něžně srdce slepí izolepou.",
    cause = "Příčina - Někdo bohatší, mladší a štíhlejší než pacient.",
    name = "Zlomené Srdce",
    symptoms = "Příznaky - Neustávající pláč a ruce plné fotek z dovolené s drahou polovičkou.",
  },
  baldness = {
    cure = "Léčba - Umělé vlasy z neprodejných paruk jsou nasázeny zpátky do pacientovy hlavy.",
    cause = "Příčina - Lhaní a vymýšlení příběhů pro zvýšení popularity.",
    name = "Plešatost",
    symptoms = "Příznaky - Povrch hlavy připomínající zrcadlo.",
  },
  bloaty_head = {
    cure = "Léčba - Nafouknutá hlava se velmi opatrně vyfoukne, pak je opatrně a velmi přesně nafouknuta na správný tlak s použitím chytré mašinky.",
    cause = "Příčina - Čichání sýra a pití nevyčištěné dešťové vody.",
    name = "Nafouknutá Hlava",
    symptoms = "Příznaky - Pacient se cítí velmi nekomfortně.",
  },
  gut_rot = {
    cure = "Léčba - Sestra může podat výběr rozpuštěných chemikálií k pokrytí žaludku.",
    cause = "Příčina - Whisky Sirup Proti Kašli Dobrých Časů Paní O'Malleyové.",
    name = "Shnilé Vnitřnosti",
    symptoms = "Příznaky - Žádný kašel, ale také žádná pokrývka stěny žaludku.",
  },
  iron_lungs = {
    cure = "Léčba - Dva Chirurgové na Operačním Sále operací odstraní plíce pevné jako sádra.",
    cause = "Příčina - Městský smog smíchaný s drobky z kebabu.",
    name = "Železné Plíce",
    symptoms = "Příznaky - Schopnost dýchat oheň a hlasitě křičet pod vodou.",
  },
  chronic_nosehair = {
    cure = "Léčba - Pacientovi je v lékarně podán lék stejné kvality jako pro všechny ostatní.",
    cause = "Příčina - Povyšování se nad ostatní.",
    name = "Chronické Chlupy v Nose",
    symptoms = "Příznaky - Knír z chlupů z nosu, ve kterých by si i jezevec mohl udělat doupě.",
  },
  kidney_beans = {
    cure = "Léčba - Dva Chirurgové musí fazole odstranit, aniž by se dotkli okrajů ledvin.",
    cause = "Příčina - Jezení kostek ledu v nápojích.",
    name = "Ledvinové Fazole",
    symptoms = "Příznaky - Bolest a časté výlety na záchod.",
  },
  fake_blood = {
    cure = "Léčba - Uklidnění Psychiatrem je jediný způsob, jak tuto poruchu řešit.",
    cause = "Příčina - Pacient je častou obětí kanadských žertíků.",
    name = "Falešná Krev",
    symptoms = "Příznaky - Takto otravný křikloun nelze v davu přehlédnout.",
  },
  heaped_piles = {
    cure = "Léčba - Příjemný, přesto účinný kyselinný nápoj rozpustí hemeroidy zevnitř.",
    cause = "Příčina - Sezení na chladných, kamenných schodech.",
    name = "Nahromaděné Hemeroidy",
    symptoms = "Příznaky - Pacient má pocit, jako by seděl na pytlíku kuliček.",
  },
  gastric_ejections = {
    cure = "Léčba - Vypití speciálního lepidla zabrání čemukoliv opustit pacientovy vnitřnosti.",
    cause = "Příčina - Kořeněné mexické nebo indické jídlo.",
    name = "Žaludeční Katapulty",
    symptoms = "Příznaky - Pacientův oběd se vrací místy, kudy vcházel, ve zcela náhodných intervalech.",
  },
  diag_ultrascan = {
    name = "Vyše Ultrasken",
  },
  alien_dna = {
    cure = "Léčba - DNA je mechanicky odstraněna, vyčištěna od mimozemských částic a navrácena na své místo.",
    cause = "Příčina - Skupinka chuligánů se zkumavkou mimozemské krve.",
    name = "Mimozemská DNA",
    symptoms = "Příznaky - Postupná proměna v mimozemšťana a touha ničení pozemských měst.",
  },
  king_complex = {
    cure = "Léčba - Psychiatr řekne pacientovi, jak směšně vypadá.",
    cause = "Příčina - Králův duch vstoupí do podvědomí pacienta, čímž kompletně ovládne pacientovu mysl.",
    name = "Králův Komplex",
    symptoms = "Příznaky - Nošení barevné semišové obuvi a nadměrné jezení cheeseburgerů.",
  },
  autopsy = {
    name = "Pitva",
  },
  unexpected_swelling = {
    cure = "Léčba - Otok může být zmenšen sadou akupunkturních jehel během operace, vyžadující dva Chirurgy.",
    cause = "Příčina - Cokoliv nečekaného.",
    name = "Nečekaný Otok",
    symptoms = "Příznak - Nečekaný otok.",
  },
  third_degree_sideburns = {
    cure = "Léčba - Zaměstnanci Psychologie musí, za použití moderních technik, přesvědčit pacienta, jak špatně jeho účes vypadá.",
    cause = "Příčina - Melancholická touha po návratu 70. let",
    name = "Licousy 3. stupně",
    symptoms = "Příznaky - Velké vlasy, světlice, platformy a jiskřivý make-up.",
  },
  pregnancy = {
    cure = "Léčba - Dítě je odstraněno na Operačním Sále, umyto a představeno pacientovi.",
    cause = "Příčina - Alespoň jeden muž.",
    name = "Těhotenství",
    symptoms = "Příznaky - Neustávající touha jíst a nepřehlédnutelné pivní panděro.",
  },
  diag_scanner = {
    name = "Vyše Skener",
  },
  tv_personalities = {
    cure = "Léčba - Vyškolený Psychiatr musí přesvědčit pacienta, aby prodal svoji TV a koupil si rádio.",
    cause = "Příčina - Každodenní sledování televize.",
    name = "TV Osobnost",
    symptoms = "Příznaky - Postiženému se zdá, že by mohl být Klukem v akci.",
  },
}
pay_rise = {
  poached = "%s mi nabídl %d. Jestliže mi nebudete platit stejně, tak jdu pryč.",
  regular = {
    [1] = "Jsem naprosto vyčerpaný. Potřebuji si hodně odpočinout, navíc chci zvýšit plat o %d, pokud nechcete, abych tuto blbou práci pověsil na hřebík.",
    [2] = "Jsem velmi unavený. Potřebuji si odpočinout a zvýšit plat o %d, což celkově bude %d. Udělejte to hned, Vy despoto.",
    [3] = "No tak. Dřu tady jako kůň. Dejte mi bonus %d a já zůstanu ve vaší nemocnici.",
    [4] = "Jsem velmi nešťastný. Požaduji zvýšení o %d, tím můj plat bude %d, jinak odcházím.",
    [5] = "Mí rodiče mi říkali, že zdravotnická profese má dobré platy. Takže mi zvyšte plat o %d, jinak se stanu producentem počítačových her.",
    [6] = "Jsem naštvaný. Máte mi platit slušnou mzdu. Myslím si, že zvýšení o %d by mělo stačit.",
  },
  definite_quit = "Nic, co můžete udělat, mě tu neudrží. Mám tohoto místa plné zuby.",
}
menu_list_window = {
  back = "Zpátky",
  save_date = "Uloženo",
  name = "Název",
}
misc = {
  low_res = "Nízké rozli.",
  send_message = "Poslat zprávu hráči %d",
  send_message_all = "Poslat zprávu všem hráčům",
  done = "Vše Hotovo",
  pause = "Pozastavit",
  no_heliport = "Buď ještě nebyly objeveny žádné nemoci, nebo na této mapě není heliport.",
  cant_treat_emergency = "Vaše nemocnice nemůže řešit tuto pohotovost, protože tuto nemoc jste ještě nevyzkoumali.",
  save_success = "Hra v Pořádku Uložena",
  not_yet_implemented = "(není ještě zavedeno)",
  force = "Donutit",
  mouse = "Myš",
  grade_adverb = {
    extremely = "extrémně",
    moderately = "středně",
    mildly = "mírně",
  },
  balance = "Soubor Rovnováhy:",
  hospital_open = "Nemocnice Otevřena",
  out_of_sync = "Hra není synchronizována",
  save_failed = "CHYBA: Hru Nelze Uložit",
  load_failed = "Uloženou hru nelze načíst",
}
progress_report = {
  win_criteria = "KRITÉRIA VÍTĚZSTVÍ",
  more_drinks_machines = "Postavte více automatů na nápoje. ",
  quite_unhappy = "Vaši lidé jsou lehce nešťastní. ",
  too_cold = "Je tu příliš velká zima. Umístěte radiátory. ",
  header = "Hlášení o Postupu",
  free_build = "VOLNÉ STAVĚNÍ",
  too_hot = "Přehodnoťte váš systém vytápění. Je tu příliš vedro. ",
  percentage_pop = "% populace",
  very_unhappy = "Vaši lidé jsou opravdu nešťastní. ",
}
new_game_window = {
  easy = "Rezident (Jednoduché)",
  cancel = "Zrušit",
  caption = "Kampaň",
  difficulty = "Obtížnost",
  option_off = "Vypnuto",
  option_on = "Zapnuto",
  tutorial = "První hra",
  hard = "Konzultant (Těžké)",
  medium = "Doktor (Střední)",
  start = "Zahájit",
  player_name = "Jméno hráče",
}
date_format = {
  daymonth = "%1% %2:months%",
}
research = {
  allocated_amount = "Přidělené Množství",
  funds_allocation = "Přidělení Financí",
  categories = {
    cure = "Nástroje pro Léčbu",
    drugs = "Výzkum Léků",
    improvements = "Vylepšení",
    diagnosis = "Diagnostické Nástroje",
    specialisation = "Specializace",
  },
}
bank_manager = {
  current_loan = "Současná Půjčka",
  balance = "Bilance",
  interest_payment = "Platba Úroků",
  hospital_value = "Hodnota Nemocnice",
  interest_rate = "Úroková Míra",
  statistics_page = {
    balance = "Bilance",
    current_balance = "Současná Bilance",
    date = "Datum",
    details = "Podrobnosti",
    money_out = "Náklady",
    money_in = "Příjmy",
  },
  inflation_rate = "Míra Inflace",
  insurance_owed = "Dluh na Pojištění",
}
casebook = {
  cure = "Léčba",
  treatment_charge = "Poplatek za Vyšetření",
  reputation = "Reputace",
  research = "Soustředit Výzkum",
  sent_home = "Odmítnuto",
  deaths = "Úmrtí",
  earned_money = "Vyděláno Peněz",
  cure_desc = {
    hire_surgeons = "Potřebujete zaměstnat Chirurgy.",
    improve_cure = "Zlepšit léčbu.",
    no_cure_known = "Žádná známá léčba.",
    build_room = "Doporučuji, abyste postavili %s",
    hire_nurses = "Měli byste zaměstnat pár Sester.",
    build_ward = "Stále potřebujete postavit Lůžkové Oddělení.",
    hire_psychiatrists = "Musíte zaměstnat Psychiatry.",
    cure_known = "Léčba.",
    hire_doctors = "Potřebujete zaměstnat pár Doktorů.",
  },
  cured = "Uzdravení",
}
original_credits = {
  [1] = " ",
  [2] = " ",
  [3] = " ",
  [4] = " ",
  [5] = " ",
  [6] = " ",
  [7] = " ",
  [8] = " ",
  [9] = " ",
  [10] = " ",
  [11] = " ",
  [12] = ":Navrhl a vytvořil",
  [13] = ":Bullfrog Productions",
  [14] = " ",
  [15] = ":Pluto Development Team",
  [16] = ",",
  [17] = "Mark Webley",
  [18] = "Gary Carr",
  [19] = "Matt Chilton",
  [20] = "Matt Sullivan",
  [21] = "Jo Rider",
  [22] = "Rajan Tande",
  [23] = "Wayne Imlach",
  [24] = "Andy Bass",
  [25] = "Jon Rennie",
  [26] = "Adam Coglan",
  [27] = "Natalie White",
  [28] = " ",
  [29] = " ",
  [30] = " ",
  [31] = ":Programování",
  [32] = ",",
  [33] = "Mark Webley",
  [34] = "Matt Chilton",
  [35] = "Matt Sullivan",
  [36] = "Rajan Tande",
  [37] = " ",
  [38] = " ",
  [39] = " ",
  [40] = ":Grafika",
  [41] = ",",
  [42] = "Gary Carr",
  [43] = "Jo Rider",
  [44] = "Andy Bass",
  [45] = "Adam Coglan",
  [46] = " ",
  [47] = " ",
  [48] = " ",
  [49] = ":Dodatečné programování",
  [50] = ",",
  [51] = "Ben Deane",
  [52] = "Gary Morgan",
  [53] = "Jonty Barnes",
  [54] = " ",
  [55] = " ",
  [56] = " ",
  [57] = ":Dodatečná grafika",
  [58] = ",",
  [59] = "Eoin Rogan",
  [60] = "George Svarovsky",
  [61] = "Saurev Sarkar",
  [62] = "Jason Brown",
  [63] = "John Kershaw",
  [64] = "Dee Lee",
  [65] = " ",
  [66] = " ",
  [67] = " ",
  [68] = ":Úvodní video",
  [69] = ",",
  [70] = "Stuart Black",
  [71] = " ",
  [72] = " ",
  [73] = " ",
  [74] = ":Hudba a zvukové Efekty",
  [75] = ",",
  [76] = "Russell Shaw",
  [77] = "Adrian Moore",
  [78] = " ",
  [79] = " ",
  [80] = " ",
  [81] = ":Dodatečná hudba",
  [82] = ",",
  [83] = "Jeremy Longley",
  [84] = "Andy Wood",
  [85] = " ",
  [86] = " ",
  [87] = " ",
  [88] = ":Hlas oznamovatelky",
  [89] = ",",
  [90] = "Rebecca Green",
  [91] = " ",
  [92] = " ",
  [93] = " ",
  [94] = ":Návrh úrovní",
  [95] = ",",
  [96] = "Wayne Imlach",
  [97] = "Natalie White",
  [98] = "Steven Jarrett",
  [99] = "Shin Kanaoya",
  [100] = " ",
  [101] = " ",
  [102] = " ",
  [103] = ":Skriptování",
  [104] = ",",
  [105] = "James Leach",
  [106] = "Sean Masterson",
  [107] = "Neil Cook",
  [108] = " ",
  [109] = " ",
  [110] = " ",
  [111] = ":Výzkum a vývoj",
  [112] = " ",
  [113] = ":Grafické jádro",
  [114] = ",",
  [115] = "Andy Cakebread",
  [116] = "Richard Reed",
  [117] = " ",
  [118] = " ",
  [119] = " ",
  [120] = ":Podpora výzkumu a vývoje",
  [121] = ",",
  [122] = "Glenn Corpes",
  [123] = "Martin Bell",
  [124] = "Ian Shaw",
  [125] = "Jan Svarovsky",
  [126] = " ",
  [127] = " ",
  [128] = " ",
  [129] = ":Knihovny a nástroje",
  [130] = " ",
  [131] = "Knihovna Dos a Win 95",
  [132] = ",",
  [133] = "Mark Huntley",
  [134] = "Alex Peters",
  [135] = "Rik Heywood",
  [136] = " ",
  [137] = " ",
  [138] = " ",
  [139] = ":Síťová knihovna",
  [140] = ",",
  [141] = "Ian Shippen",
  [142] = "Mark Lamport",
  [143] = " ",
  [144] = " ",
  [145] = " ",
  [146] = ":Zvuková knihovna",
  [147] = ",",
  [148] = "Russell Shaw",
  [149] = "Tony Cox",
  [150] = " ",
  [151] = " ",
  [152] = " ",
  [153] = ":Programování instalátoru",
  [154] = ",",
  [155] = "Andy Nuttall",
  [156] = "Tony Cox",
  [157] = "Andy Cakebread",
  [158] = " ",
  [159] = " ",
  [160] = " ",
  [161] = ":Morální podpora",
  [162] = ",",
  [163] = "Peter Molyneux",
  [164] = " ",
  [165] = " ",
  [166] = " ",
  [167] = ":Manažer testování",
  [168] = ",",
  [169] = "Andy Robson",
  [170] = " ",
  [171] = " ",
  [172] = " ",
  [173] = ":Hlavní testeři",
  [174] = ",",
  [175] = "Wayne Imlach",
  [176] = "Jon Rennie",
  [177] = " ",
  [178] = " ",
  [179] = " ",
  [180] = ":Testeři hraní",
  [181] = ",",
  [182] = "Jeff Brutus",
  [183] = "Wayne Frost",
  [184] = "Steven Lawrie",
  [185] = "Tristan Paramor",
  [186] = "Nathan Smethurst",
  [187] = " ",
  [188] = "Ryan Corkery",
  [189] = "Simon Doherty",
  [190] = "James Dormer",
  [191] = "Martin Gregory",
  [192] = "Ben Lawley",
  [193] = "Joel Lewis",
  [194] = "David Lowe",
  [195] = "Robert Monczak",
  [196] = "Dominic Mortoza",
  [197] = "Karl O'Keeffe",
  [198] = "Michael Singletary",
  [199] = "Andrew Skipper",
  [200] = "Stuart Stephen",
  [201] = "David Wallington",
  [202] = " ",
  [203] = "A všichni naši ostatní zkušení testeři hraní",
  [204] = " ",
  [205] = " ",
  [206] = " ",
  [207] = ":Technická podpora",
  [208] = ",",
  [209] = "Kevin Donkin",
  [210] = "Mike Burnham",
  [211] = "Simon Handby",
  [212] = " ",
  [213] = " ",
  [214] = " ",
  [215] = ":Marketing",
  [216] = ",",
  [217] = "Pete Murphy",
  [218] = "Sean Ratcliffe",
  [219] = " ",
  [220] = " ",
  [221] = " ",
  [222] = ":Děkujeme:",
  [223] = ",",
  [224] = "Tamara Burke",
  [225] = "Annabel Roose",
  [226] = "Chris Morgan",
  [227] = "Pete Larsen",
  [228] = " ",
  [229] = " ",
  [230] = " ",
  [231] = ":PR",
  [232] = ",",
  [233] = "Cathy Campos",
  [234] = " ",
  [235] = " ",
  [236] = " ",
  [237] = ":Dokumentace",
  [238] = ",",
  [239] = "Mark Casey",
  [240] = "Richard Johnston",
  [241] = "James Lenoel",
  [242] = "Jon Rennie",
  [243] = " ",
  [244] = " ",
  [245] = " ",
  [246] = ":Úprava dokumentace a balení",
  [247] = ",",
  [248] = "Caroline Arthur",
  [249] = "James Nolan",
  [250] = " ",
  [251] = " ",
  [252] = " ",
  [253] = ":Manažer lokalizace projektu",
  [254] = ",",
  [255] = "Carol Aggett",
  [256] = " ",
  [257] = " ",
  [258] = " ",
  [259] = ":Lokalizace",
  [260] = ",",
  [261] = "Sandra Picaper",
  [262] = "Sonia 'Sam' Yazmadjian",
  [263] = " ",
  [264] = "Bettina Klos",
  [265] = "Alexa Kortsch",
  [266] = "Bianca Normann",
  [267] = " ",
  [268] = "C.T.O. S.p.A. Zola Predosa (BO)",
  [269] = "Gian Maria Battistini",
  [270] = "Maria Ziino",
  [271] = "Gabriele Vegetti",
  [272] = " ",
  [273] = "Elena Ruiz de Velasco",
  [274] = "Julio Valladares",
  [275] = "Ricardo Martínez",
  [276] = " ",
  [277] = "Kia Collin",
  [278] = "CBG Consult",
  [279] = "Ulf Thor",
  [280] = " ",
  [281] = " ",
  [282] = " ",
  [283] = ":Produkce",
  [284] = ",",
  [285] = "Rachel Holman",
  [286] = " ",
  [287] = " ",
  [288] = " ",
  [289] = ":Producent",
  [290] = ",",
  [291] = "Mark Webley",
  [292] = " ",
  [293] = " ",
  [294] = " ",
  [295] = ":Vedoucí výroby",
  [296] = ",",
  [297] = "Andy Nuttall",
  [298] = " ",
  [299] = " ",
  [300] = " ",
  [301] = ":Operace",
  [302] = ",",
  [303] = "Steve Fitton",
  [304] = " ",
  [305] = " ",
  [306] = " ",
  [307] = ":Správa společnosti",
  [308] = ",",
  [309] = "Audrey Adams",
  [310] = "Annette Dabb",
  [311] = "Emma Gibbs",
  [312] = "Lucia Gobbo",
  [313] = "Jo Goodwin",
  [314] = "Sian Jones",
  [315] = "Kathy McEntee",
  [316] = "Louise Ratcliffe",
  [317] = " ",
  [318] = " ",
  [319] = " ",
  [320] = ":Vedení společnosti",
  [321] = ",",
  [322] = "Les Edgar",
  [323] = "Peter Molyneux",
  [324] = "David Byrne",
  [325] = " ",
  [326] = " ",
  [327] = ":Všichni v Bullfrog Productions",
  [328] = " ",
  [329] = " ",
  [330] = " ",
  [331] = ":Zvláštní poděkování",
  [332] = ",",
  [333] = "Všem ve Frimley Park Hospital",
  [334] = " ",
  [335] = ":Zvláště",
  [336] = ",",
  [337] = "Beverley Cannell",
  [338] = "Doug Carlisle",
  [339] = " ",
  [340] = " ",
  [341] = " ",
  [342] = ":Nepřestávejte myslet",
  [343] = " ",
  [344] = " ",
  [345] = " ",
  [346] = " ",
  [347] = " ",
  [348] = " ",
  [349] = " ",
  [350] = " ",
  [351] = " ",
  [352] = " ",
  [353] = " ",
  [354] = " ",
  [355] = " ",
  [356] = " ",
  [357] = " ",
  [358] = " ",
  [359] = " ",
  [360] = " ",
  [361] = ".",
}
competitor_names = {
  [1] = "RATH",
  [2] = "PRYMULA",
  [3] = "FANTOMAS",
  [4] = "DLAHA",
  [5] = "MENDEL",
  [6] = "ŠPIDLA",
  [7] = "KENTÁN",
  [8] = "JANOUŠEK",
  [9] = "CIMRMAN",
  [10] = "OZZÁK",
  [11] = "HAMLET",
  [12] = "JÁNOŠÍK",
  [13] = "WICHTERLE",
  [14] = "HIPPOKRATÉS",
  [15] = "MRÁČEK",
  [16] = "BABICA",
  [17] = "CHEWBACCA",
  [18] = "FAUST",
  [19] = "DRACULA",
  [20] = "BOHOUŠEK",
  [21] = "BOND",
  [22] = "PAROUBEK",
  [23] = "SÁMO",
  [24] = "EVŽEN",
}
staff_title = {
  general = "Praktický",
  doctor = "Doktor",
  nurse = "Sestra",
  psychiatrist = "Psychiatr",
  receptionist = "Recepční",
  researcher = "Výzkumník",
  junior = "Rezident",
  surgeon = "Chirurg",
  consultant = "Konzultant",
}
room_descriptions = {
  gp = {
    [1] = "Kancelář Praktického Lékaře\n\n",
    [2] = "Toto je základní vyšetřovací místnost ve vaší nemocnici. Její dominantou je velmi chytrý počítač s doktorem, který je jediný schopen odhadnout diagnózu. Proto jsou sem posíláni všichni pacienti. Čím větší je místnost a čím více předmětů do ní umístíte, tím vyšší je prestiž doktora (to platí pro všechny místnosti).\n\n",
    [3] = "Kancelář Praktického Lékaře vyžaduje jakéhokoliv Doktora. ",
  },
  x_ray = {
    [1] = "Rentgen\n\n",
    [2] = "Rentgen pořizuje snímky vnitřku pacientů použitím rentgenového záření, čímž zaměstnancům poskytuje dobrou představu o tom, co se v nich nachází.\n\n",
    [3] = "Rentgen vyžaduje jakéhokoliv Doktora. Také potřebuje údržbu. ",
  },
  toilets = {
    [1] = "Toalety\n\n",
    [2] = "Pacienti, kteří cítí volání přírody, si budou muset ulehčit v pohodlí vašich toaletních zařízení. Můžete postavit další kabinky a umyvadla pokud očekáváte spousty návštěvníků. V některých případech byste mohli zvážit postavit další zařízení někde jinde v nemocnici. ",
  },
  tv_room = {
    [1] = "TV MÍSTNOST NENÍ POUŽITA",
  },
  general_diag = {
    [1] = "Vyšetřovna\n\n",
    [2] = "Pacienti, kteří vyžadují další vyšetření, jsou sem posláni na kontrolu. Pokud praktický lékař nepřijde na to, co je s pacientem špatně, na Vyšetřovně se na to často přijde. Odtud je poslán zpátky do kanceláře praktika k analýze výsledků z tohoto vyšetření.\n\n",
    [3] = "Vyšetřovna vyžaduje jakéhokoliv Doktora. ",
  },
  hair_restoration = {
    [1] = "Klinika Obnovy Vlasů\n\n",
    [2] = "Pacienti trpící extrémním případem Plešatosti budou nasměrování směrem k Sázeči Vlasů v této Klinice. Doktor bude obsluhovat stroj, který rychle zasází pacientovu hlavu novými vlasy přijatelné kvality.\n\n",
    [3] = "Klinika Obnovy Vlasů vyžaduje jakéhokoliv Doktora. Také vyžaduje pravidelnou údržbu. ",
  },
  ward = {
    [1] = "Lůžkové Oddělení\n\n",
    [2] = "Pacienti jsou zde drženi na pozorování, které zajišťuje Sestra. Zůstávají zde mimo jiné před provedením operace. Některým slouží poležení s čajem s citronem i jako léčba.\n\n",
    [3] = "Lůžkové Oddělení vyžaduje alespoň jednu Sestru. ",
  },
  scanner = {
    [1] = "Skener\n\n",
    [2] = "Pacienti jsou přesně vyšetřeni použitím důmyslného Skeneru. Následně si jdou pro vásledky k praktickému lékaři.\n\n",
    [3] = "Skener vyžaduje jakéhokoliv Doktora. Také vyžaduje údržbu. ",
  },
  slack_tongue = {
    [1] = "ORL (Ochablojazyková Rychlá Léčba)\n\n",
    [2] = "Pacienti s diagnózou Ochablého Jazyka jsou posláni na tuto kliniku k vyléčení. Doktor použije velmi moderní a precizní přístroj k natáhnutí a ušmiknutí jazyka, čímž jej navrátí do správné podoby.\n\n",
    [3] = "ORL vyžaduje jakéhokoliv Doktora. Také občas potřebuje údržbu. ",
  },
  cardiogram = {
    [1] = "Kardiogram\n\n",
    [2] = "Nesportovní pacienti jsou zde podrobeni nenáviděnému běhu, čímž se jim vzteky zvýší tlak. Tato hodnota pomáhá praktikovi stanovit diagnózu.\n\n",
    [3] = "Kardiogram vyžaduje jakéhokoliv Doktora. Také vyžaduje údržbu. ",
  },
  decontamination = {
    [1] = "Dekontaminační Klinika\n\n",
    [2] = "Pacienti, kteří byli vystaveni Radiaci, jsou rychle odkázáni na Dekontaminační Kliniku. V této místnosti se nachází Dekontaminační sprcha, ve které jsou pacienti nejdříve omyti vodou a mýdlem a nakonec důkladně vykartáčováni.\n\n",
    [3] = "Dekontaminační Sprcha vyžaduje jakéhokoliv Doktora. Také potřebuje kontroly Údržbáře. ",
  },
  dna_fixer = {
    [1] = "Genex 2000\n\n",
    [2] = "Pacientům, jejichž DNA obsahuje mimo jiné geny pro zelenou kůži, musí být DNA vyjmuta, důkladně vyčištěna a navrácena zpět ve všech buňkách. Přístroj Genex 2000 je velmi složitý kus vybavení a není od věci mít u něj hasicí přístroj.\n\n",
    [3] = "Přístroj Genex 2000 vyžaduje pravidelnou kontrolu od Údržbáře. Také vyžaduje Doktora s Výzkumnou kvalifikací k jeho fungování. ",
  },
  training = {
    [1] = "Učebna\n\n",
    [2] = "Vaši Rezidenti a Doktoři můžou studiem v této místnosti získat cenné další kvalifikace. Konzultant s Chirurgickými, Výzkumnými nebo Psychiatrickými dovednostmi je předá na všechny Doktory, kteří jsou zde vyučování. Doktoři, kteří už tyto dovednosti mají, náhle zjistí, že je mohou používat efektivněji.\n\n",
    [3] = "Učebna vyžaduje Konzultanta k výuce. ",
  },
  electrolysis = {
    [1] = "Místnost Elektrolýzy\n\n",
    [2] = "Pacienti s Vlasitidou jsou posláni do této místnosti, kde zvláštní přístroj jménem Elektrolyzér elektricky vlasy vytrhne a uzavře póry použitím směsi ne nepodobné maltě.\n\n",
    [3] = "Elektrolyzér vyžaduje jakéhokoliv Doktora. Také potřebuje údržbu od Údržbáře. ",
  },
  jelly_vat = {
    [1] = "Klinika Slizu\n\n",
    [2] = "Pacienti prokletí srandovní nemocí Slizitidou se musí dokymácet do Kliniky Slizu a být umístěni do Formy na Sliz. Vyléčí je to způsobem, který stále není ve zdravotnických kruzích plně pochopen.\n\n",
    [3] = "Klinika Slizu vyžaduje jakéhokoliv Doktora. Také potřebuje Údržbáře pro údržbu. ",
  },
  research = {
    [1] = "Výzkumná Laboratoř\n\n",
    [2] = "Nové léky a postupy léčby vymýšlí a zdokonalují mozky ve Výzkumné Laboratoři. Toto je důležitá část vaší nemocnice, která bude dělat zázraky ve vašich procentech vyléčených.\n\n",
    [3] = "Výzkumná Laboratoř vyžaduje doktora s Výzkumnými dovednostmi. ",
  },
  inflation = {
    [1] = "Hustírna\n\n",
    [2] = "Pacienti s bolestivou (i když legrační) nemocí Nafouknutá Hlava musí přijít do Hustírny, kde je předimenzovaná lebka opatrně vyfouknuta a nahuštěna na správný tlak.\n\n",
    [3] = "Hustírna vyžaduje jakéhokoliv Doktora. Také vyžaduje soustavnou obsluhu od Údržbáře. ",
  },
  no_room = {
    [1] = "",
  },
  blood_machine = {
    [1] = "Hemogram\n\n",
    [2] = "Hemogram je kus vyšetřovacího vybavení, které kontroluje buňky v pacientově krvi. Pokud mají špatnou barvu, dá se tento poznatek využít k diagnóze.\n\n",
    [3] = "Hemogram vyžaduje jakéhokoliv Doktora. Také vyžaduje údržbu. ",
  },
  psych = {
    [1] = "Psychiatrie\n\n",
    [2] = "Pacienti s diagnózou psychiatrické nemoci musí navštívit Psychiatrii, kde na ně čeká psychiatr na pohodlném křesle. Oni si následně lehnou na jetou pohovku a jsou správně diagnostikováni a případně rovnou i léčení použitím magie a úplatků.\n\n",
    [3] = "Psychiatrie vyžaduje Psychiatricky vyučeného Doktora. ",
  },
  fracture_clinic = {
    [1] = "Oddělení Zlomenin\n\n",
    [2] = "Ti pacienti, kteří mají takovou smůlu, že mají Zlomené Kosti, se dobelhají sem. Přístroj na Odstranění Sádry použije účinné průmyslové lasery k uříznutí jakékoli zatuhnuté sádry, což pacienta jen „lehce štípne“.\n\n",
    [3] = "Oddělení Zlomenin vyžaduje Sestru. Také čas od času vyžaduje údržbu. ",
  },
  ultrascan = {
    [1] = "Ultrasken\n\n",
    [2] = "Ultrasken je složitě vyvinutý skener schopný přiblížení 1,1x. Cena je sice vysoká, ale díky svým úžasným schopnostem dokáže lépe a rychleji diagnostikovat pacienty.\n\n",
    [3] = "Ultrasken vyžaduje jakéhokoliv Doktora. Také vyžaduje údržbu. ",
  },
  staff_room = {
    [1] = "Místnost pro Zaměstnance\n\n",
    [2] = "Vaši zaměstnanci se při provádění jejich práce unaví. Tuto místnost potřebují, aby si odpočinuli a obnovili síly. Unavení zaměstnanci jsou pomalí, požadují více peněz a nakonec odejdou. Také dělají více chyb. Postavení místnosti pro debatní kroužky a možnost závislosti na videohrách je od únavy odradí. Ujistěte se, že je tam místo pro více zaměstnanců najednou. ",
  },
  pharmacy = {
    [1] = "Lékárna\n\n",
    [2] = "Pacienti, kteří byli vyšetřeni a kterým je předepsán nějaký tajný lektvar, musí navštívit Lékárnu, aby si ho vzali. Je dobré zmínit, že lektvarů budete muset míchat hodně, takže možná byste mohli chtít později postavit další Lékárnu.\n\n",
    [3] = "Lékárna vyžaduje Sestru. ",
  },
  operating_theatre = {
    [1] = "Operační Sál\n\n",
    [2] = "Na tomto místě probíhají veškeré chirurgické zákroky (rozumějte rituály s trochou černé magie). Jedná se o často používanou součást nemocnice.\n\n",
    [3] = "Operační Sál vyžaduje dva Doktory s Chirurgickými kvalifikacemi. ",
  },
}
queue_window = {
  num_expected = "Očekáváno",
  num_entered = "Počet Návštěvníků",
  max_queue_size = "Max Velikost",
  num_in_queue = "Velikost Fronty",
}
debug_patient_window = {
  caption = "Pacient pro Ladění",
}
totd_window = {
  next = "Další Rada",
  previous = "Předchozí Rada",
  tips = {
    [1] = "Každá nemocnice potřebuje recepci a Kancelář Praktického Lékaře, aby mohla fungovat. Poté záleží na tom, jací pacienti navštěvují vaši nemocnici. Lékárna je ale vždycky dobrá volba.",
    [2] = "Přístroje, jako je Nafukovač, potřebují údržbu. Zaměstnejte jednoho nebo dva údržbáře pro opravu vašich přístrojů, jinak riskujete, že se vaši pacienti a zaměstnanci zraní.",
    [3] = "Po chvíli se vaši zaměstnanci unaví. Ujistěte se, že postavíte místnost pro zaměstnance, aby si mohli odpočinout.",
    [4] = "Umístěte dostatek radiátorů, aby vašim pacientům a zaměstnancům bylo teplo, jinak budou nešťastní. Použijte mapu města k nalezení míst ve vaší nemocnici, která potřebují více vytápění.",
    [5] = "Doktorova úroveň dovedností vysoce ovlivňuje kvalitu a rychlost jeho diagnóz. Umístěte zkušeného doktora do vaší kanceláře a nebudete potřebovat tolik dodatečných diagnostických místností.",
    [6] = "Rezidenti a doktoři můžou své dovednosti zlepšit výukou od konzultanta v učebně. Pokud konzultant má zvláštní kvalifikace (chirurg, psychiatr nebo výzkumník), tak také tyto vědomosti předá svým žákům.",
    [7] = "Zkusili jste zadat evropské číslo tísňového volání (112) do faxu? Nezapomeňte si zapnout zvuk!",
    [8] = "Jistá nastavení, jako např. rozlišení obrazovky a jazyk, můžete upravit v okně nastavení, které naleznete jak v hlavním menu, tak i ve hře.",
    [9] = "Vybrali jste jiný jazyk než angličtina, ale přesto je všude anglický text? Pomozte nám přeložit chybějící texty do vašeho jazyka!",
    [10] = "Tým CorsixTH hledá posily! Zajímá vás programování, překládání, nebo vytváření grafiky pro CorsixTH? Kontaktuje nás na našem Discordu, případně se podívejte na naše stránky.",
    [11] = "Pokud naleznete chybu, ohlaste ji prosím na našem sledovači chyb: th-issues.corsix.org",
    [12] = "Každá úroveň má jisté požadavky, které musíte splnit předtím, než můžete pokračovat do další. Podívejte se na okno stavu, abyste viděli váš postup směrem ke splnění úkolů úrovně.",
    [13] = "Pokud chcete upravit nebo odstranit existující místnost, můžete tak učinit pomocí tlačítka úpravy místnosti, které naleznete dole na panelu nástrojů.",
    [14] = "V davu čekajících pacientů můžete rychle najít ty, kteří čekají na určitou místnost tím, že nad tuto místnost najedete kurzorem myši.",
    [15] = "Klikněte na dveře místnosti, abyste viděli její frontu. Zde můžete udělat drobné úpravy, jako např. změnit pořadí fronty nebo poslat pacienta do jiné místnosti.",
    [16] = "Nešťastní zaměstnanci budou žádat o zvýšení platu častěji. Ujistěte se, že vaši zaměstnanci pracují v pohodlném prostředí, abyste tomuto zabránili.",
    [17] = "Pacienti budou mít žízeň, zatímco čekají ve vaší nemocnici, a pokud zvýšite teplotu, bude ještě vyšší! Umístěte Automaty na Nápoje ve strategických pozicích pro dodatečný příjem.",
    [18] = "Můžete předčasně ukončit proces vyšetření a hádat léčbu, pokud jste se již s nemocí setkali. Uvědomte si ale, že toto může zvýšit riziko špatné léčby, což způsobí smrt pacienta.",
    [19] = "Pohotovost může být dobrým zdrojem peněz navíc, za předpokladu, že máte dostatečné kapacity na včasné zvládnutí pohotovostních pacientů.",
  },
}
information = {
  custom_game = "Vítejte v CorsixTH. Užijte si tuto vlastní mapu!",
  cannot_restart = "Bohužel, tato hra byla uložena předtím, než byla zavedena funkce restart.",
  no_custom_game_in_demo = "Je nám líto, ale ve zkušební verzi nemůžete hrát žádné vlastní mapy.",
  very_old_save = "Od spuštění této úrovně došlo k mnoha aktualizacím. Aby bylo zajištěno, že všechny funkce pracují tak, jak mají, zvažte restartování této úrovně.",
  cheat_not_possible = "Tento cheat nemůžete použít v této úrovni. Už ani podvádět Vám nejde, to je život, co?",
  level_lost = {
    [1] = "To se úplně nepovedlo. Hodně štěstí příště!",
    [2] = "Důvod, proč jste prohráli:",
    reputation = "Vaše reputace se kamsi vytratila, spadla pod %d.",
    balance = "Vaše bankovní bilance spadla pod bod mrazu, konkrétně pod %d.",
    percentage_killed = "Jsme nemocnice, ne jatka. Zabili jste více než %d procent pacientů.",
    cheat = "Tohle jste chtěli, či jste snad zvolili špatné tlačítko? To vám ani nejde podvádět? Tady máte lopatu a jděte se zahrabat.",
  },
}
errors = {
  minimum_screen_size = "Zadejte prosím alespoň 640x480 jako rozlišení obrazovky.",
  map_file_missing = "Nelze nalézt soubor s mapou %s pro tuto úroveň!",
  dialog_missing_graphics = "Je nám líto, datové soubory demoverze toto dialogové okno neobsahují.",
  load_prefix = "Chyba při načtení hry: ",
  unavailable_screen_size = "Rozlišení obrazovky, které požadujete, není dostupné v režimu celé obrazovky.",
  save_prefix = "Chyba při uložení hry: ",
  alien_dna = "POZNÁMKA: Pro animaci s Mimozemskou DNA neexistují animace pro sednutí, otevírání nebo klepání na dveře atd. Proto se při těchto činnostech, stejně jako v Theme Hospital, dočasně změní na normálně vypadající pacienty a pak se změní zpět. Tyto pacienti se v nemocnici objeví pouze při nastavení v souboru úrovně",
  fractured_bones = "POZNÁMKA: Animace ženských pacientů se Zlomenými kostmi není dokonalá",
  load_quick_save = "Chyba! Rychle uloženou pozici nelze načíst, protože neexistuje. Není třeba se obávat, hned jsme jednu pro Vás vytvořili!",
  no_games_to_contine = "Žádné uložené hry.",
  could_not_load_campaign = "Nelze načíst kampaň: %s",
  could_not_find_first_campaign_level = "Nelze načíst první úroveň této kampaně: %s",
  save_to_tmp = "Soubor %s nemohl být použit. Hra byla proto uložena do %s. Chyba: %s",
  dialog_empty_queue = "Postava aktuálně nemá nic na práci ve své řadě úloh, a tak neví, co má dělat dále. Zkontrolujte příkazové okno pro více informací. Jednáme s tímto potížistou. Chcete ho z nemocnice vyhodit?",
  compatibility_error = {
    new_in_old = "Pozor! Tato hra byla uložena v novější verzi CorsixTH a není kompatibilní. Pro hraní aktualizujte na novější verzi CorsixTH.",
  },
}
menu = {
  charts = "  GRAFY  ",
  options = "  NASTAVENÍ  ",
  file = "  SOUBOR  ",
  display = "  ZOBRAZENÍ  ",
  debug = "  LADĚNÍ  ",
  player_count = "POČET HRÁČŮ",
}
lua_console = {
  close = "Zavřít",
  execute_code = "Spustit",
}
menu_options = {
  edge_scrolling = "    POSUNOVÁNÍ OKRAJŮ  ",
  autosave = "    AUTOMATICKÉ ULOŽENÍ  ",
  game_speed = "    RYCHLOST HRY  ",
  sound_vol = "    HLASITOST ZVUKU  ",
  announcements = "  (%1%) OZNÁMENÍ   ",
  lock_windows = "    UZAMKNOUT OKNA  ",
  music = "   (%1%) HUDBA   ",
  adviser_disabled = "   (%1%) PORADCE  ",
  music_vol = "   HLASITOST HUDBY  ",
  sound = "   (%1%) ZVUK   ",
  announcements_vol = "    HLASITOST OZNÁMENÍ  ",
  jukebox = "   (%1%) JUKEBOX  ",
  warmth_colors = "    BARVY TEPLOTY",
  twentyfour_hour_clock = "    24HODINOVÝ REŽIM  ",
  wage_increase = "    MZDOVÉ POŽADAVKY",
  capture_mouse = "  ZACHYCOVAT KURZOR  ",
}
menu_options_warmth_colors = {
  choice_2 = "     MODRÁ ZELENÁ ČERVENÁ ",
  choice_1 = "     ČERVENÁ ",
  choice_3 = "     ŽLUTÁ ORANŽOVÁ ČERVENÁ ",
}
menu_debug = {
  cheats = "    (%1%) CHEATY  ",
  win_level_anim = "    ANIM VÝHRY ÚROVNĚ       ",
  enter_nav_debug = "    VSTOUPIT DO LADĚNÍ NAV      ",
  object_cells = "    BUŇKY OBJEKTU         ",
  show_nav_cells = "    ZOBRAZIT BUŇKY NAV       ",
  dump_strings = "   (%1%) VYPSAT ŘETĚZCE  ",
  disable_salary_raise = "    ZAKÁZAT ZVYŠOVÁNÍ PLATU  ",
  display_pager = "    ZOBRAZIT PAGER        ",
  make_debug_patient = "    VYTVOŘIT PACIENTA PRO LADĚNÍ  ",
  keep_clear_cells = "    UDRŽET ČISTÉ BUŇKY     ",
  show_help_hotspot = "    ZOBRAZIT AKTIVNÍ BODY NÁPOVĚDY   ",
  map_overlay = "    PŘEKRYV MAPY  ",
  remove_walls = "    ODSTRANIT ZDI         ",
  pixbuf_cells = "    BUŇKY VYRPPIX         ",
  plant_pagers = "    UMÍSTIT PAGERY         ",
  nav_bits = "    BITY NAV             ",
  sprite_viewer = "    PROHLÍŽEČ SPRITŮ  ",
  display_room_status = "    ZOBRAZIT STAV MÍSTNOSTI  ",
  machine_pagers = "    PAGERY PŘÍSTROJŮ       ",
  transparent_walls = "    (%1%) PRŮHLEDNÉ ZDI  ",
  limit_camera = "    OMEZIT KAMERU  ",
  make_debug_fax = "    VYTVOŘIT FAX LADĚNÍ  ",
  jump_to_level = "    SKOČIT DO ÚROVNĚ  ",
  win_game_anim = "    ANIM VÝHRY HRY        ",
  dump_gamelog = "    (%1%) VYPSAT ZÁZNAM HRY  ",
  entry_cells = "    BUŇKY VSTUPU          ",
  lose_game_anim = {
    [1] = "    ANIM PROHRY ÚROVNĚ 1     ",
    [2] = "    ANIM PROHRY ÚROVNĚ 2     ",
    [3] = "    ANIM PROHRY ÚROVNĚ 3     ",
    [4] = "    ANIM PROHRY ÚROVNĚ 4     ",
    [5] = "    ANIM PROHRY ÚROVNĚ 5     ",
    [6] = "    ANIM PROHRY ÚROVNĚ 6     ",
    [7] = "    ANIM PROHRY ÚROVNĚ 7     ",
  },
  calls_dispatcher = "    ROZVRHOVAČ VOLÁNÍ  ",
  remove_objects = "    ODSTRANIT OBJEKTY       ",
  lua_console = "    (%1%) KONZOLE LUA  ",
  mapwho_checking = "    KONTROLA MAPYKDO      ",
  display_big_cells = "    ZOBRAZIT VELKÉ BUŇKY    ",
  porter_pagers = "    PAGERY OBSLUHY        ",
  debug_script = "    (%1%) SPUSTIT SKRIPT PRO LADĚNÍ  ",
  connect_debugger = "    (%1%) PŘIPOJIT LUA DBGp SERVER  ",
  allow_blocking_off_areas = "  POVOLIT VYBLOKOVÁNÍ OBLASTÍ  ",
}
save_game_window = {
  caption = "Uložit Hru (%1%)",
  new_save_game = "Nová Uložená Hra",
}
main_menu = {
  custom_level = "Vlastní úroveň",
  load_game = "Načíst hru",
  options = "Nastavení",
  savegame_version = "Verze ukládaných her: ",
  version = "Verze: ",
  exit = "Ukončit",
  new_game = "Nová hra",
  continue = "Pokračovat ve hře",
  custom_campaign = "Vlastní kampaň",
  map_edit = "Editor map",
  updates_off = "Kontrola aktualizací vypnuta",
}
letter = {
  [1] = {
    [1] = "Vážený/á %s\n\n",
    [2] = "Úžasné! Zvládli jste provoz této nemocnice na výbornou. My pohlaváři na Ministerstvu Zdravotnictví bychom chtěli, abyste měli zájem o přijmutí většího projektu. Existuje práce, o které si myslíme, že je pro Vás dokonalá. Plat by byl %d$. Promyslete si to.\n\n",
    [3] = "Máte zájem o práci v Nemocnici %s?",
  },
  [2] = {
    [1] = "Vážený/á %s\n\n",
    [2] = "Výborně! Ve Vaší nemocnici jste udělali znamenitý pokrok. Našli jsme pro Vás něco dalšího, co můžete spravovat, pokud máte chuť na změnu prostředí a novou řadu úkolů. Nemusíte přijímat, ale může to stát za to. Plat by byl %d$\n\n",
    [3] = "Chcete práci v Nemocnici %s?",
  },
  [3] = {
    [1] = "Vážený/á %s\n\n",
    [2] = "Byli jste nesmírně úspěšní během Vašeho období v této nemocnici. Díky tomu od vás očekáváme velké věci a chtěli bychom Vám nabídnout pozici jinde. Plat by byl %d$, a myslíme si, že si zamilujete nové výzvy, které by to přineslo.\n\n",
    [3] = "Chtěli byste pozici v Nemocnici %s?",
  },
  [4] = {
    [1] = "Vážený/á %s\n\n",
    [2] = "Blahopřejeme! My na Ministerstvu jsme velmi ohromeni Vašimi schopnostmi provozovat nemocnici. Jste určitě zlatý chlapec v Oddělení Zdraví. Myslíme si ale, že byste upřednostňovali trošičku těžší práci. Byli byste placeni %d$, ale rozhodnutí je na Vás.\n\n",
    [3] = "Máte zájem o práci v Nemocnici %s?",
  },
  [5] = {
    [1] = "Vážený/á %s\n\n",
    [2] = "Dobrý den, opět. Vážíme si Vašeho přání neodejít z této okouzlující nemocnice, ale naléháme, abyste si to rozmysleli. Nabídneme Vám skvělý plat %d$, pokud jste připraveni odejít do jiné nemocnice a zařídit, aby běžela stejně tak hladce.\n\n",
    [3] = "Chtěli byste se teď přesunout do Nemocnice %s?",
  },
  [6] = {
    [1] = "Vážený/á %s\n\n",
    [2] = "Zdravíme. Víme, že jste šťastní v této milé a dobře provozované instituci, ale myslíme si, že byste teď měli zvážit další kariérní postup. Samozřejmě Vám bude náležet plat %d$ pokud se rozhodnete přesunout. Stojí za to o tom popřemýšlet, ne?\n\n",
    [3] = "Přejete si vzít místo v Nemocnici %s?",
  },
  [7] = {
    [1] = "Vážený/á %s\n\n",
    [2] = "Dobrý den! Ministerstvo Zdravotnictví by chtělo vědět, zda byste si nechtěli rozmyslet Vaše rozhodnutí zůstat v této nemocnici. Potvrzujeme, že máte milou nemocnici, ale také cítíme, že byste udělal dobře, když byste přijal místo s těžší výzvou, a platem %d$.\n\n",
    [3] = "Chtěli byste přijmout pozici v Nemocnici %s?",
  },
  [8] = {
    [1] = "Vážený/á %s\n\n",
    [2] = "Dobrý den, ještě jednou. Na náš poslední dopis, nabízející Vám prvotřídní pozici v nové nemocnici, a zvýšený plat %d$, jste odpověděli negativně. Nicméně, stále máme pocit, že byste si toto rozhodnutí měli rozmyslet. Máme totiž pro Vás dokonalou práci.\n\n",
    [3] = "Vezmete místo v Nemocnici %s? Prosím?",
  },
  [9] = {
    [1] = "Vážený/á %s\n\n",
    [2] = "Předvedli jste, že jste nejlepší správce nemocnice v dlouhé a pestré historii lékařství. Takový významný úspěch nemůže zůstat bez odměny, takže bychom Vám rádi nabídli místo Vrchního Šéfa Všech Nemocnic. Toto je čestná práce a přichází s platem %d$. Bude vám uspořádán oslavný průvod a lidé Vám budou ukazovat své uznání, kamkoliv půjdete.\n\n",
    [3] = "Díky za všechno, co jste udělali. Ať si pořádně užijete dlouhý napůl-důchod.\n\n",
    [4] = "",
  },
  [10] = {
    [1] = "Vážený/á %s\n\n",
    [2] = "Blahopřejeme k úspěšnému provozu všech nemocnic, ke kterým jsme Vás přidělili. Takový výtečný výkon Vás opravňuje ke svobodě všech světových měst. Je Vám dán důchod %d$, navíc limuzína a vše, co po Vás žádáme je cestovat od města k městu, setkávat se s Vaším zbožňujícím lidem a všude propagovat práci všech nemocnic.\n\n",
    [3] = "Všichni jsme na Vás pyšní. Není mezi námi nikdo, kdo by se necítil vděčný za Vaši tvrdou práci při zachraňování životů.\n\n",
    [4] = "",
  },
  [11] = {
    [1] = "Vážený/á %s\n\n",
    [2] = "Vaše kariéra byla ukázková, a Vy jste inspirací pro nás všechny. Děkujeme, že jste spravovali tolik nemocnic a v každé práci si moc dobře vedli. Chtěli bychom Vám darovat doživotní plat %d$, a chtěli bychom od Vás pouze to, abyste cestovali oficiálním autem s otevřenou střechou od města k městu a přednášeli o tom, jak jste dosáhli tolik tak rychle.\n\n",
    [3] = "Jste příklad pro každého správně smýšlejícího člověka, a to bez výjimky, všichni na světě Vás považují za skvělý přínos.\n\n",
    [4] = "",
  },
  [12] = {
    [1] = "Vážený/á %s\n\n",
    [2] = "Vaše úspěšná kariéra nejlepšího správce nemocnice od dob Mojžíše se chýlí ke konci. Nicméně, Váš dopad na pohodlný svět lékařství byl tak výrazný, že by Vám Ministerstvo rádo nabídlo plat %d$ jen abyste se objevili jako náš zástupce, zahajovat slavnosti, spouštět lodě a pořádat televizní zábavný program. Celý svět po Vás volá a pro nás všechny by to byla dobrá reklama!\n\n",
    [3] = "Prosím, přijměte tuto pozici. Nebude to těžká práce a poskytneme Vám auto a policejní doprovod kamkoliv se hnete.\n\n",
    [4] = "",
  },
  custom_level_completed = "Výborně! Dokončili jste všechny úkoly v této vlastní úrovni!",
  dear_player = "Vážený/á %s",
  return_to_main_menu = "Chtěli byste se vrátit do hlavního menu, nebo pokračovat v hraní?",
  campaign_level_completed = "Dobrá práce! Splnili jste úroveň. Ale ještě není konec! Chtěli byste přijmout pozici v nemocnici %s?",
  campaign_level_missing = "Je nám líto, ale zdá se, že následující úroveň této kampaně chybí. (Název: %s)",
  campaign_completed = "Neuvěřitelné! Zvládli jste splnit všechny úrovně. Nyní si můžete oddychnout a začít sepisovat sebechválu na všech fórech na Internetu. Hodně štěstí!",
}
rooms_short = {
  dna_fixer = "Genex 2000",
  psychiatric = "Psychiatrie",
  gps_office = "Kancelář Prak. Lékaře",
  toilets = "Toalety",
  general_diag = "Vyšetřovna",
  hair_restoration = "Sázeč Vlasů",
  corridor_objects = "Objekty Chodby",
  electrolysis = "Oddělení Elektrolýzy",
  scanner = "Skener",
  research_room = "Výzkumná Laboratoř",
  cardiogram = "Kardiogram",
  destroyed = "Zničená",
  reception = "Recepce",
  staffroom = "Místnost pro Zam.",
  ward = "Lůžkové Oddělení",
  jelly_vat = "Klinika Slizu",
  x_ray = "Rentgen",
  inflation = "Hustírna",
  ultrascan = "Ultrasken",
  blood_machine = "Hemogram",
  tongue_clinic = "Odd. Ochablého Jazyka",
  fracture_clinic = "Oddělení Zlomenin",
  training_room = "Výuka",
  decontamination = "Dekontaminace",
  pharmacy = "Lékárna",
  operating_theatre = "Operační Sál",
}
buy_objects_window = {
  price = "Cena: ",
  choose_items = "Zvolte Položky",
  total = "Celkem: ",
}
vip_names = {
  [1] = "Starosta Horních Kotěhůlek",
  [2] = "Karel Schwarzenberg",
  [3] = "Jan Novák, pracovník ve skladu Jednoty Malý Beranov",
  [4] = "Tomáš Marný, zástupný ředitel pojišťovny Neplaťto",
  [5] = "Franta Kocourek",
  [6] = "Tomáš Garrigue Masaryk",
  [7] = "Rada Vacátko",
  [8] = "Karel Brückner",
  [9] = "Aštar Šeran, vedoucí Velké vesmírné flotily",
  [10] = "Marek Vašut, prezident chlapáků",
  health_minister = "Ministr zdravotnictví",
}
fax = {
  vip_visit_query = {
    choices = {
      invite = "Vydat oficiální pozvánku pro V.I.P.",
      refuse = "Odmítnout s omluvou V.I.P.",
    },
    vip_name = "%s vyjádřil přání navštívit Vaší nemocnici",
  },
  vip_visit_result = {
    telegram = "Telegram!",
    vip_remarked_name = "Po návštěvě Vaší nemocnice, %s poznamenal:",
    remarks = {
      [1] = "To je úžasný špitál! Až zase něco lapnu, hoďte mě semka.",
      [2] = "Tak tomuto říkám nemocnice!",
      [3] = "Máte skvělou nemocnici. A v tom se vyznám, pár jsem jich již navštívil.",
      [4] = "Jak krásně fungující nemocnice. Děkuji za pozvání.",
      [5] = "Hmm. Docela pěkné lékařské zařízení, opravdu.",
      [6] = "Čas strávený ve vaší okouzlující nemocnici jsem si užil. Dáte si někdo gyros v Taj?",
      [7] = "Mno… viděl jsem i horší. I tak by se hodilo něco vylepšit.",
      [8] = "Ach bože. Nechtěl bych tady skončit, kdyby mi bylo špatně.",
      [9] = "Taková normální nemocnice, abych pravdu řekl. Upřímně, čekal jsem více.",
      [10] = "Proč jsem se s váma vůbec obtěžoval? Bylo to horší než čtyřhodinová opera!",
      [11] = "Jsem znechucen tím, co jsem u vás viděl. Tomu říkáte nemocnice? Spíše popelnice!",
      [12] = "Už mě nebaví být veřejně známý a navštěvovat takové díry jako je ta vaše! Rezignuji!",
      [13] = "To nebyla skládka? Udělám vše, co je v mých silách, aby vám to tu zavřeli!",
      [14] = "Doteď jsem neviděl takto otřesnou nemocnici. Jaká ostuda!",
      [15] = "To je děs! Tomuto jako říkáte nemocnice? To musím pořádně zapít.",
    },
    close_text = "Děkuji za návštěvu nemocnice.",
    cash_grant = "Byl Vám darován peněžní dar ve výši %d.",
    rep_loss = "Vaše reputace kvůli tomu utrpěla.",
    rep_boost = "Vaše reputace ve společnosti se zvýšila.",
  },
  disease_discovered = {
    can_cure = "Tuto nemoc můžete zvládnout.",
    close_text = "Byla objevena nová nemoc.",
    need_to_build = "Musíte vybudovat %s, abyste to mohli vyléčit.",
    need_to_build_and_employ = "Pokud vybudujete %s a zaměstnáte %s, můžete léčit tuto nemoc.",
    need_to_employ = "Zaměstnejte %s, abyste mohli tuto krizi zvládnout.",
    discovered_name = "Váš tým objevil novou nemoc. Je to %s",
  },
  diagnosis_failed = {
    choices = {
      send_home = "Poslat pacienta domů.",
      wait = "Nechat pacienta čekat, dokud nepostavíte další diagnostické místnosti.",
      take_chance = "Zkusit možnou léčbu.",
    },
    situation = "Vyčerpali jsme všechny diagnostické procedury na tomto pacientovi a stále si nejsme jisti, co s ním je špatně.",
    what_to_do_question = "Co máme s pacientem dělat?",
    partial_diagnosis_percentage_name = "Existuje %d procentní šance, že jsme identifikovali, že pacient má %s.",
  },
  epidemic_result = {
    fine_amount = "Vláda vyhlásila obecné ohrožení a uděluje Vám pokutu ve výši %d.",
    succeeded = {
      part_1_name = "Hygienický Inspektor slyšel zvěsti, že Vaše zařízení řeší zlý případ %s.",
      part_2 = "Nicméně se mu nepodařilo najít důkazy k potvrzení těchto zvěstí.",
    },
    close_text = "Hurá!",
    rep_loss_fine_amount = "Noviny si nad tímto smlsnou. Vaše reputace bude vážně poskvrněna. Navíc dostanete pokutu ve výši %d.",
    failed = {
      part_1_name = "Při pokusu o zakrytí faktu, že mají před sebou nakažlivé propuknutí %s",
      part_2 = "Vaši zaměstnanci nemocnice způsobili, že se choroba rozšířila do širokého okolí nemocnice.",
    },
    compensation_amount = "Vláda se rozhodla Vás odměnit %d jako vyrovnání za škodu, kterou tyto malé lži způsobili Vašemu dobrému jménu nemocnice.",
    hospital_evacuated = "Zdravotnická Rada neměla jinou možnost, než evakuovat nemocnici.",
  },
  emergency = {
    cure_not_possible_build = "Potřebujete postavit %s",
    locations = {
      [1] = "Chemický závod Spolana Neratovice.",
      [2] = "Padělaná Univerzita.",
      [3] = "Herbicidní Zahradnické Centrum.",
      [4] = "Výzkumný Institut Nebezpečných Látek.",
      [5] = "sjezd tanečníků České besedy.",
      [6] = "hospoda Žába a Býk.",
      [7] = "Pohřební síň a výčep Velkého Dejva.",
      [8] = "rychlé občerstvení Taj.",
      [9] = "Bártův Ráj Použitých Petrochemikálií.",
    },
    choices = {
      accept = "Ano. Jsem připraven zvládnout tuto pohotovost. ",
      refuse = "Ne. Odmítám zvládnout tuto pohotovost.",
    },
    cure_not_possible_employ = "Potřebujete zaměstnat %s",
    free_build = "Pokud budete úspěšní, Vaše reputace se zvýší, pokud ale selžete, bude to mít velký dopad na Vaši reputaci.",
    num_disease_singular = "Je tu 1 osoba s %s a vyžaduje okamžitou pozornost.",
    cure_not_possible_build_and_employ = "Bude potřeba postavit %s a zaměstnat %s",
    bonus = "K dispozici je maximální bonus %d za zvládnutí této havárie. Pokud ale selžete, Vaše reputace bude silně pošramocena.",
    cure_not_possible = "V tuto chvíli nemůžete nemoc léčit.",
    location = "V %s se stala nehoda",
    cure_possible_drug_name_efficiency = "Již máte potřebné přístroje a dovednosti. Máte lék, který potřebují. Je to %s a lék je na %d procent účinný.",
    cure_possible = "Máte správné vybavení a dovednosti, takže byste měli tuto havárii zvládnout.",
    num_disease = "Je tu %d osob s %s a vyžadují okamžitou pozornost.",
  },
  epidemic = {
    cover_up_explanation_2 = "Pokud nemocnici Hygienický Inspektor navštíví a zjistí, že stále probíhá ututlání epidemie, může proti Vám přijmout drastická opatření.",
    disease_name = "Vaši doktoři objevili nakažlivý kmen %s.",
    choices = {
      declare = "Vyhlásit Epidemii. Zaplatit pokutu a přijmout zásah do reputace.",
      cover_up = "Pokusit se vyléčit všechny nakažené pacienty ve vymezeném čase a předtím, než kdokoliv odejde z nemocnice.",
    },
    declare_explanation_fine = "Pokud vyhlásíte epidemii, zaplatíte pokutu %d, dostanete zásah do reputace a všichni Vaši pacienti budou automaticky očkováni.",
    cover_up_explanation_1 = "Na druhou stranu, pokud se pokusíte toto ututlat, máte omezený čas na vyléčení všech nakažených pacientů předtím, než na to přijdou Zdravotní Orgány.",
  },
  choices = {
    return_to_main_menu = "Návrat do hlavního menu",
    accept_new_level = "Pokračovat do další úrovně",
    decline_new_level = "Hrát ještě o trochu déle",
  },
  emergency_result = {
    earned_money = "Z maximálního bonusu %d jste získali %d.",
    close_text = "Klikněte pro zavření.",
    saved_people = "Zachránili jste %d lidí z celkových %d.",
  },
  disease_discovered_patient_choice = {
    what_to_do_question = "Co chcete s pacientem dělat?",
    need_to_employ = "Zaměstnat %s, aby bylo možné tuto situaci zvládnout.",
    can_not_cure = "Tuto chorobu nemůžete vyléčit.",
    need_to_build = "Musíte vybudovat %s, abyste byli schopni toto zvládnout.",
    choices = {
      send_home = "Poslat pacienta domů.",
      wait = "Nechat pacienta chvilku čekat v nemocnici.",
      research = "Poslat pacienta do Výzkumné Laboratoře.",
    },
    need_to_build_and_employ = "Pokud vybudujete %s a zaměstnáte %s, můžete uspět.",
    guessed_percentage_name = "Váš tým musel odhadnout pacientovu nemoc. Je tu %d procentní šance, že je to %s",
    disease_name = "Váš tým objevil novou nemoc. Je to %s",
  },
  debug_fax = {
    text2 = "CELKEM %d LIDÍ V NEMOCNICI ZAPSÁNO PROTI %d",
    text7 = "REPUTACE: %d OČEKÁVÁNA %d SNÍŽENÍ %d",
    text9 = "KATASTROFY %d POVOLENO (MĚS) %d (%d)SNÍŽENÍ %d",
    text4 = "FAKTORY  : DOKT %d  SESTRY %d  OBLAST %d  MÍSTNOSTI %d  CENA %d",
    text1 = "NEJLEPŠÍ POČET %d",
    text6 = "NÁSLEDUJÍCÍ FAKTORY JSOU TAKÉ ZAHRNUTY",
    close_text = "Jo, jo, jo!",
    text3 = "ČÍSLA  : DOKT %d  SESTRY %d  OBLAST %d  MÍSTNOSTI %d  CENA %d",
    text5 = "PŘISPÍVAJÍCÍ : DOKT %d  SESTRY %d  OBLAST %d  MÍSTNOSTI %d  CENA %d PROCENT",
    text8 = "POHODLÍ %d LIDÍ ZVLÁDNUTO %d ANÍŽENÍ %d",
    text10 = "ÚMRTÍ %d POVOLENO (MĚS) %d (%d) SNÍŽENÍ %d",
    text11 = "LIDÍ TENTO MĚSÍC %d",
  },
}
insurance_companies = {
  [1] = "RadyBaby a.s.",
  [2] = "Sparta pojišťovna k.s.",
  [3] = "Solidarita s.r.o.",
  [4] = "Jizva Bígla v.o.s.",
  [5] = "Píchlá Duše s.r.o.",
  [6] = "Jindřich Upřímný a.s.",
  [7] = "Koncern Pana Baculatého",
  [8] = "Rozbitý a spol. v.o.s.",
  [9] = "Ješitný a Bim s.r.o.",
  [10] = "pojišťovna Neplaťto",
  [11] = "Družstevní Pojišťovna",
  out_of_business = "BANKROT",
}
menu_file = {
  save = "  (%1%) ULOŽIT  ",
  load = "  (%1%) NAČÍST  ",
  restart = "  (%1%) RESTARTOVAT  ",
  quit = "  (%1%) ODEJÍT  ",
}
graphs = {
  visitors = "Návštěvníci",
  time_spans = {
    [1] = "1 Rok",
    [2] = "12 Let",
    [3] = "48 Let",
  },
  cures = "Vyléčení",
  wages = "Platy",
  deaths = "Úmrtí",
  balance = "Bilance",
  money_in = "Příjem",
  money_out = "Výdej",
  reputation = "Reputace",
}
staff_list = {
  total_wages = "PLATY CELKEM",
  tiredness = "ÚNAVA",
  morale = "MORÁLKA",
  skill = "DOVEDNOSTI",
}
introduction_texts = {
  level14 =
    "Je tu ještě jedna výzva - naprosto nečekaná nemocnice jako překvapení. " ..
    "Pokud to tu úspěšně zvládnete, budete vítěz všech vítězů. " ..
    "Nečekejte ale, že to bude lehké, protože je to ten nejtěžší úkol, jaký jste kdy viděli. " ..
    "Hodně Štěstí!",
  level16 =
    "Jakmile jste některé pacienty vyšetřili, budete muset pro jejich léčbu postavit léčebná zařízení a oddělení - dobrý začátek " ..
    "je Lékárna. Budete také potřebovat Sestru k vydávání různých léků v Lékárně.",
  level15 =
    "Dobrá, tak toto jsou základní instrukce jak sestavit nemocnici.\n\n" ..
    "Vaši Doktoři budou potřebovat veškerou pomoc, kterou mohou získat k vyšetření některých pacientů. Můžete jim pomoci " ..
    "postavením jiného diagnostického zařízení jako např. Vyšetřovny.",
  level18 = "",
  level12 =
    "Nyní máte před sebou výzvu všech výzev. " ..
    "Ohromeni vaším úspěchem, Ministerstvo má pro vás špičkovou práci; chtějí, aby někdo postavil tu nejlepší nemocnici, vydělal obrovské množství penízků a měl neuvěřitelnou reputaci. " ..
    "Očekává se, že také koupíte všechny pozemky, které můžete, všechno vyléčíte (a tím myslíme opravdu všechno) a vyhrajete všechna ocenění. " ..
    "Myslíte, že na to máte?" ..
    "Vydělejte 650,000$, vylečte 750 lidí a mějte reputaci ve výši 800, abyste to tu vyhráli.",
  level17 =
    "Malé varování - opravdu si hlídejte Vaši reputaci - to je to, co pacienty přiláká z široka daleka do vašeho zařízení. " ..
    "Pokud nezabijete příliš mnoho lidí a udržíte je rozumně šťastné, neměli byste mít v této úrovni problémy!\n\n" ..
    "Teď jste v tom sami. Hodně štěstí a tak dále.",
  level4 =
    "Udržte všechny lidi šťastné, zacházejte s nimi tak dobře, jak to jen jde, a udržte úmrtí na absolutním minimu. " ..
    "V sázce je vaše reputace, takže se ujistěte, že ji budete mít tak vysoko, jak je to jen možné. " ..
    "O peníze se moc nestarejte - ty přijdou společně s růstem vaší reputace. " ..
    "Budete mít také možnost učit Doktory a rozšířit jejich schopnosti. " ..
    "Mohli by mít na starost pacienta, který se zdá být méně neprůhledný než ostatní. " ..
    "Dosáhněte reputace přes 500.",
  level13 =
    "Vaše neuvěřitelné dovednosti správce nemocnice neunikly Bezpečnostní Informační Službě. " ..
    "Mají pro vás zvláštní bonus; je tu krysami zamořená nemocnice, která potřebuje účinného Terminátora. " ..
    "Musíte zastřelit tolik krys, kolik můžete, než Údržbáři uklidí všechen bordel. " ..
    "Myslíte, že to zvládnete?",
  level6 =
    "Použijte všechny vaše znalosti k zřízení bezproblémové, dobře spravované nemocnice, která má zdravý příjem a může se vypořádat s čímkoliv, co na ni nemocná veřejnost může hodit. " ..
    "Musíte si uvědomit, že zdejší atmosféra je zvláště vhodná k přenášení bacilů a infekcí. " ..
    "Pokud nebudete vaše zařízení udržovat až puntičkářsky čisté, můžete čelit řadě epidemií mezi pacienty. " ..
    "Ujistěte se, že si vyděláte 150,000$ a že vaše nemocnice má hodnotu přes 140,000$.",
  level5 =
    "Toto bude zaneprázdněná nemocnice, která bude řešit různé případy. " ..
    "Vaši Doktoři jsou všichni přímo z medicíny, takže bude zásadní vybudovat učebnu a vyučit si je. " ..
    "Máte pouze tři Konzultanty, kteří vám pomohou s výukou vašich nezkušených zaměstnanců, takže je udržujte šťastné. " ..
    "Nezapomeňte také, že základy této nemocnice stojí na geologickém zlomu San Robot. " ..
    "Je tu vždy možné nebezpečí zemětřesení. " ..
    "To způsobí vážné poškození vašich přístrojů a naruší hladký chod vaší nemocnice. " ..
    "Dostaňte vaši reputaci na značku 400 a uložte suprových 50,000$ abyste uspěli. Ještě vylečte 200 pacientů.",
  level8 =
    "Je na vás zřídit tu nejúčinnější a nákladově co nejefektivnější nemocnici. " ..
    "lidé v tomto okolí se nemají vůbec špatně, takže z nich vymáčkněte tolik prašulí, kolik můžete. " ..
    "Nezapomeňte, léčení lidí je sice hezké, ale opravdu POTŘEBUJETE peníze, které to přináší. " ..
    "Nezapomeňte tyto lidi řádně vyprášit. " ..
    "Nasyslete astronomických 300,000$ k dokončení této úrovně.",
  level7 =
    "Zde budete pod pečlivou kontrolou Ministerstva Zdravotnictví, takže se ujistěte, že vaše účty ukazují, že vyděláváte hodně peněz, a že vaše reputace je ve výšinách. " ..
    "Nemůžeme si dovolit zbytečná úmrtí - jsou špatná pro byznys. " ..
    "Ujistěte se, že vaši zaměstnanci jsou v nejlepší formě, a že máte veškeré vybavení, které potřebujete. " ..
    "Dostaňte reputaci na výši 600, plus 200,000$ v bance.",
  level2 =
    "V této oblasti je větší škála nemocí. " ..
    "Postavte vaši nemocnici, aby zvládla více pacientů, a nachystejte se na vybudování Výzkumné Laboratoře. " ..
    "Nezapomeňte udržovat vaše zařízení čisté a zkuste dostat vaši reputaci tak vysoko, jak to jen jde - budete čelit nemocem jako je Ochablý Jazyk, takže potřebujete ORL. " ..
    "Můžete také postavit Kardiogram, aby vám pomohl vyšetřit nové nemoci. " ..
    "Obě tyto místnosti musí být vyzkoumány předtím, než je budete moci postavit. Také si můžete zakoupit dodatečné parcely pozemků k rozšíření vaší nemocnice - pro toto použijte Mapu Města. " ..
    "Miřte k reputaci 300, bankovní bilanci 10,000$ a 40 vyléčeným lidem.",
  level9 =
    "Když jste naplnili bankovní účet Ministerstva a zaplatili novou limuzínu pro samotného Ministra, můžete se vrátit zpět k vytváření pečující, dobře zřízené nemocnice ve prospěch nemocných a potřebných. " ..
    "Můžete očekávat, že se zde objeví spousta různorodých problémů. " ..
    "Pokud ale máte dostatek dobře vyškolených zaměstnanců a místností, nemělo by se jednat o větší problém. " ..
    "Vaše nemocnice musí mít hodnotu 200,000$ a budete potřebovat 400,000$ v bance. " ..
    "Cokoliv méně a nebudete moct dokončit úroveň.",
  demo =
    "Vítejte v demo nemocnici!\n\n" ..
    "Bohužel, demo verze obsahuje pouze tuto úroveň. Nicméně je toho více než dost, abyste se na chvilku zabavili! " ..
    "Setkáte se s různými nemocemi, které potřebují různé místnosti k léčbě. Čas od času můžete narazit na pohotovosti. A budete potřebovat vyzkoumat dodatečné místnosti pomocí výzkumné laboratoře. " ..
    "Vaším úkolem je vydělat 100,000$, mít hodnotu nemocnice na výši 70,000$ a reputaci 700, přičemž musíte vyléčit alespoň 75% vašich pacientů. " ..
    "Ujistěte se, že vaše reputace nespadne 300 a že nezabijete více než 40% vašich pacientů, jinak prohrajete.\n\n" ..
    "Zlomte vaz! (Ale ne doslova prosím.)",
  level10 =
    "Stejně jako zvládnutí všech nemocí, které se v této oblasti vyskytují, Ministerstvo žádá, abyste strávil nějaký čas soustředěním se na účinnost vašich léků. " ..
    "Z ČasNemoci, Hlídacího Psa Zdravotnictví, se ozývají jisté stížnosti. Tudíž, abyste vypadali dobře, musíte zajistit, že vaše léky jsou mimořádně účinné. " ..
    "Také zajistěte, aby vaše nemocnice nemusela být kárána. Ať ta úmrtnost není příliš vysoká. " ..
    "Malá nápověda: možná byste měli vyhradit prostor pro Kliniku Slizu. " ..
    "Zdokonalte všechny svoje léky na účinnost alespoň 80 procent, mějte reputaci 650 a ukryjte 500,000$ v bance, abyste vyhráli. ",
  level11 =
    "Byla vám dána šance vybudovat to nejlepší z nemocnic. " ..
    "Toto je mimořádně prestižní oblast a Ministerstvo by rádo vidělo tu nejlepší možnou nemocnici. " ..
    "Očekáváme, že budete vydělávat velké peníze, získáte vysokou reputaci a zvládnete všechny možné případy. " ..
    "Toto je důležitá práce. " ..
    "Musíte se opravdu snažit, abyste toto zvládli. " ..
    "Nezapomeňte také, že v oblasti byla zpozorována UFO. Ujistěte se, že vaši zaměstnanci jsou připraveni na nečekané návštěvníky. " ..
    "Vaše nemocnice potřebuje mít hodnotu 240,000$, v bance potřebujete 500,000$ a vaše reputace musí dosahovat alespoň 700.",
  level3 =
    "Tentokrát budete zřizovat nemocnici v zámožné oblasti. " ..
    "Ministerstvo Zdravotnictví od vás očekává, že zde zajistíte zdravý příjem. " ..
    "Především budete muset získat dobrou reputaci, ale jakmile nemocnice běží sama, soustřeďte se co nejvíce na vydělávání peněz. " ..
    "Je tu také možnost výskytu Pohotovostí. " ..
    "To znamená, že přijde najednou velký počet lidí a všichni mají stejnou nemoc. " ..
    "Vyléčení všech v časovém limitu vám vylepší reputaci a přidá velký bonus. " ..
    "Mohou se objevit nemoci jako Králův Komplex. Také byste měli zahrnout do rozpočtu výstavbu Operačního Sálu a poblíž i Lůžkové Oddělení. " ..
    "Vydělejte 20,000$ abyste dosáhli další úrovně.",
  level1 =
    "Vítejte ve vaší první nemocnici!\n\n" ..
    "Rozchoďte to tu umístěním Recepce, vybudováním Kanceláře Praktického Lékaře a najmutím Recepční a Doktora. " ..
    "Pak počkejte, až přijde nějaký byznys. " ..
    "Je dobrý nápad postavit Psychiatrii a najmout Doktora s Psychiatrickými kvalifikacemi. " ..
    "Lékárna a Sestra jsou také nutné k léčbě Vašich pacientů. " ..
    "Dejte si pozor na případy podivné nemoci Nafouknutá Hlava - Hustírna je vyléčí. " ..
    "Musíte vyléčit alespoň 10 lidí a zajistit, že vaše reputace nespadne pod 200.",
}
install = {
  th_directory = "CorsixTH potřebuje kopii datových souborů z původní hry Theme Hospital (nebo demoverze), aby mohla běžet. Prosím, použijte okno níže k nalezení instalační složky Theme Hospital.",
  title = "-------------------------------- Nastavení CorsixTH --------------------------------",
  exit = "Odejít",
  ok = "OK",
  cancel = "Zrušit",
}
staff_class = {
  receptionist = "Recepční",
  surgeon = "Chirurg",
  handyman = "Údržbář",
  doctor = "Doktor",
  nurse = "Sestra",
}
menu_charts = {
  bank_manager  = "  (%1%) SPRÁVCE BANKY  ",
  statement     = "  (%1%) FINANČNÍ VÝKAZ  ",
  staff_listing = "  (%1%) SEZNAM ZAMĚSTNANCŮ  ",
  town_map      = "  (%1%) MAPA MĚSTA  ",
  casebook      = "  (%1%) KNIHA LÉČBY PACIENTŮ  ",
  research      = "  (%1%) VÝZKUM  ",
  status        = "  (%1%) STAV  ",
  graphs        = "  (%1%) GRAFY  ",
  policy        = "  (%1%) ZÁSADY  ",
  briefing      = "  ÚVOD DO MISE  ",
}
level_progress = {
  cured_enough_patients = "Vyléčil jste dost svých pacientů, ale k výhře musíte dostat nemocnici do lepšího stavu.",
  hospital_value_enough = "Neklesněte s hodnotou své nemocnice pod %d a k výhře vám postačí dořešit zbylé problémy.",
}
menu_options_volume = {
  [30] = "    30%  ",
  [10] = "    10%  ",
  [90] = "    90%  ",
  [40] = "    40%  ",
  [20] = "    20%  ",
  [50] = "    50%  ",
  [70] = "    70%  ",
  [60] = "    60%  ",
  [100] = "    100%  ",
  [80] = "    80%  ",
}
drug_companies = {
  [1] = "Léky-co-máte-rádi",
  [2] = "Léky Jsme My",
  [3] = "Drsná Malá Pilulka spol.",
  [4] = "Heřman Dobromyslný s.r.o.",
  [5] = "Všelék a.s.",
}
options_window = {
  change_resolution = "Změnit Rozlišení",
  width = "Šířka",
  fullscreen = "Celá Obrazovka",
  apply = "Použít",
  caption = "Nastavení",
  resolution = "Rozlišení",
  option_off = "Vypnuto",
  custom_resolution = "Vlastní…",
  option_on = "Zapnuto",
  language = "Jazyk hry",
  height = "Výška",
  cancel = "Zrušit",
  back = "Zpět",
  folder = "Složky",
  customise = "Přizpůsobit",
  audio = "Globální audio",
  zoom_speed = "Rychlost přibližování",
  scrollspeed = "Rychlost rolování",
  capture_mouse = "Zachytávat myš v okně hry",
  hotkey = "Klávesové zkratky",
  shift_scrollspeed = "Rychlost rolování se shiftem",
  option_enabled = "Povoleno",
  option_disabled = "Zakázáno",
  check_for_updates = "Kontrola aktualizací",
}
folders_window = {
  new_th_location = "Zde můžete zadat novou instalační složku Theme Hospital. Jakmile ji zvolíte, hra bude restartována.",
  data_label = "Data TH",
  music_label = "MP3",
  savegames_label = "Uložené hry",
  music_location = "Vyberte adresář s hudbou, která bude použita ve hře.",
  caption = "Umístění složek",
  screenshots_label = "Snímky obrazovky",
  font_label = "Písmo",
  back = "Zpět",
  savegames_location = "Vyberte složku, kde budou ukládány vaše uložené hry",
  screenshots_location = "Vyberte složku, kde budou ukládány snímky obrazovky",
}
font_location_window = {
  caption = "Zvolte písmo (%1%)"
}
multiplayer = {
  everyone_failed = "Nikdo nesplnil poslední cíl. Všichni tedy s chutí do práce!",
  players_failed = "Tito hráči nezvládli splnit poslední cíl:",
}
disease_discovered_patient_choice = {
  need_to_employ = "Ke zvládnutí musíte zaměstant %s.",
}
menu_options_wage_increase = {
  deny = "    ZAMÍTNOUT",
  grant = "    VYHOVĚT",
}
hotkey_window = {
  ingame_scroll_left = "Rolovat doleva",
  ingame_panel_research_alt = "Výzkum 2",
  ingame_recallPosition_6 = "6",
  button_accept = "Potvrdit",
  ingame_panel_casebook_alt = "Sez. nemocí",
  ingame_loadMenu = "Načíst hru",
  ingame_patient_gohome = "Poslat domů",
  ingame_recallPosition_0 = "10",
  ingame_storePosition_0 = "10",
  ingame_panel_bankStats = "Stav bankovního účtu",
  caption_main = "Nastavení klávesových zkratek",
  ingame_zoom_in_more = "Přiblížit více",
  ingame_panel_hireStaff = "Najmout zaměstnance",
  button_recallPosKeys = "Přepnout na pozici",
  ingame_zoom_in = "Přiblížit",
  panel_generalInGameKeys = "Hlavní herní kláv.",
  ingame_toggleSounds = "Zvuky",
  ingame_poopLog = "Vypsat log",
  ingame_panel_casebook = "Sez. nemocí",
  global_screenshot = "Snímek obrazovky",
  panel_altPanelKeys = "Náhradní klávesy",
  ingame_toggleAdvisor = "Poradce",
  global_connectDebugger = "Debugger",
  ingame_quickSave = "Rychlé uložení",
  ingame_scroll_up = "Rolovat nahoru",
  global_exitApp = "Vypnout program",
  global_resetApp = "Resetovat program",
  panel_toggleKeys = "Klávesy vypnutí/zapnutí",
  button_back = "Zpátky",
  global_stop_movie_alt = "Vypnout film",
  ingame_scroll_right = "Rolovat vpravo",
  ingame_toggleInfo = "Info",
  global_cancel = "Zrušit",
  ingame_gamespeed_slowest = "Nejpomalejší",
  ingame_storePosition_8 = "8",
  panel_scrollKeys = "Rolování kamery",
  button_defaults = "Resetovat na výchozí",
  ingame_storePosition_2 = "2",
  global_runDebugScript = "Skript pro ladění",
  ingame_recallPosition_3 = "3",
  ingame_panel_editRoom = "Upravit místnost",
  ingame_panel_policy = "Zásady",
  ingame_recallPosition_8 = "8",
  ingame_quitLevel = "Odejít z úrovně",
  ingame_jukebox = "Jukebox",
  global_releaseMouse = "Přestat zachycovat kurzor",
  ingame_storePosition_9 = "9",
  ingame_recallPosition_9 = "9",
  ingame_pause = "Pauza",
  ingame_panel_map_alt = "Mapa města 2",
  ingame_scroll_down = "Rolovat dolů",
  panel_storePosKey = "Uložit pozici kamery",
  ingame_recallPosition_7 = "7",
  global_showLuaConsole = "Lua Konzole",
  ingame_recallPosition_4 = "4",
  ingame_saveMenu = "Uložit hru",
  ingame_gamespeed_slower = "Pomalejší",
  panel_globalKeys = "Klávesy všude",
  ingame_storePosition_5 = "5",
  ingame_openFirstMessage = "Cíle úrovně",
  panel_miscInGameKeys = "Různé klávesy ve hře",
  ingame_zoom_out_more = "Oddálit více",
  ingame_showCheatWindow = "Nabídka cheatů",
  ingame_panel_staffManage = "Spravovat zaměstnance",
  ingame_gamespeed_max = "Max rychlost",
  ingame_showmenubar = "Zobrazit nabídku",
  ingame_gamespeed_speedup = "Zrychlit",
  ingame_panel_townMap = "Mapa města",
  panel_recallPosKeys = "Pozice kamery",
  ingame_recallPosition_2 = "2",
  ingame_panel_research = "Výzkum",
  global_confirm_alt = "Potvrdit",
  ingame_toggleMusic = "Hudba",
  panel_zoomKeys = "Klávesy přiblížení",
  ingame_panel_casebook_alt02 = "Sez. nemocí",
  global_cancel_alt = "Zrušit",
  ingame_toggleAnnouncements = "Oznámení",
  ingame_storePosition_7 = "7",
  button_cancel = "Zrušit",
  ingame_zoom_out = "Oddálit",
  ingame_panel_status = "Úspěšnost",
  ingame_storePosition_4 = "4",
  global_fullscreen_toggle = "Celá obrazovka",
  ingame_panel_bankManager = "Bankovní správce",
  ingame_setTransparent = "Zprůhlednit",
  ingame_restartLevel = "Restartovat úroveň",
  panel_gameSpeedKeys = "Klávesy rychlosti hry",
  panel_debugKeys = "Vývojářské klávesy",
  ingame_panel_furnishCorridor = "Vybavení chodby",
  ingame_panel_buildRoom = "Postavit místnost",
  ingame_storePosition_1 = "1",
  global_confirm = "Potvrdit",
  ingame_scroll_shift = "Změna rychlosti",
  ingame_recallPosition_1 = "1",
  ingame_panel_charts = "Grafy",
  button_toggleKeys = "Přenastavit klávesy",
  ingame_gamespeed_thensome = "A ještě trochu navíc",
  ingame_quickLoad = "Rychlé načtení",
  ingame_recallPosition_5 = "5",
  global_window_close_alt = "Zavřít okno",
  ingame_storePosition_6 = "6",
  ingame_rotateobject = "Otočit objekt",
  ingame_poopStrings = "Vypsat řetězce",
  caption_panels = "Kláv. panelu",
  ingame_storePosition_3 = "3",
  ingame_gamespeed_normal = "Normální",
  button_gameSpeedKeys = "Klávesy rychlosti hry",
  ingame_reset_zoom = "Obnovit přiblížení",
  panel_storePosKeys = "Uložit klávesy poz. kamery",
}
update_window = {
  caption = "Dostupná aktualizace!",
  new_version = "Nová verze:",
  current_version = "Současná verze:",
  download = "Přejít na stránku ke stažení",
  ignore = "Přeskočit a přejít do hlavní nabídky",
}
customise_window = {
  average_contents = "Průměrný obsah",
  option_on = "Zapnuto",
  paused = "Stavět při pozastavení",
  option_off = "Vypnuto",
  intro = "Přehrát úvodní video",
  caption = "Vlastní nastavení",
  back = "Zpět",
  movies = "Globální kontrola videí",
  volume = "Zkrátka snížení hlasitosti",
  aliens = "Pacienti s mimozemskou DNA",
  fractured_bones = "Zlomené kosti",
  remove_destroyed_rooms = "Odklidit zničenou místnost.",
}
custom_campaign_window = {
  caption = "Vlastní kampaň",
  start_selected_campaign = "Spustit kampaň",
}
warnings = {
  levelfile_variable_is_deprecated = "Upozornění: Úroveň '%s' ve svém souboru obsahuje zastaralé určení proměnné.'%LevelFile' bylo přejmenováno na '%MapFile'. Pro aktualizaci úrovně prosím použijte editor map.",
  newersave = "Pozor! Nahráli jste uloženou hru z novější verze. Nedoporučujeme pokračovat z důvodu možných pádů hry. Na vlastní riziko.",
}
map_editor_window = {
  pages = {
    paste = "Vložit oblast",
    camera_3 = "Kamera 3",
    hedgerow = "Živý plot",
    delete_wall = "Smazat zdi",
    road = "Silnice",
    parcel_7 = "Parcela 7",
    pond = "Rybníky",
    heliport_3 = "Heliport 3",
    outside = "Vnější prostory",
    parcel_3 = "Parcela 3",
    helipad = "Přistávací plocha",
    parcel_1 = "Parcela 1",
    heliport_4 = "Heliport 4",
    parcel_6 = "Parcela 6",
    foliage = "Rostliny",
    parcel_2 = "Parcela 2",
    parcel_5 = "Parcela 5",
    parcel_4 = "Parcela 4",
    parcel_0 = "Parcela 0",
    north_wall = "Severní zeď",
    inside = "Vnitřní prostory",
    parcel_9 = "Parcela 9",
    heliport_2 = "Heliport 2",
    parcel_8 = "Parcela 8",
    camera_4 = "Kamera 4",
    camera_1 = "Kamera 1",
    camera_2 = "Kamera 2",
    west_wall = "Západní zeď",
    heliport_1 = "Heliport 1",
  },
}
save_map_window = {
  new_map = "Nová mapa",
  caption = "Uložit mapu (%1%)",
}
menu_player_count = {
  players_1 = "  1 HRÁČ  ",
  players_2 = "  2 HRÁČI  ",
  players_3 = "  3 HRÁČI  ",
  players_4 = "  4 HRÁČI  ",
}

